/*******************************************************************************
* File: wire_mesh.pov                                                          *
* Author: William Scott Gammans                                                *
*                                                                              *
* This file creates the wire_mesh.bmp bitmap that is used in the               *
* texture map for the impulse engine cowling housing in my Starship Enterprise *
* POV-Ray model. RENDER THIS FILE IN ORTHOGRAPHIC 100 x 100.                   *
*                                                                              *
* "Star Trek", the "Starship Enterprise" and related marks are trademarks of   *
* Paramount Pictures Corporation. No infringement on the trademarks and copy-  *
* rights of Paramount Pictures Corporation is implied or intended.             *
*                                                                              *
* Permission is hereby given to use this POV-Ray scene file free of charge for *
* any NON-COMMERCIAL purpose, provided that credit is given to the author,     *
* William Scott Gammans. Commercial use is prohibited by the trademarks and    *
* copyrights of Paramount Pictures Corporation. Non-attributed use is just     *
* plain bad manners; your mother didn't raise you to be a thief.               *
*                                                                              *
* This original artwork copyright (c) 2002 by William Scott Gammans.           *
*                                                                              *
* Visit my website at http://www.scottgammans.com                              *
*                                                                              *
* Original USS Enterprise design by Matt Jeffries.                             *
*******************************************************************************/

#declare Y_Gradient_Texture = texture {
	gradient y
	texture_map {
		[0 pigment {color rgb 1} finish {ambient 1}]
		[0.5 pigment {color rgb 0.25} finish {ambient 1}]
		[1 pigment {color rgb 1} finish {ambient 1}]
	} 
	scale 2
}

#local MESH_MAJOR_RADIUS = 1.5;
#local MESH_MINOR_RADIUS = 1.0;

#declare Horizontal_Mesh = union {
	difference {
		torus {MESH_MAJOR_RADIUS,MESH_MINOR_RADIUS texture {Y_Gradient_Texture} rotate x*90 translate x*-9}
		plane {y,0 inverse}
	}
	difference {
		torus {MESH_MAJOR_RADIUS,MESH_MINOR_RADIUS texture {Y_Gradient_Texture} rotate x*90 translate x*-6}
		plane {y,0}
	}
	difference {
		torus {MESH_MAJOR_RADIUS,MESH_MINOR_RADIUS texture {Y_Gradient_Texture} rotate x*90 translate x*-3}
		plane {y,0 inverse}
	}
	difference {
		torus {MESH_MAJOR_RADIUS,MESH_MINOR_RADIUS texture {Y_Gradient_Texture} rotate x*90}
		plane {y,0}
	}
	difference {
		torus {MESH_MAJOR_RADIUS,MESH_MINOR_RADIUS texture {Y_Gradient_Texture} rotate x*90 translate x*3}
		plane {y,0 inverse}
	}
	difference {
		torus {MESH_MAJOR_RADIUS,MESH_MINOR_RADIUS texture {Y_Gradient_Texture} rotate x*90 translate x*6}
		plane {y,0}
	}
	difference {
		torus {MESH_MAJOR_RADIUS,MESH_MINOR_RADIUS texture {Y_Gradient_Texture} rotate x*90 translate x*9}
		plane {y,0 inverse}
	}
}

#declare Vertical_Mesh = union {
	difference {
		torus {MESH_MAJOR_RADIUS,MESH_MINOR_RADIUS texture {Y_Gradient_Texture} rotate z*90 translate z*-9}
		plane {y,0 inverse}
	}
	difference {
		torus {MESH_MAJOR_RADIUS,MESH_MINOR_RADIUS texture {Y_Gradient_Texture} rotate z*90 translate z*-6}
		plane {y,0}
	}
	difference {
		torus {MESH_MAJOR_RADIUS,MESH_MINOR_RADIUS texture {Y_Gradient_Texture} rotate z*90 translate z*-3}
		plane {y,0 inverse}
	}
	difference {
		torus {MESH_MAJOR_RADIUS,MESH_MINOR_RADIUS texture {Y_Gradient_Texture} rotate z*90}
		plane {y,0}
	}
	difference {
		torus {MESH_MAJOR_RADIUS,MESH_MINOR_RADIUS texture {Y_Gradient_Texture} rotate z*90 translate z*3}
		plane {y,0 inverse}
	}
	difference {
		torus {MESH_MAJOR_RADIUS,MESH_MINOR_RADIUS texture {Y_Gradient_Texture} rotate z*90 translate z*6}
		plane {y,0}
	}
	difference {
		torus {MESH_MAJOR_RADIUS,MESH_MINOR_RADIUS texture {Y_Gradient_Texture} rotate z*90 translate z*9}
		plane {y,0 inverse}
	}
}

union {
	object {Horizontal_Mesh translate <0,0,6>}
	object {Horizontal_Mesh translate <3,0,3>}
	object {Horizontal_Mesh translate <0,0,0>}
	object {Horizontal_Mesh translate <3,0,-3>}
	object {Horizontal_Mesh translate <0,0,-6>}

	object {Vertical_Mesh translate <-6,0,-3>}
	object {Vertical_Mesh translate <-3,0,0>}
	object {Vertical_Mesh translate <0,0,-3>}
	object {Vertical_Mesh translate <3,0,0>}
	object {Vertical_Mesh translate <6,0,-3>}
}

camera {     
	/*
	orthographic
	location <200,200,200>
	up y
	right x
	look_at 175
	angle 27
	*/
	///*
	orthographic
	location y*200
	up y
	right x
	look_at y*175 
	angle 27
	//*/
}
