/*******************************************************************************
* File: starship_enterprise.inc                                                *
* Author: William Scott Gammans                                                *
*                                                                              *
* This file contains the POV-Ray model of the Starship Enterprise as seen      *
* during the original "Star Trek" series.                                      *
*                                                                              *
* "Star Trek", the "Starship Enterprise" and related marks are trademarks of   *
* Paramount Pictures Corporation. No infringement on the trademarks and copy-  *
* rights of Paramount Pictures Corporation is implied or intended.             *
*                                                                              *
* Permission is hereby given to use this POV-Ray scene file free of charge for *
* any NON-COMMERCIAL purpose, provided that credit is given to the author,     *
* William Scott Gammans. Commercial use is prohibited by the trademarks and    *
* copyrights of Paramount Pictures Corporation. Non-attributed use is just     *
* plain bad manners; your mother didn't raise you to be a thief.               *
*                                                                              *
* This original artwork copyright (c) 2002 by William Scott Gammans.           *
*                                                                              *
* Visit my website at http://www.scottgammans.com                              *
*                                                                              *
* Original USS Enterprise design by Matt Jeffries.                             *
*******************************************************************************/

/*******************************************************************************
* Revision history                                                             *
* ================                                                             *
* 06/11/2002 - Public release of version 1.0.                                  *
*******************************************************************************/

/*******************************************************************************
* Rendering switches                                                           *
* These switches control various aspects of how the Enterprise is rendered.    *
*******************************************************************************/
#declare ANIM_FRAMES_PER_SECOND=24;         // This setting governs temporal effects that need to know the animation FPS (s/b either 24 or 30)
#declare WARP_POWER_LEVEL=100;              // This setting controls the brightness of the bussard collector dome and the ball at the aft end of the warp nacelle. 0% is completely dark; 100% is full power
#declare WARP_NACELLE_RPM=30;               // The number of revolutions per minute the bussard collector spinner makes (at 30 fps). Set to 0 to stop rotation completely. Normal speed is 20 (1 rev every 3 secs @ 30 fps)
#declare HANGAR_BAY_DOORS_OPEN_PCT=0;       // This setting opens (100%) and closes (0%) the hangar bay clamshell doors
#declare IMPULSE_POWER_PCT=075;             // This setting antenuates the glow of the impulse engines. 0% is completely dark, 25% is a good "standby" glow, and 100% is full power
#declare BLINK_PHASE=0;                     // Set to any value between 0 & ANIM_FRAMES_PER_SECOND to make multiple starships not blink in sync
#declare NO_PORTHOLES=false;                // Rendering the portholes exponentially slows down the rendering of the Enterprise. For test renders, this switch can be set to not punch out windows.
#declare NO_EXTERIOR_LIGHTS=false;          // The self-illumination lights also slow down rendering...
#declare DETAIL_LEVEL=5;                    // Valid values are 1-5. 5=full rez 4=no interior lights 3=less physical detailing 2=opaque ambient windows 1=reserved

#if (DETAIL_LEVEL<5)
	#declare NO_INTERIOR_LIGHTS=true;       // The interior lights ALSO slow down rendering...
#else
	#declare NO_INTERIOR_LIGHTS=false;
#end

/*******************************************************************************
* Constants                                                                    *
*******************************************************************************/

// The hull of the Enterprise is modeled as a three-layer sandwich consisting
// of the outer hull layer, a glass porthole layer, and the inner hull layer.
// This allows us to have three different materials/textures for each layer:
#declare OUTER_HULL_THICKNESS=0.125;    // The thickness of the outer skin of the ship
#declare PORTHOLE_THICKNESS=0.0625;     // The thickness of the glass in a porthole
#declare INNER_HULL_THICKNESS=0.0625;   // The thickness of the inner walls of the ship
#declare HULL_THICKNESS = OUTER_HULL_THICKNESS + PORTHOLE_THICKNESS + INNER_HULL_THICKNESS;

// This model eventually will be a "virtual Enterprise" with actual
// interior rooms. That's why we define all of the deck locations:
#declare DECK_THICKNESS=0.25;                               
#declare BULKHEAD_THICKNESS=0.25;                               
#declare DECK_CLEARANCE=2.25;                               // i.e., floor-to-ceiling average height (this will vary in some spots)
#declare DECK_SPACING=DECK_CLEARANCE + DECK_THICKNESS/2;	// centerline to centerline

// y-axis offset for primary hull decks:
#declare PRIMARY_HULL_DECK_1_Y_OFFSET = 11.7625;
#declare PRIMARY_HULL_DECK_2_Y_OFFSET = 9.2625;
#declare PRIMARY_HULL_DECK_3_Y_OFFSET = 6.7625;
#declare PRIMARY_HULL_DECK_4_Y_OFFSET = 4.2625;
#declare PRIMARY_HULL_DECK_5_Y_OFFSET = 1.7625;
#declare PRIMARY_HULL_DECK_6_Y_OFFSET = -0.7375;
#declare PRIMARY_HULL_DECK_7_Y_OFFSET = -3.2375;
#declare PRIMARY_HULL_DECK_8_Y_OFFSET = -5.7375;
#declare PRIMARY_HULL_DECK_9_Y_OFFSET = -9.0988;	// Decks 9 & 10 moved downward to accomodate the placement of the exterior windows around the lower sensor array
#declare PRIMARY_HULL_DECK_10_Y_OFFSET = -11.5988;

// y-axis offset for interconnecting pylon decks:
#declare INTERCONNECTING_PYLON_UPPER_PLANE = 8.76;
#declare INTERCONNECTING_DECK_7_Y_OFFSET = 6.26;
#declare INTERCONNECTING_DECK_8_Y_OFFSET = 3.76;
#declare INTERCONNECTING_DECK_9_Y_OFFSET = 1.26;
#declare INTERCONNECTING_DECK_10_Y_OFFSET = -1.24;
#declare INTERCONNECTING_DECK_11_Y_OFFSET = -3.74;
#declare INTERCONNECTING_DECK_12_Y_OFFSET = -6.24;
#declare INTERCONNECTING_DECK_13_Y_OFFSET = -8.74;
#declare INTERCONNECTING_DECK_14_Y_OFFSET = -12.865;	// This is where the pylon meets the secondary hull

// y-axis offset for secondary hull decks:
#declare SECONDARY_HULL_DECK_15_Y_OFFSET = 9.875;
#declare SECONDARY_HULL_DECK_16_Y_OFFSET = 7.375;
#declare SECONDARY_HULL_DECK_17_Y_OFFSET = 4.875;
#declare SECONDARY_HULL_DECK_18_Y_OFFSET = 2.375;
#declare SECONDARY_HULL_DECK_19_Y_OFFSET = -0.125;
#declare SECONDARY_HULL_DECK_20_Y_OFFSET = -2.625;
#declare SECONDARY_HULL_DECK_21_Y_OFFSET = -5.125;
#declare SECONDARY_HULL_DECK_22_Y_OFFSET = -7.625;
#declare SECONDARY_HULL_DECK_23_Y_OFFSET = -10.125;
#declare SECONDARY_HULL_DECK_24_Y_OFFSET = -12.625;

// Colors:
#declare ENTERPRISE_RED=color red 0.75 green 0.0 blue 0.0;
#declare ENTERPRISE_YELLOW=color red 0.75 green 0.75 blue 0.0;
#macro ENTERPRISE_GRAY(grayscale_strength)
	color red grayscale_strength/100 green grayscale_strength/100+0.01 blue grayscale_strength/100
#end
//#declare ENTERPRISE_COPPER=color red 0.72 green 0.45 blue 0.20;
#declare ENTERPRISE_COPPER=color red 0.36 green 0.225 blue 0.10;
#declare ENTERPRISE_SILVER=color red 0.90 green 0.91 blue 0.98;
#declare ENTERPRISE_BLACK=color red 0.02 green 0.02 blue 0.02;
#declare ENTERPRISE_GOLD=color red 0.85 green 0.85 blue 0.10;
#declare ENTERPRISE_DARKSLATEGRAY = color red 0.09 green 0.15 blue 0.15;
#declare ENTERPRISE_DARKGREEN=color red 0.6 green 0.7 blue 0.6;
#declare ENTERPRISE_TODO=color rgb 0.8;

/*******************************************************************************
* POV-Ray constants                                                            *
*******************************************************************************/
// Map types
#declare MT_PLANE    = 0;
#declare MT_SPHERE   = 1;
#declare MT_CYLINDER = 2;
#declare MT_FUTURE3  = 3;
#declare MT_FUTURE4  = 4;
#declare MT_TORUS    = 5;

/*******************************************************************************
* Textures and texture macros                                                  *
*******************************************************************************/
#macro Metallic_Hull_Plating(c,df,spec,rf) 
	pigment {c}
	finish {
	    ambient 0.05
	    brilliance 4
	    diffuse df
	    metallic 0.5
	    specular spec
	    roughness 0.65
	    reflection rf
	}
#end

#macro Metallic_Hull_Plating_Ambient(c,df,spec,rf) 
	pigment {c}
	finish {
	    ambient 0.75
	    brilliance 4
	    diffuse df
	    metallic 0.5
	    specular spec
	    roughness 0.65
	    reflection rf
	}
#end

#macro Painted_Hull_Plating(c,df,spec,rf) 
	pigment {c}
	finish {
	    ambient 0.05
	    brilliance 6
	    diffuse df
	    metallic 1
	    specular spec
	    roughness 0.4
	    reflection rf
	}
#end

#macro Conical_Hull_Plate(chp_start,chp_start_radius,chp_end,chp_end_radius,chp_slice_angle,plate_texture,joint_texture,control_0,control_1,z_scale_override)
difference {
	cone {<0,0,chp_start>,chp_start_radius+0.000001,<0,0,chp_end>,chp_end_radius+0.000001}
	cone {<0,0,chp_start+0.000001>,chp_start_radius,<0,0,chp_end-0.000001>,chp_end_radius}
	plane {y,0 rotate z*-chp_slice_angle/2}
	plane {y,0 rotate z*chp_slice_angle/2 inverse}
	texture {
	  	quilted
		texture_map {
			[0.0 plate_texture]
			[1.0 joint_texture]
		}
		control0 control_0
		control1 control_1
		#local xy_scale=sin(radians(chp_slice_angle/2))*chp_start_radius*2;
		#if (z_scale_override!=0)
			#local z_scale=z_scale_override;
		#else
			#local z_scale=chp_start-chp_end;
		#end		
		matrix <
			xy_scale,0,0,
			0,xy_scale,0,
			0,0,z_scale,
			0,xy_scale/2,chp_start
		>
	}
}
#end

#if (DETAIL_LEVEL<5)
	#declare Deck_Texture = texture {Metallic_Hull_Plating_Ambient(ENTERPRISE_GRAY(40),0.6,0.4,0)}
	#declare Bulkhead_Texture = texture {Metallic_Hull_Plating_Ambient(ENTERPRISE_GRAY(70),0.6,0.4,0)}
#else
	#declare Deck_Texture = texture {Metallic_Hull_Plating(ENTERPRISE_GRAY(70),0.6,0.4,0)}
	#declare Bulkhead_Texture = texture {Metallic_Hull_Plating(ENTERPRISE_GRAY(90),0.6,0.4,0)}
#end

#macro Running_Light(rl_radius,rl_base_size,rl_red,rl_green,rl_blue,no_blink)
	#local rl_color = color rgbft <rl_red,rl_green,rl_blue,0.3,0.35>;
	// The following switch statement smoothly ramps up and 
	// down the brightness of the running light once per two seconds
	#if (no_blink=true)
		#local rl_brightness = 1;
	#else
		#if (ANIM_FRAMES_PER_SECOND=30)
			#switch(mod(frame_number-BLINK_PHASE,60))
				#range(0,1)
					#local rl_brightness = 1;
					#break
				#range(2,3)
					#local rl_brightness = 0.90;
					#break
				#range(4,5)
					#local rl_brightness = 0.80;
					#break
				#range(6,7)
					#local rl_brightness = 0.70;
					#break
				#range(8,9)
					#local rl_brightness = 0.60;
					#break
				#range(10,11)
					#local rl_brightness = 0.50;
					#break
				#range(12,13)
					#local rl_brightness = 0.40;
					#break
				#range(14,15)
					#local rl_brightness = 0.30;
					#break
				#range(15,16)
					#local rl_brightness = 0.20;
					#break
				#range(17,18)
					#local rl_brightness = 0.10;
					#break
				#range(19,39)
					#local rl_brightness = 0.00;
					#break
				#range(40,41)
					#local rl_brightness = 0.10;
					#break
				#range(42,43)
					#local rl_brightness = 0.20;
					#break
				#range(44,45)
					#local rl_brightness = 0.30;
					#break
				#range(46,47)
					#local rl_brightness = 0.40;
					#break
				#range(48,49)
					#local rl_brightness = 0.50;
					#break
				#range(50,51)
					#local rl_brightness = 0.60;
					#break
				#range(52,53)
					#local rl_brightness = 0.70;
					#break
				#range(54,55)
					#local rl_brightness = 0.80;
					#break
				#range(56,57)
					#local rl_brightness = 0.90;
					#break
				#range(58,59)
					#local rl_brightness = 1.00;
					#break
				#else
					#local rl_brightness = 1.00;
					#break
			#end
		#else
			#switch(mod(frame_number-BLINK_PHASE,48))
				#range(0,1)
					#local rl_brightness = 1;
					#break
				#range(2,3)
					#local rl_brightness = 0.90;
					#break
				#range(4,5)
					#local rl_brightness = 0.80;
					#break
				#range(6,7)
					#local rl_brightness = 0.70;
					#break
				#range(8,9)
					#local rl_brightness = 0.60;
					#break
				#range(10,11)
					#local rl_brightness = 0.50;
					#break
				#range(12,13)
					#local rl_brightness = 0.40;
					#break
				#range(14,15)
					#local rl_brightness = 0.30;
					#break
				#range(15,16)
					#local rl_brightness = 0.20;
					#break
				#range(17,18)
					#local rl_brightness = 0.10;
					#break
				#range(19,27)
					#local rl_brightness = 0.00;
					#break
				#range(28,29)
					#local rl_brightness = 0.10;
					#break
				#range(30,31)
					#local rl_brightness = 0.20;
					#break
				#range(32,33)
					#local rl_brightness = 0.30;
					#break
				#range(34,35)
					#local rl_brightness = 0.40;
					#break
				#range(36,37)
					#local rl_brightness = 0.50;
					#break
				#range(38,39)
					#local rl_brightness = 0.60;
					#break
				#range(40,41)
					#local rl_brightness = 0.70;
					#break
				#range(42,43)
					#local rl_brightness = 0.80;
					#break
				#range(44,45)
					#local rl_brightness = 0.90;
					#break
				#range(46,47)
					#local rl_brightness = 1.00;
					#break
				#else
					#local rl_brightness = 1.00;
					#break
			#end
		#end
	#end
	#if (NO_EXTERIOR_LIGHTS=true)
		#local rl_brightness=0;
	#end
	union {
		union {
			difference {
				sphere {
					<0,rl_radius/2,0>, rl_radius 
				}
				plane {y,0}                       
			} 
			cylinder {<0,0,0>,<0,rl_radius/2,0>,rl_radius}						
			texture {
				pigment {rl_color} 
				
				finish {
					specular 0.7*rl_brightness      
					roughness 0.1875*rl_brightness
					ambient 1*rl_brightness
				}
			}
		}
		light_source {
			y*(rl_radius*0.75)
			color rgb <rl_red*rl_brightness,rl_green*rl_brightness,rl_blue*rl_brightness>
			fade_distance rl_radius*3
			fade_power 5  
		} 
		torus {rl_radius,rl_radius*rl_base_size texture {Metallic_Hull_Plating(ENTERPRISE_GRAY(80),0.70,0.25,0.05)}}
	}
#end

// Basically a flattened running light:
#macro Beacon(rl_radius,rl_base_size,rl_red,rl_green,rl_blue,no_blink)

	#local rl_color = color rgbft <rl_red,rl_green,rl_blue,0.3,0.35>;
	// The following switch statement smoothly ramps up and 
	// down the brightness of the running light once per two seconds
	#if (no_blink=true)
		#local rl_brightness = 1;
	#else
		#if (ANIM_FRAMES_PER_SECOND=30)
			#switch(mod(frame_number-BLINK_PHASE,60))
				#range(0,1)
					#local rl_brightness = 1;
					#break
				#range(2,3)
					#local rl_brightness = 0.90;
					#break
				#range(4,5)
					#local rl_brightness = 0.80;
					#break
				#range(6,7)
					#local rl_brightness = 0.70;
					#break
				#range(8,9)
					#local rl_brightness = 0.60;
					#break
				#range(10,11)
					#local rl_brightness = 0.50;
					#break
				#range(12,13)
					#local rl_brightness = 0.40;
					#break
				#range(14,15)
					#local rl_brightness = 0.30;
					#break
				#range(15,16)
					#local rl_brightness = 0.20;
					#break
				#range(17,18)
					#local rl_brightness = 0.10;
					#break
				#range(19,39)
					#local rl_brightness = 0.00;
					#break
				#range(40,41)
					#local rl_brightness = 0.10;
					#break
				#range(42,43)
					#local rl_brightness = 0.20;
					#break
				#range(44,45)
					#local rl_brightness = 0.30;
					#break
				#range(46,47)
					#local rl_brightness = 0.40;
					#break
				#range(48,49)
					#local rl_brightness = 0.50;
					#break
				#range(50,51)
					#local rl_brightness = 0.60;
					#break
				#range(52,53)
					#local rl_brightness = 0.70;
					#break
				#range(54,55)
					#local rl_brightness = 0.80;
					#break
				#range(56,57)
					#local rl_brightness = 0.90;
					#break
				#range(58,59)
					#local rl_brightness = 1.00;
					#break
				#else
					#local rl_brightness = 1.00;
					#break
			#end
		#else
			#switch(mod(frame_number-BLINK_PHASE,48))
				#range(0,1)
					#local rl_brightness = 1;
					#break
				#range(2,3)
					#local rl_brightness = 0.90;
					#break
				#range(4,5)
					#local rl_brightness = 0.80;
					#break
				#range(6,7)
					#local rl_brightness = 0.70;
					#break
				#range(8,9)
					#local rl_brightness = 0.60;
					#break
				#range(10,11)
					#local rl_brightness = 0.50;
					#break
				#range(12,13)
					#local rl_brightness = 0.40;
					#break
				#range(14,15)
					#local rl_brightness = 0.30;
					#break
				#range(15,16)
					#local rl_brightness = 0.20;
					#break
				#range(17,18)
					#local rl_brightness = 0.10;
					#break
				#range(19,27)
					#local rl_brightness = 0.00;
					#break
				#range(28,29)
					#local rl_brightness = 0.10;
					#break
				#range(30,31)
					#local rl_brightness = 0.20;
					#break
				#range(32,33)
					#local rl_brightness = 0.30;
					#break
				#range(34,35)
					#local rl_brightness = 0.40;
					#break
				#range(36,37)
					#local rl_brightness = 0.50;
					#break
				#range(38,39)
					#local rl_brightness = 0.60;
					#break
				#range(40,41)
					#local rl_brightness = 0.70;
					#break
				#range(42,43)
					#local rl_brightness = 0.80;
					#break
				#range(44,45)
					#local rl_brightness = 0.90;
					#break
				#range(46,47)
					#local rl_brightness = 1.00;
					#break
				#else
					#local rl_brightness = 1.00;
					#break
			#end
		#end
	#end
	#if (NO_EXTERIOR_LIGHTS=true)
		#local rl_brightness=0;
	#end

	union {

		difference {

			sphere {<0,0,0>,rl_radius scale <1,0.5,1>}

			plane {y,0}                       

			texture {
				pigment {rl_color} 
				
				finish {
					specular 0.7*rl_brightness      
					roughness 0.1875*rl_brightness
					ambient 1*rl_brightness
				}
			}
		} 

		#if (NO_EXTERIOR_LIGHTS=false)
			light_source {			
				y*(rl_radius*.5)
				color rgb <rl_red*rl_brightness,rl_green*rl_brightness,rl_blue*rl_brightness>
				fade_distance rl_radius*3
				fade_power 5  
			} 
		#end

		// The ring around the base of the beacon:
		torus {rl_radius,rl_radius*rl_base_size texture {Metallic_Hull_Plating(ENTERPRISE_GRAY(80),0.70,0.25,0.05)}}
	}
#end

// This macro makes a cylinder capped by half-spheres at each end.
// Useful for making ribs!
#macro Rounded_Cylinder(rc_length,rc_radius)
	union {
		#local cylinder_length=rc_length-(rc_radius*2);
		cylinder {<0,0,-cylinder_length/2>,<0,0,cylinder_length/2>,rc_radius}
		sphere {<0,0,-cylinder_length/2>,rc_radius}
		sphere {<0,0,cylinder_length/2>,rc_radius}
	}
#end

#declare Impulse_Reactor_Texture =
	texture {
	    pigment {color rgb <0.658824, 0.658824, 0.658824> }
	    finish {
	        ambient 0
	        diffuse 0.7
	        reflection 0.15
	        brilliance 8
	        specular 0.8
	        roughness 0.1
	    }
	}

/*******************************************************************************
* Portholes and glass objects                                                  *
*******************************************************************************/
// Used at low detail levels. Simulates portholes with an ambient texture:
#declare Fake_Porthole_Glass_Texture =
	texture {
	    pigment {color rgb <0.7,0.7,0.5>}
	    finish {ambient 0.75}
	}

#declare Porthole_Glass_Texture=
	texture {
	    pigment {color rgbf <1,1,1,1>}
	    finish {
	        ambient 0
	        diffuse 0
	        reflection 0.5
	        phong 0.3
	        phong_size 60
	    }
	}

#declare Porthole_Glass_Interior =
	interior {
		ior 1.5
		fade_power 2
		fade_distance 5
		fade_color <1,1,0.95>
	}

// At low detail levels, use fake glass:
#if (DETAIL_LEVEL<3)
	#declare Porthole_Glass_Material = material {texture {Fake_Porthole_Glass_Texture}}
#else
	#declare Porthole_Glass_Material = material {texture {Porthole_Glass_Texture} interior {Porthole_Glass_Interior}}
#end

// This macro is used to difference out round portholes.
// porthole_orientation: 
// 1=x-axis (i.e., sides of ship)
// 2=y-axis (i.e., top or bottom of ship)
// 3=z-axis (i.e., front or back of ship)
#macro Round_Porthole(porthole_radius, porthole_orientation,porthole_depth)
	#switch (porthole_orientation)
		#case (1)
			cylinder {<porthole_depth/2,0,0>,<-porthole_depth/2,0,0>,porthole_radius}
			#break
		#case (2)
			cylinder {<0,porthole_depth/2,0>,<0,-porthole_depth/2,0>,porthole_radius}
			#break
		#case (3)
			cylinder {<0,0,porthole_depth/2>,<0,0,-porthole_depth/2>,porthole_radius}
			#break
	#end
#end

// This macro is used to difference out rectangular portholes with rounded edges.
// Porthole_orientation: 
// 1=x-axis (i.e., sides of ship)
// 2=y-axis (i.e., top or bottom of ship)
// 3=z-axis (i.e., front or back of ship)
#macro Rectangular_Porthole(porthole_width,porthole_height,porthole_orientation,porthole_depth)
	union {

		// If the porthole is too short or too narrow, 
		// reduce the standard 125mm corner radius to handle it:
		#local corner_radius=0.125;
		#if (porthole_width < porthole_height)
			#if (porthole_width < 0.25)
				#local corner_radius=porthole_width/2;
			#end
		#else
			#if (porthole_height < 0.25)
				#local corner_radius=porthole_height/2;
			#end
		#end


		#local width_translate=porthole_width/2-corner_radius;
		#local height_translate=porthole_height/2-corner_radius;
		
		// The four corners:
		cylinder {<porthole_depth/2,height_translate,width_translate>,<-porthole_depth/2,height_translate,width_translate>,corner_radius}
		cylinder {<porthole_depth/2,height_translate,-width_translate>,<-porthole_depth/2,height_translate,-width_translate>,corner_radius}
		cylinder {<porthole_depth/2,-height_translate,width_translate>,<-porthole_depth/2,-height_translate,width_translate>,corner_radius}
		cylinder {<porthole_depth/2,-height_translate,-width_translate>,<-porthole_depth/2,-height_translate,-width_translate>,corner_radius}
		
		// The vertical and horizontal sides:
		box {<porthole_depth/2,height_translate+corner_radius,width_translate>,<-porthole_depth/2,-height_translate-corner_radius,-width_translate>}
		box {<porthole_depth/2,height_translate,width_translate+corner_radius>,<-porthole_depth/2,-height_translate,-width_translate-corner_radius>}
		
		// Rotate to the requested orientation:
		#switch (porthole_orientation)
			#case (1)
				// Do nothing; default orientation IS x-axis
				#break
			#case (2)
				rotate z*90
				#break
			#case (3)
				rotate y*90
				#break
		#end		
	}
#end

#declare Sensor_Dome_Texture = 
	texture {
		pigment {color rgbt <1,1,0.9,0.45>} 
	    finish {
	    	#if (NO_INTERIOR_LIGHTS=true)
		        ambient 0
			#else
		        ambient 0.3
			#end
			diffuse 0.9
			brilliance 6.0
			reflection 0.5
			phong 0.4
			phong_size 250
	    }
	}

#declare Sensor_Dome_Interior =
	interior {
		ior 5
		fade_distance 0.5
		fade_power 1001
		fade_color rgb <1,1,0.9>
	}
	
#declare Sensor_Dome_Material =
	material {texture {Sensor_Dome_Texture} interior {Sensor_Dome_Interior}}

/************************ Macros picked up on the Internet ***********************/
#macro Matrix(mv_X,mv_Y,mv_Z,mv_L)
matrix <(mv_X).x,(mv_X).y,(mv_X).z,(mv_Y).x,(mv_Y).y,(mv_Y).z,(mv_Z).x,(mv_Z).y,(mv_Z).z,(mv_L).x,(mv_L).y,(mv_L).z >
#end

#macro Beveled_Cylinder(Start,End,MajorRadius,MinorRadius)
  #local pS=<0,0,0>+Start;
  #local pE=<0,0,0>+End;
  #local sJ=MajorRadius;
  #local sN=MinorRadius;
  #local vY=vnormalize(pE-pS);
  #local vX=vnormalize(vcross(<vY.y,vY.z,-vY.x>,vY));
  #local vZ=vnormalize(vcross(vX,vY));
  
  cylinder { pS,pE,sJ-sN }
  cylinder { pS+vY*sN,pE-vY*sN,sJ }
  torus { sJ-sN,sN translate  y*sN Matrix(vX,vY,vZ,pS) }
  torus { sJ-sN,sN translate -y*sN Matrix(vX,vY,vZ,pE) }
#end

// This is the flat part at the bottom of the lower primary hull directly above the lower
// sensor platform. It is also the bottom of Deck 10: 
#macro Lower_Primary_Hull_1_Shell_Plate(spec)
	difference {
		cylinder {<0,-11.866,0>,<0,-11.616,0>,7.5748}
		plane {x,0 rotate y*360/56 inverse}
		plane {x,0 rotate y*-360/56}
		texture {
			spherical
			texture_map {
					[0.0          Metallic_Hull_Plating(ENTERPRISE_GRAY(60),0.78,0.22,0.00)]
					[0.125          Metallic_Hull_Plating(ENTERPRISE_GRAY(70),0.75,0.24,0.01)]
					[1.0          Metallic_Hull_Plating(ENTERPRISE_GRAY(80),0.73,0.26,0.01)]
			}
			scale <2,1,2>
			translate <0,-11,7.6>
		} 
		bounded_by {box {<-5,-12,8>,<5,-11,0>}}
	}
#end

#declare Lower_Primary_Hull_1_Outer_Hull = union {
	#local y_rot=0;    
	#while (y_rot<28)
		object {Lower_Primary_Hull_1_Shell_Plate(0.25) rotate y*((y_rot*360/28)+360/56)}
		#local y_rot=y_rot+1;
	#end
}    


// This is the first convex part at the bottom of the primary hull:
#macro Lower_Primary_Hull_2_Shell(outer_offset,inner_offset)
	intersection {
		
		difference {
			
			torus {7.5748,4.5+outer_offset}

			torus {7.5748,4.5+inner_offset}
			
			cylinder {<0,-100,0>,<0,100,0>,7.5748}

			translate y*-7.366
		}

		cone {<0,-7.366,0>,7.5748,<0,-16.9542,0>,10.415}
		
		bounded_by {box {<10,-10,10>,<-10,-12,-10>}}
	}		
#end

#macro Lower_Primary_Hull_2_Shell_Plate(spec)
	difference {
		object {Lower_Primary_Hull_2_Shell(0.00001,0)}
		plane {x,0 rotate y*360/56 inverse}
		plane {x,0 rotate y*-360/56}
		texture {
			spherical
			texture_map {
					[0.0          Metallic_Hull_Plating(ENTERPRISE_GRAY(60),0.78,0.22,0.00)]
					[0.125          Metallic_Hull_Plating(ENTERPRISE_GRAY(70),0.75,0.24,0.01)]
					[1.0          Metallic_Hull_Plating(ENTERPRISE_GRAY(80),0.73,0.26,0.01)]
			}
			scale <2,1,2>
			translate <0,-11,7.6>
		}
		bounded_by {box {<-5,-12,15>,<5,-10,0>}}
	}
#end

#declare Lower_Primary_Hull_2_Outer_Hull = union {
	object {Lower_Primary_Hull_2_Shell(0,-OUTER_HULL_THICKNESS)}
	#local y_rot=0;    
	#while (y_rot<28)
		object {Lower_Primary_Hull_2_Shell_Plate(0.25) rotate y*((y_rot*360/28)+360/56)}
		#local y_rot=y_rot+1;
	#end
}    

#declare Lower_Primary_Hull_2_Inner_Hull = object {Lower_Primary_Hull_2_Shell(-OUTER_HULL_THICKNESS-PORTHOLE_THICKNESS-0.001,-HULL_THICKNESS) texture {Bulkhead_Texture}}

// This is the next-outermost convex ring at the bottom of the primary hull,
// with an increased slope from Lower_Primary_Hull_2:
#macro Lower_Primary_Hull_3_Shell(outer_offset,inner_offset)
	intersection {
		
		difference {
			
			difference {
				
				torus {-8.188,60.0+outer_offset}
	
				torus {-8.188,60.0+inner_offset}
				
				translate y*45.8485
			}
			
			cone {<0,45.8485,0>,-8.188,<0,-16.9542,0>,10.415}
		}

		cone {<0,45.8485,0>,-8.188,<0,-12.5731,0>,20.3061}

		bounded_by {box {<20,-7,20>,<-20,-12,-20>}}
	}		
#end

#macro Lower_Primary_Hull_3_Shell_Plate(spec)
	difference {
		object {Lower_Primary_Hull_3_Shell(0.00001,0)}
		plane {x,0 rotate y*360/56 inverse}
		plane {x,0 rotate y*-360/56}
		texture {
			spherical
			texture_map {
					[0.0          Metallic_Hull_Plating(ENTERPRISE_GRAY(60),0.78,0.22,0.00)]
					[0.125          Metallic_Hull_Plating(ENTERPRISE_GRAY(70),0.75,0.24,0.01)]
					[1.0          Metallic_Hull_Plating(ENTERPRISE_GRAY(80),0.73,0.26,0.01)]
			}
			translate <0,-1,2.15>
			scale <2.5,8.25,6.5>
		}
		bounded_by {box {<6,-7,20>,<-6,-12,0>}}
	}
#end

#declare Lower_Primary_Hull_3_Outer_Hull = union {
	object {Lower_Primary_Hull_3_Shell(0,-OUTER_HULL_THICKNESS)}
	#local y_rot=0;    
	#while (y_rot<28)
		object {Lower_Primary_Hull_3_Shell_Plate(0.25) rotate y*((y_rot*360/28)+360/56)}
		#local y_rot=y_rot+1;
	#end
}    

#declare Lower_Primary_Hull_3_Inner_Hull = object {Lower_Primary_Hull_3_Shell(-OUTER_HULL_THICKNESS-PORTHOLE_THICKNESS-0.001,-HULL_THICKNESS) texture {Bulkhead_Texture}}

// This is the first convex ring that starts the scoopout of the primary hull:
#macro Lower_Primary_Hull_4_Shell(inner_offset,outer_offset)
  	difference {
  		
		intersection {
			
			difference {
				
				torus {40.0328,50+inner_offset}
				torus {40.0328,50+outer_offset}
				translate y*-53.0188
			}
			
			cone {<0,-53.0188,0>,40.0328,<0,-0.422,0>,23.9524}
		}  
		
		cone {<0,-53.0188,0>,40.0328,<0,-3.5851,0>,15.9224}		
		plane {y,-53.0187}

		bounded_by {box {<26,-4,26>,<-26,-9,-26>}}
	}
#end

#macro Lower_Primary_Hull_4_Shell_Plate(outer_radius,inner_radius,tx_scale,tx_rotate,tx_translate,spec)
	intersection {
		difference {
			object {Lower_Primary_Hull_4_Shell(0,-0.00001)}
			plane {x,0 rotate y*360/56 inverse}
			plane {x,0 rotate y*-360/56}
		} 
		difference {
			cylinder {<0,0,0>,<0,-15,0>,outer_radius}
			cylinder {<0,1,0>,<0,-16,0>,inner_radius}
		}
		texture {
			spherical
			texture_map {
					[0.0          Metallic_Hull_Plating(ENTERPRISE_GRAY(60),0.78,0.22,0.00)]
					[0.125          Metallic_Hull_Plating(ENTERPRISE_GRAY(70),0.75,0.24,0.01)]
					[1.0          Metallic_Hull_Plating(ENTERPRISE_GRAY(80),0.73,0.26,0.01)]
			}
			scale tx_scale rotate tx_rotate translate tx_translate
		}
		bounded_by {box {<7,-4,26>,<-7,-9,11>}}
	}
#end

#declare Lower_Primary_Hull_4_Outer_Hull = union {
	object {Lower_Primary_Hull_4_Shell(OUTER_HULL_THICKNESS,0) texture {Metallic_Hull_Plating(ENTERPRISE_GRAY(80),0.75,0.24,0.01)}}
	#local y_rot=0;    
	#local y_rot=0;    
	#while (y_rot<28)
		object {Lower_Primary_Hull_4_Shell_Plate(28.5,0,<4.2,6.75,3>,<75,0,0>,<0,-5.2,21>,0.25) rotate y*((y_rot*360/28)+360/56)}
		#local y_rot=y_rot+1;
	#end
}    

#declare Lower_Primary_Hull_4_Inner_Hull = object {Lower_Primary_Hull_4_Shell(HULL_THICKNESS,HULL_THICKNESS-INNER_HULL_THICKNESS+0.001) texture {Bulkhead_Texture}}

// This is the second convex ring that increases the scoopout of the primary hull:
#macro Lower_Primary_Hull_5_Shell(inner_offset,outer_offset)
  	difference {
  		
		intersection {
			
			difference {
				
				torus {57.5751,110+inner_offset}
				torus {57.5751,110+outer_offset}
				translate y*-110.3971
			}
			
			cone {<0,-110.3971,0>,57.5751,<0,1.1869,0>,29.7541}
		}  
		
		cone {<0,-110.3971,0>,57.5751,<0,-0.4221,0>,23.9524}		
		plane {y,-6}

		bounded_by {box {<32,-3,32>,<-32,-6,-32>}}
	}
#end

#macro Lower_Primary_Hull_5_Shell_Plate(outer_radius,inner_radius,tx_scale,tx_rotate,tx_translate,spec)
	intersection {
		difference {
			object {Lower_Primary_Hull_5_Shell(0,-0.00001)}
			plane {x,0 rotate y*360/56 inverse}
			plane {x,0 rotate y*-360/56}
		} 
		difference {
			cylinder {<0,0,0>,<0,-15,0>,outer_radius}
			cylinder {<0,1,0>,<0,-16,0>,inner_radius}
		}
		texture {
			spherical
			texture_map {
					[0.0          Metallic_Hull_Plating(ENTERPRISE_GRAY(60),0.78,0.22,0.00)]
					[0.125          Metallic_Hull_Plating(ENTERPRISE_GRAY(70),0.75,0.24,0.01)]
					[1.0          Metallic_Hull_Plating(ENTERPRISE_GRAY(80),0.71,0.28,0.01)]
			}
			scale tx_scale rotate tx_rotate translate tx_translate
		}
		bounded_by {box {<7,-3,outer_radius+1>,<-7,-6,inner_radius-2>}}
	}
#end

#declare Lower_Primary_Hull_5_Outer_Hull = union {
	object {Lower_Primary_Hull_5_Shell(OUTER_HULL_THICKNESS,0) texture {Metallic_Hull_Plating(ENTERPRISE_GRAY(80),0.75,0.24,0.01)}}
	#local y_rot=0;    
	#local y_rot=0;    

	#while (y_rot<28)
		object {Lower_Primary_Hull_5_Shell_Plate(31,28.75,<5.25,2,2>,<0,0,0>,<0,-5,30>,0.25) rotate y*((y_rot*360/28)+360/56)}
		object {Lower_Primary_Hull_5_Shell_Plate(28.5,20,<4.75,2,2>,<0,0,0>,<0,-5.5,27>,0.25) rotate y*((y_rot*360/28)+360/56)}
		#local y_rot=y_rot+1;
	#end
}    

#declare Lower_Primary_Hull_5_Inner_Hull = object {Lower_Primary_Hull_5_Shell(HULL_THICKNESS,HULL_THICKNESS-INNER_HULL_THICKNESS+0.001) texture {Bulkhead_Texture}}

// This is the third and largest convex ring that forms the 
// large part of the scoopout of the lower primary hull:
#macro Lower_Primary_Hull_6_Shell(inner_offset,outer_offset)
  	difference {
  		
		intersection {
			
			difference {
				
				torus {43.0598,50+inner_offset}
				torus {43.0598,50+outer_offset}
				translate y*-52.1794
			}
			
			cone {<0,-52.1794,0>,43.0598,<0,2.1658,0>,51.5214}
		}  
		
		cone {<0,-52.1794,0>,43.0598,<0,1.1869,0>,29.7541}		
		plane {y,-52.1793}
		
		bounded_by {box {<52,-4,52>,<-52,0,-52>}}
	}
#end

#macro Lower_Primary_Hull_6_Shell_Plate(outer_radius,inner_radius,tx_scale,tx_rotate,tx_translate,spec)
	intersection {
		difference {
			object {Lower_Primary_Hull_6_Shell(0,-0.00001)}
			plane {x,0 rotate y*360/56 inverse}
			plane {x,0 rotate y*-360/56}
		} 
		difference {
			cylinder {<0,0,0>,<0,-15,0>,outer_radius}
			cylinder {<0,1,0>,<0,-16,0>,inner_radius}
		}
		texture {
			spherical
			texture_map {
					[0.0          Metallic_Hull_Plating(ENTERPRISE_GRAY(60),0.78,0.22,0.00)]
					[0.125          Metallic_Hull_Plating(ENTERPRISE_GRAY(70),0.75,0.24,0.01)]
					[1.0          Metallic_Hull_Plating(ENTERPRISE_GRAY(80),0.73,0.26,0.01)]
			}
			scale tx_scale rotate tx_rotate translate tx_translate
		}
		bounded_by {box {<9,-4,outer_radius+1>,<-9,0,inner_radius-3>}}
	}
#end

#declare Lower_Primary_Hull_6_Outer_Hull = union {
	object {Lower_Primary_Hull_6_Shell(OUTER_HULL_THICKNESS,0) texture {Metallic_Hull_Plating(ENTERPRISE_GRAY(80),0.75,0.24,0.01)}}
	#local y_rot=0;    
	#local y_rot=0;    
	#while (y_rot<28)
		object {Lower_Primary_Hull_6_Shell_Plate(52,43,<7.5,6,7>,<0,0,0>,<0,0,47.5>,0.25) rotate y*((y_rot*360/28)+360/56)}
		object {Lower_Primary_Hull_6_Shell_Plate(43,36,<6,6,6>,<0,0,0>,<0,-1,39.5>,0.25) rotate y*((y_rot*360/28)+360/56)}
		object {Lower_Primary_Hull_6_Shell_Plate(36,30,<5,5,3.75>,<0,0,0>,<0,-3,33.5>,0.25) rotate y*((y_rot*360/28)+360/56)}
		#local y_rot=y_rot+1;
	#end
}    

#declare Lower_Primary_Hull_6_Inner_Hull = object {Lower_Primary_Hull_6_Shell(HULL_THICKNESS,HULL_THICKNESS-INNER_HULL_THICKNESS+0.001) texture {Bulkhead_Texture}}

// This is the outermost sloping part of the lower primary hull:
#macro Lower_Primary_Hull_7_Shell(outer_offset,inner_offset)
  	difference {
  		
		intersection {
			
			difference {
				
				torus {58.4446,50+outer_offset}
				torus {58.4446,50+inner_offset}
				translate y*46.63
			}
			
			cylinder {<0,200,0>,<0,-200,0>,58.4446}
		}  
		
		cone {<0,46.63,0>,58.4446,<0,-7.7152,0>,49.983}		
		plane {y,46.62 inverse}
		
		bounded_by {box {<60,-1,60>,<-60,-4,-60>}}
	}
#end

#macro Lower_Primary_Hull_7_Shell_Plate(spec)
	difference {
		object {Lower_Primary_Hull_7_Shell(0.00001,0)}
		plane {x,0 rotate y*360/56 inverse}
		plane {x,0 rotate y*-360/56}
		texture {
			spherical
			texture_map {
				[0.0          Metallic_Hull_Plating(ENTERPRISE_GRAY(60),0.78,0.22,0.00)]
				[0.125          Metallic_Hull_Plating(ENTERPRISE_GRAY(70),0.75,0.24,0.01)]
				[1.0          Metallic_Hull_Plating(ENTERPRISE_GRAY(80),0.73,0.26,0.01)]
			}
			scale <7.8,6,9> rotate x*0 translate <0,-1,55.5>
		}
		bounded_by {box {<10,-1,60>,<-10,-4,50>}}
	}
#end

#declare Lower_Primary_Hull_7_Outer_Hull = union {
	object {Lower_Primary_Hull_7_Shell(0,-OUTER_HULL_THICKNESS) texture {Metallic_Hull_Plating(ENTERPRISE_GRAY(80),0.75,0.24,0.01)}}
	#local y_rot=0;    
	#while (y_rot<28)
		object {Lower_Primary_Hull_7_Shell_Plate(0.25) rotate y*((y_rot*360/28)+360/56)}
		#local y_rot=y_rot+1;
	#end
}    

#declare Lower_Primary_Hull_7_Inner_Hull = object {Lower_Primary_Hull_7_Shell(-HULL_THICKNESS+INNER_HULL_THICKNESS-0.001,-HULL_THICKNESS) texture {Bulkhead_Texture}}

// This is the narrow flat part at the outermost edge of the lower primary hull,
// where the lower primary hull meets the primary hull rim:
#declare Lower_Primary_Hull_8_Outer_Hull = difference {
	cylinder {<0,-3.37,0>,<0,-3.12,0>,59.9446}
	cylinder {<0,-4,0>,<0,-3,0>,58.4446}
	texture {
		radial
		texture_map {
			[0.0 Metallic_Hull_Plating(ENTERPRISE_GRAY(80),0.73,0.26,0.01)]						
			[0.49 Metallic_Hull_Plating(ENTERPRISE_GRAY(70),0.75,0.24,0.0)]						
			[0.5 Metallic_Hull_Plating(ENTERPRISE_GRAY(60),0.78,0.22,0.0)]						
			[0.51 Metallic_Hull_Plating(ENTERPRISE_GRAY(70),0.75,0.24,0.0)]						
			[1.0 Metallic_Hull_Plating(ENTERPRISE_GRAY(80),0.73,0.26,0.01)]						
		}
		frequency 28
		rotate y*360/56
	}
}

// This is the lower rounded lip of the primary hull rim:
#macro Primary_Hull_Rim_1_Shell(outer_offset,inner_offset,use_textures)
	intersection {
		
		difference {
			
			difference {
				
				torus {59.9446,1.5+outer_offset}
	
				torus {59.9446,1.5+inner_offset}
				
				translate y*-1.87
			}
			
			cylinder {<0,5,0>,<0,-5,0>,59.9446}
		}

		cone {<0,-1.87,0>,59.9446,<0,-3.7479,0>,63.4764}

		bounded_by {box {<62,-4,62>,<-62,-2,-62>}}

		#if (use_textures=true)
			texture {
				radial
				texture_map {
					[0.0 Metallic_Hull_Plating(ENTERPRISE_GRAY(80),0.73,0.26,0.01)]						
					[0.49 Metallic_Hull_Plating(ENTERPRISE_GRAY(70),0.75,0.24,0.0)]						
					[0.5 Metallic_Hull_Plating(ENTERPRISE_GRAY(60),0.78,0.22,0.0)]						
					[0.51 Metallic_Hull_Plating(ENTERPRISE_GRAY(70),0.75,0.24,0.0)]						
					[1.0 Metallic_Hull_Plating(ENTERPRISE_GRAY(80),0.73,0.26,0.01)]						
				}
				frequency 28
				rotate y*360/56
			}
		#end
	}		
#end

#declare Primary_Hull_Rim_1_Outer_Hull = object {Primary_Hull_Rim_1_Shell(0,-OUTER_HULL_THICKNESS,true)}
#declare Primary_Hull_Rim_1_Inner_Hull = object {Primary_Hull_Rim_1_Shell(-OUTER_HULL_THICKNESS-PORTHOLE_THICKNESS-0.001,-HULL_THICKNESS,false) texture {Bulkhead_Texture}}

// This is the sloped middle part of the primary hull rim:
#macro Primary_Hull_Rim_2_Shell(apply_texture,inner_texture)
	intersection {
		
		difference {
		
			cone {<0,1.9227,0>,63.66,<0,-2.5742,0>,61.269}
		
			cone {
				<0,2.6531,0>,63.7653,<0,-2.8983,0>,60.8136
				#if (apply_texture=true)
					texture {inner_texture}
				#end
			}
		}
		
		cone {<0,6.3475,0>,54.6870,<0,-5.3893,0>,76.7607}

		bounded_by {box {<64,3,64>,<-64,-3,-64>}}
	}
#end

// This is the upper rounded lip of the primary hull rim:
#macro Primary_Hull_Rim_3_Shell(outer_offset,inner_offset,use_textures)
	difference {
		
		difference {
			
			torus {63.075,0.5+outer_offset}

			torus {63.075,0.5+inner_offset}
			
			translate y*1.8875
		}
		
		cylinder {<0,5,0>,<0,-5,0>,63.075}
		
		cone {<0,6.3475,0>,54.6870,<0,-5.3893,0>,76.7607}

		bounded_by {box {<64,1,64>,<-64,4,-64>}}
		
		#if (use_textures=true)
			texture {
				radial
				texture_map {
					[0.0 Metallic_Hull_Plating(ENTERPRISE_GRAY(80),0.73,0.26,0.01)]						
					[0.49 Metallic_Hull_Plating(ENTERPRISE_GRAY(70),0.75,0.24,0.0)]						
					[0.5 Metallic_Hull_Plating(ENTERPRISE_GRAY(60),0.78,0.22,0.0)]						
					[0.51 Metallic_Hull_Plating(ENTERPRISE_GRAY(70),0.75,0.24,0.0)]						
					[1.0 Metallic_Hull_Plating(ENTERPRISE_GRAY(80),0.73,0.26,0.01)]						
				}
				frequency 28
				rotate y*360/56
			}
		#end
	}
#end

#declare Primary_Hull_Rim_3_Outer_Hull = object {Primary_Hull_Rim_3_Shell(0,-OUTER_HULL_THICKNESS,true)}
#declare Primary_Hull_Rim_3_Inner_Hull = object {Primary_Hull_Rim_3_Shell(-OUTER_HULL_THICKNESS-PORTHOLE_THICKNESS-0.001,-HULL_THICKNESS,false) texture {Bulkhead_Texture}}

// This is the outermost sloping part of the upper primary hull:
#macro Upper_Primary_Hull_1_Shell(outer_offset,inner_offset)
	intersection {
		
		difference {
			
			difference {
				
				torus {63.075,400+outer_offset}
				torus {63.075,400+inner_offset}
				translate y*402.3875
			}
		
			cone {<0,402.3875,0>,63.075,<0,-1.9611,0>,40.1144}
			plane {y,5 inverse}
		}
	
		cylinder {<0,10,0>,<0,0,0>,63.075}		
		bounded_by {box {<64,5,64>,<-64,2,-64>}}
	}  
#end

#macro Upper_Primary_Hull_1_Shell_Plate(outer_radius,inner_radius,tx_scale,tx_rotate,tx_translate,spec)
	intersection {
		difference {
			object {Upper_Primary_Hull_1_Shell(0,-0.00001)}
			plane {x,0 rotate y*360/56 inverse}
			plane {x,0 rotate y*-360/56}
		} 
		difference {
			cylinder {<0,0,0>,<0,9.5,0>,outer_radius}
			cylinder {<0,-1,0>,<0,10,0>,inner_radius}
		}
		texture {
			spherical
			texture_map {
					[0.0          Metallic_Hull_Plating(ENTERPRISE_GRAY(60),0.78,0.22,0.00)]
					[0.125          Metallic_Hull_Plating(ENTERPRISE_GRAY(70),0.75,0.24,0.01)]
					[1.0          Metallic_Hull_Plating(ENTERPRISE_GRAY(80),0.73,0.26,0.01)]
			}
			scale tx_scale rotate tx_rotate translate tx_translate
		}
		bounded_by {box {<10,5,outer_radius+1>,<-10,2,inner_radius-2>}}
	}
#end

#macro Upper_Primary_Hull_1_Outer_Hull(apply_texturing)
	union {
		object {Upper_Primary_Hull_1_Shell(OUTER_HULL_THICKNESS,0) texture {Metallic_Hull_Plating(ENTERPRISE_GRAY(80),0.75,0.24,0.01)}}
		#if (apply_texturing=true)
			#local y_rot=0;    
			#local y_rot=0;    
			#while (y_rot<28)
				object {Upper_Primary_Hull_1_Shell_Plate(64.0,56.4,<8,8,8>,<0,0,0>,<0,3.0,59.7>,0.25) rotate y*((y_rot*360/28)+360/56)}
				object {Upper_Primary_Hull_1_Shell_Plate(56.4,49.2,<7.5,8,8>,<0,0,0>,<0,3.2,52.8>,0.25) rotate y*((y_rot*360/28)+360/56)}
				object {Upper_Primary_Hull_1_Shell_Plate(49.2,40.0,<7,8,8>,<0,0,0>,<0,3.5,44.9>,0.25) rotate y*((y_rot*360/28)+360/56)}
				#local y_rot=y_rot+1;
			#end
		#end
	}    
#end

#declare Upper_Primary_Hull_1_Inner_Hull = object {Upper_Primary_Hull_1_Shell(HULL_THICKNESS,HULL_THICKNESS-INNER_HULL_THICKNESS+0.001) texture {Bulkhead_Texture}}

// This is the next outermost sloping part of the upper primary hull:
#macro Upper_Primary_Hull_2_Shell(outer_offset,inner_offset)
	intersection {
		
		difference {
			
			difference {
				
				torus {42.5239,37.5+outer_offset}
				torus {42.5239,37.5+inner_offset}
				translate y*40.4705
			}
		
			cone {<0,40.4705,0>,42.5239,<0,-7.8258,0>,29.5829}
			plane {y,5 inverse}
		}
	
		cone {<0,402.3875,0>,63.075,<0,-1.9611,0>,40.1144}
		bounded_by {box {<42,5,42>,<-42,2,-42>}}
	}  
#end

#macro Upper_Primary_Hull_2_Shell_Plate(tx_scale,tx_rotate,tx_translate,spec)
	difference {
		object {Upper_Primary_Hull_2_Shell(0,-0.00001)}
		plane {x,0 rotate y*360/56 inverse}
		plane {x,0 rotate y*-360/56}
		texture {
			spherical
			texture_map {
					[0.0          Metallic_Hull_Plating(ENTERPRISE_GRAY(60),0.78,0.22,0.00)]
					[0.125          Metallic_Hull_Plating(ENTERPRISE_GRAY(70),0.75,0.24,0.01)]
					[1.0          Metallic_Hull_Plating(ENTERPRISE_GRAY(80),0.73,0.26,0.01)]
			}
			scale tx_scale rotate tx_rotate translate tx_translate
		}
		bounded_by {box {<8,5,42>,<-8,2,30>}}
	}
#end

#macro Upper_Primary_Hull_2_Outer_Hull(apply_texturing)
	union {
		object {
			Upper_Primary_Hull_2_Shell(OUTER_HULL_THICKNESS,0)
			#if (apply_texturing=true)
				texture {Metallic_Hull_Plating(ENTERPRISE_GRAY(80),0.75,0.24,0.01)}
			#end
		}
		#if (apply_texturing=true)
			#local y_rot=0;    
			#local y_rot=0;    
			#while (y_rot<28)
				object {Upper_Primary_Hull_2_Shell_Plate(<6.25,8,7.5>,<0,0,0>,<0,3.5,36.4>,0.25) rotate y*((y_rot*360/28)+360/56)}
				#local y_rot=y_rot+1;
			#end
		#end
	}    
#end

#declare Upper_Primary_Hull_2_Inner_Hull = object {Upper_Primary_Hull_2_Shell(HULL_THICKNESS,HULL_THICKNESS-INNER_HULL_THICKNESS+0.001) texture {Bulkhead_Texture}}

// This is the top of the upper primary hull:
#macro Upper_Primary_Hull_3_Shell(outer_offset,inner_offset)
	intersection {
		
		difference {
			
			sphere {<0,-118.231,0>,126.7999+outer_offset}

			sphere {<0,-118.231,0>,126.7999+inner_offset}

			plane {y,3}
		}

		cone {<0,-118.231,0>,0,<0,40.4705,0>,42.5239}
		
		bounded_by {box {<34,9,34>,<-34,3,-34>}}
	}		
#end

#macro Upper_Primary_Hull_3_Shell_Plate(outer_radius,inner_radius,tx_scale,tx_rotate,tx_translate,spec)
	intersection {
		difference {
			object {Upper_Primary_Hull_3_Shell(0.00001,0)}
			plane {x,0 rotate y*360/56 inverse}
			plane {x,0 rotate y*-360/56}
		} 
		difference {
			cylinder {<0,0,0>,<0,9.5,0>,outer_radius}
			cylinder {<0,-1,0>,<0,10,0>,inner_radius}
		}
		texture {
			spherical
			texture_map {
					[0.0          Metallic_Hull_Plating(ENTERPRISE_GRAY(60),0.78,0.22,0.00)]
					[0.125          Metallic_Hull_Plating(ENTERPRISE_GRAY(70),0.75,0.24,0.01)]
					[1.0          Metallic_Hull_Plating(ENTERPRISE_GRAY(80),0.73,0.26,0.01)]
			}
			scale tx_scale rotate tx_rotate translate tx_translate
		}
		bounded_by {box {<7,9,outer_radius+1>,<-7,3,inner_radius-2>}}
	}
#end

#macro Upper_Primary_Hull_3_Outer_Hull(apply_texturing)
	union {
		object {
			Upper_Primary_Hull_3_Shell(0,-OUTER_HULL_THICKNESS)
			#if (apply_texturing=true)
				texture {Metallic_Hull_Plating(ENTERPRISE_GRAY(80),0.75,0.24,0.01)}
			#end
		}
		#if (apply_texturing=true)
			#local y_rot=0;    
			#local y_rot=0;    
			#while (y_rot<28)
			 	object {Upper_Primary_Hull_3_Shell_Plate(33.0,24.6,<6.0,8,8>,<0,0,0>,<0,5.4,28.5>,0.25) rotate y*((y_rot*360/28)+360/56)}
				object {Upper_Primary_Hull_3_Shell_Plate(24.6,15.4,<5.5,8,8>,<0,0,0>,<0,7.0,20.0>,0.25) rotate y*((y_rot*360/28)+360/56)}
				object {Upper_Primary_Hull_3_Shell_Plate(15.4,12.5,<5.0,8,3>,<0,0,0>,<0,7.8,13.5>,0.25) rotate y*((y_rot*360/28)+360/56)}
				#local y_rot=y_rot+1;
			#end
		#end
	}    
#end

#declare Upper_Primary_Hull_3_Inner_Hull = object {Upper_Primary_Hull_3_Shell(-OUTER_HULL_THICKNESS-PORTHOLE_THICKNESS-0.001,-HULL_THICKNESS) texture {Bulkhead_Texture}}

// Used to texture the primary hull rim:
#macro Primary_Hull_Rim_Plate(hp_slice_angle,plate_texture,joint_texture)
	difference {
		cone {<0,1.6527,0>,63.5166,<0,-2.5741,0>,61.2691}
		cone {<0,1.6528,0>,63.5165,<0,-2.5742,0>,61.269}	// This is the actual outside wall
		plane {x,0 rotate y*-hp_slice_angle/2}
		plane {x,0 rotate y*hp_slice_angle/2 inverse}
		texture {
		  	quilted
			texture_map {
				[0.0 plate_texture]
				[1.0 joint_texture]
			}
			control0 0
			control1 0
			#local xz_scale=sin(radians(hp_slice_angle/2))*63.66*2;
			scale <xz_scale,4.227,xz_scale>
			translate <xz_scale/2,-2.5742,0>
		}
		bounded_by {box {<12,2.5,64>,<-12,-4,60>}}
	}
#end
                     

#declare Primary_Hull_Rim_Plating = union {
 
 	#local rotation_step=0;
 	#while (rotation_step<28)
		object {Primary_Hull_Rim_Plate(360/28, texture {Metallic_Hull_Plating(ENTERPRISE_GRAY(80),0.75,0.24,0.01)},texture {Metallic_Hull_Plating(ENTERPRISE_GRAY(0),0.90,0.10,0.00)}) rotate y*(rotation_step*(360/28)+(360/56))}
		#local rotation_step=rotation_step+1;
	#end
}

// Put the primary hull rim together:
#declare Primary_Hull_Rim_With_Holes = difference {

	union {
		union {
			object {Primary_Hull_Rim_1_Outer_Hull} 
			object {Primary_Hull_Rim_1_Inner_Hull} 
			object {Primary_Hull_Rim_2_Shell(true,texture {Bulkhead_Texture})}
			object {Primary_Hull_Rim_3_Outer_Hull} 
			object {Primary_Hull_Rim_3_Inner_Hull}
			
			texture {Metallic_Hull_Plating(ENTERPRISE_GRAY(80),0.75,0.22,0.03)} 
		}

		object {Primary_Hull_Rim_Plating}
	}

	// Punch out the rim portholes:	
	#if (NO_PORTHOLES=false)	

		// Array of windows at starboard aft:  
		object {Round_Porthole(0.3125,1,5) translate <61.5,-1.6375,0> rotate y*38.75}
		object {Round_Porthole(0.3125,1,5) translate <61.5,0.8625,0> rotate y*41.75}
		object {Rectangular_Porthole(1.5,0.725,1,5) translate <61.5,0.8625,0> rotate y*43.75}
		object {Rectangular_Porthole(1.5,0.725,1,5) translate <61.5,0.8625,0> rotate y*46.25}
		object {Round_Porthole(0.3125,1,5) translate <61.5,0.8625,0> rotate y*48.25}
		object {Round_Porthole(0.3125,1,5) translate <61.5,-1.6375,0> rotate y*48.25}
		object {Round_Porthole(0.3125,1,5) translate <61.5,0.8625,0> rotate y*49.75}
		object {Round_Porthole(0.3125,1,5) translate <61.5,-1.6375,0> rotate y*52.75}

		// Array of windows at port aft:  
		object {Round_Porthole(0.3125,1,5) translate <-61.5,-1.6375,0> rotate y*-38.75}
		object {Round_Porthole(0.3125,1,5) translate <-61.5,0.8625,0> rotate y*-41.75}
		object {Rectangular_Porthole(1.5,0.725,1,5) translate <-61.5,0.8625,0> rotate y*-43.75}
		object {Rectangular_Porthole(1.5,0.725,1,5) translate <-61.5,0.8625,0> rotate y*-46.25}
		object {Round_Porthole(0.3125,1,5) translate <-61.5,0.8625,0> rotate y*-48.25}
		object {Round_Porthole(0.3125,1,5) translate <-61.5,-1.6375,0> rotate y*-48.25}
		object {Round_Porthole(0.3125,1,5) translate <-61.5,0.8625,0> rotate y*-49.75}
		object {Round_Porthole(0.3125,1,5) translate <-61.5,-1.6375,0> rotate y*-52.75}

		// Array of windows at port foward:
		object {Round_Porthole(0.3125,1,5) translate <-61.5,-1.6375,0> rotate y*38.75}
		object {Rectangular_Porthole(1.5,0.725,1,5) translate <-61.5,0.8625,0> rotate y*41.25}
		object {Rectangular_Porthole(1.5,0.725,1,5) translate <-61.5,0.8625,0> rotate y*43.75}
		object {Rectangular_Porthole(1.5,0.725,1,5) translate <-61.5,0.8625,0> rotate y*46.25}
		object {Rectangular_Porthole(1.5,0.725,1,5) translate <-61.5,0.8625,0> rotate y*48.75}
		object {Rectangular_Porthole(1.5,0.725,1,5) translate <-61.5,-1.6375,0> rotate y*51.25}
		object {Round_Porthole(0.3125,1,5) translate <-61.5,0.8625,0> rotate y*53.75}
		
		// Array of windows at starboard foward:
		object {Round_Porthole(0.3125,1,5) translate <61.5,-1.6375,0> rotate y*-38.75}
		object {Rectangular_Porthole(1.5,0.725,1,5) translate <61.5,0.8625,0> rotate y*-41.25}
		object {Rectangular_Porthole(1.5,0.725,1,5) translate <61.5,0.8625,0> rotate y*-43.75}
		object {Rectangular_Porthole(1.5,0.725,1,5) translate <61.5,0.8625,0> rotate y*-46.25}
		object {Rectangular_Porthole(1.5,0.725,1,5) translate <61.5,0.8625,0> rotate y*-48.75}
		object {Rectangular_Porthole(1.5,0.725,1,5) translate <61.5,-1.6375,0> rotate y*-51.25}
		object {Round_Porthole(0.3125,1,5) translate <61.5,0.8625,0> rotate y*-53.75}
		
		// The three round portholes at the front of the saucer
		// These may *not* actually be portholes; they're positioned
		// just about where the deckplate for deck 6 goes...)
		object {Round_Porthole(0.625,3,3) translate <0,-1,62> rotate y*3 }
		object {Round_Porthole(0.625,3,3) translate <0,-1,62>}
		object {Round_Porthole(0.625,3,3) translate <0,-1,62> rotate y*-3}
	#end	
}

#declare Primary_Hull_Rim_Glass = difference {  
	
	// Scaling dimensions:
	#local hullOuter = 62.4;	                         // Average distance from the rim outer hull surface to the center of the primary hull
	#local glassOuter = 62.4-OUTER_HULL_THICKNESS;       // Average distance from the outer surface of the porthole glass to the center of the p.h.
	#local glassInner = glassOuter - PORTHOLE_THICKNESS; // The distance from the inner surface of the porthole glass to the center of the p.h.

	object {Primary_Hull_Rim_2_Shell(false,0) scale glassOuter/hullOuter}
	object {Primary_Hull_Rim_2_Shell(false,0) scale glassInner/hullOuter}
	
	plane {y,-2.5}
	plane {y,1.5 inverse}

	bounded_by {box {<64,1.5,64>,<-64,-2.5,-64>}}

	material {Porthole_Glass_Material}
}

// The "L" shaped hatches on the aft dorsal side of the hull. Use 1 for
// port and -1 for starboard:
#macro L_Hatch_Outline(port_or_starboard,line_offset,height_offset)
	prism {
		linear_sweep
		linear_spline
		0-height_offset,3+height_offset,7
		<(-3.4+line_offset)*port_or_starboard,-60.5-line_offset>,<(-10.9-line_offset)*port_or_starboard,-60.5-line_offset>,
		<(-10.9-line_offset)*port_or_starboard,-56.3+line_offset>,<(-7.5-line_offset)*port_or_starboard,-56.3+line_offset>,
		<(-7.5-line_offset)*port_or_starboard,-53.4+line_offset>,<(-3.4+line_offset)*port_or_starboard,-53.4+line_offset>,
		<(-3.4+line_offset)*port_or_starboard,-60.5-line_offset>
	}
#end

#declare L_Hatch_Port = intersection {
	object {Upper_Primary_Hull_1_Shell(0,-0.1)}	
	object {L_Hatch_Outline(1,-0.3,0)}
	translate y*-0.2
	texture {
	  	quilted
		texture_map {
			[0.0 Metallic_Hull_Plating(ENTERPRISE_GRAY(70),0.75,0.24,0.01)]
			[1.0 Metallic_Hull_Plating(ENTERPRISE_GRAY(25),0.80,0.20,0.00)]
		}
		control0 0
		control1 0
		scale 3
	}
}

#declare L_Hatch_Starboard = intersection {
	object {Upper_Primary_Hull_1_Shell(0,-0.1)}	
	object {L_Hatch_Outline(-1,-0.3,0)}
	translate y*-0.2
	texture {
	  	quilted
		texture_map {
			[0.0 Metallic_Hull_Plating(ENTERPRISE_GRAY(70),0.75,0.24,0.01)]
			[1.0 Metallic_Hull_Plating(ENTERPRISE_GRAY(25),0.80,0.20,0.00)]
		}
		control0 0
		control1 0
		scale 3
	}
}

// Put the outer upper primary hull together:
#macro Upper_Primary_Hull_1_With_Holes(apply_texturing)
	difference { 
	                                                       
		union {
			object {Upper_Primary_Hull_1_Outer_Hull(apply_texturing)} 
			difference {
				object {Upper_Primary_Hull_1_Inner_Hull} 
				plane {x,0 rotate y*10}
				plane {x,0 rotate y*-10 inverse}
			}
		}
		
		// Difference out the L-shaped hatches:
		object {L_Hatch_Outline(1,-0.4,0)}
		object {L_Hatch_Outline(-1,-0.4,0)}
		
		// Difference out the portholes on the dorsal side:
		#if (NO_PORTHOLES=false)
			object {Rectangular_Porthole(0.725,1.65,2,4) translate <-10.6,2.4,-53.3>}
			object {Rectangular_Porthole(0.725,1.65,2,4) translate <10.6,2.4,-53.3>}
			object {Rectangular_Porthole(3.0,4.0,2,4) translate <0,2.4,53.50> rotate y*-45}
			object {Rectangular_Porthole(3.0,4.0,2,4) translate <0,2.4,53.50> rotate y*45}
			object {Rectangular_Porthole(3.8,5.0,2,4) translate <0,2.4,57.25> rotate y*-135}
			object {Rectangular_Porthole(3.8,5.0,2,4) translate <0,2.4,57.25> rotate y*135}
		#end
	}
#end

#declare Upper_Primary_Hull_1_Glass = difference {
	
	object {Upper_Primary_Hull_1_Shell(HULL_THICKNESS-INNER_HULL_THICKNESS,HULL_THICKNESS-INNER_HULL_THICKNESS-PORTHOLE_THICKNESS) material {Porthole_Glass_Material}}
	
	// Difference out the L-shaped hatches:
	object {L_Hatch_Outline(1,-0.4,0)}
	object {L_Hatch_Outline(-1,-0.4,0)}
}

// This is the little yellow hatch near the lower sensor array:
#declare Ventral_Yellow_Hatch_Outline = box {<18.7667,-12,-0.8>,<15.6167,0,0.8>}

// This is the dark gray hatch near the yellow hatch:
#declare Ventral_Gray60_Hatch_Outline = box {<23.4,-12,-0.875>,<20.9667,0,0.875> rotate y*4}

// This is the square gray/green hatch inside the innermost concentric ring:
#declare Ventral_Square_Inner_Hatch_Outline = box {<0.825,-12,18.75>,<-0.825,0,16.95> rotate y*12}

// This is the square gray hatch between the innermost and 2nd concentric rings:
#declare Ventral_Square_Outer_Hatch_Outline = box {<0.825,-12,22.4>,<-0.825,0,20.6> rotate y*6.5}

#declare Ventral_Yellow_Hatch = intersection {
	
	union {	
	 	object {Lower_Primary_Hull_3_Shell(0,-OUTER_HULL_THICKNESS)}
	 	object {Lower_Primary_Hull_4_Shell(OUTER_HULL_THICKNESS,0)}
	}
	
	object {Ventral_Yellow_Hatch_Outline}
	
	translate y*0.1
	
	texture {Metallic_Hull_Plating(ENTERPRISE_YELLOW,0.75,0.24,0.01)}
}

#declare Ventral_Gray60_Hatch = intersection {
	
	union {	
	 	object {Lower_Primary_Hull_3_Shell(0,-OUTER_HULL_THICKNESS)}
	 	object {Lower_Primary_Hull_4_Shell(OUTER_HULL_THICKNESS,0)}
	}
	
	object {Ventral_Gray60_Hatch_Outline}
	
	translate y*0.1
	
	texture {Metallic_Hull_Plating(ENTERPRISE_GRAY(60),0.75,0.24,0.01)}
}

#declare Ventral_Square_Inner_Hatch = intersection {
	
	union {	
	 	object {Lower_Primary_Hull_3_Shell(0,-OUTER_HULL_THICKNESS)}
	 	object {Lower_Primary_Hull_4_Shell(OUTER_HULL_THICKNESS,0)}
	}
	
	object {Ventral_Square_Inner_Hatch_Outline}
	
	translate y*0.1
	
	texture {Metallic_Hull_Plating(ENTERPRISE_DARKGREEN,0.75,0.24,0.01)}
}

#declare Ventral_Square_Outer_Hatch = intersection {
	
	union {	
	 	object {Lower_Primary_Hull_3_Shell(0,-OUTER_HULL_THICKNESS)}
	 	object {Lower_Primary_Hull_4_Shell(OUTER_HULL_THICKNESS,0)}
	}
	
	object {Ventral_Square_Outer_Hatch_Outline}
	
	translate y*0.1
	
	texture {Metallic_Hull_Plating(ENTERPRISE_GRAY(55),0.75,0.24,0.01)}
}

// This is the triangular indention on the underside of the saucer:
#declare Landing_Pad_Outer_Outline = intersection {
	prism {                                
		linear_sweep
		linear_spline
		-17,
		0,
		5,
		<-3.5381,30.3000>,<-0.8662,52.6000>,<0.8662,52.6000>,<3.5381,30.3000>,<-3.5381,30.3000>
	}
	difference {
		cylinder {<0,-15,0>,<0,0,0>,52.6}
		cylinder {<0,-16,0>,<0,1,0>,30.6}
	}
}

#declare Landing_Pad_Inner_Outline = intersection {
	prism {                                
		linear_sweep
		linear_spline
		-17,
		0,
		5,
		<-3.2000,30.6000>,<-0.6000,52.3000>,<0.6000,52.3000>,<3.2000,30.6000>,<-3.2000,30.6000>
	}
	difference {
		cylinder {<0,-15,0>,<0,0,0>,52.3}
		cylinder {<0,-16,0>,<0,1,0>,30.9}
	}
}

#declare Landing_Pad = intersection {
	
	union {	
	 	object {Lower_Primary_Hull_5_Shell(OUTER_HULL_THICKNESS,0)}
	 	object {Lower_Primary_Hull_6_Shell(OUTER_HULL_THICKNESS,0)}
		object {Lower_Primary_Hull_7_Shell(0,-OUTER_HULL_THICKNESS)}
	}
	
	object {Landing_Pad_Inner_Outline}
	
	translate y*0.1
	
	texture {
		spherical
		texture_map {
				[0.0          Metallic_Hull_Plating(ENTERPRISE_GRAY(40),0.78,0.22,0.00)]
				[1.0          Metallic_Hull_Plating(ENTERPRISE_GRAY(60),0.73,0.26,0.01)]
		}
		scale <2.5,1,12>
		translate <0,-3,40>
	}
}


// This is the little outdent next to the landing pad:
#declare Landing_Pad_Ring =	union {
	
	difference {
		
		torus {30.4,0.25}
		plane {x,0 rotate y*6.25 inverse}
		plane {x,0 rotate y*-6.25}
	}

	sphere {<0,0,0>,0.25 translate z*30.4 rotate y*6.25}
	sphere {<0,0,0>,0.25 translate z*30.4 rotate y*-6.25}
	
	texture {Metallic_Hull_Plating(ENTERPRISE_GRAY(75),0.75,0.24,0.01)}
	
	translate y*-3.9
}

// Put the lower primary hull together:
#declare Lower_Primary_Hull_3456_With_Holes = difference {

	union {
		object {Lower_Primary_Hull_3_Outer_Hull} 
		object {Lower_Primary_Hull_3_Inner_Hull} 	
		object {Lower_Primary_Hull_4_Outer_Hull} 
		object {Lower_Primary_Hull_4_Inner_Hull} 	
		object {Lower_Primary_Hull_5_Inner_Hull} 	
		object {Lower_Primary_Hull_5_Outer_Hull} 
		object {Lower_Primary_Hull_6_Outer_Hull} 
		object {Lower_Primary_Hull_6_Inner_Hull} 	
	}
	  
	// Difference out the three concentric rings around the lower sensor array:
	torus {19.6,0.25 translate y*-7.53 texture {Metallic_Hull_Plating(ENTERPRISE_GRAY(70),0.75,0.24,0.1)}}
	torus {24.1,0.25 translate y*-5.76 texture {Metallic_Hull_Plating(ENTERPRISE_GRAY(70),0.75,0.24,0.1)}}
	torus {28.6,0.25 translate y*-4.42 texture {Metallic_Hull_Plating(ENTERPRISE_GRAY(70),0.75,0.24,0.1)}}

	// Difference out the "landing pads" (the elongated triangular markings):
	object {Landing_Pad_Inner_Outline rotate y*59.5}
	object {Landing_Pad_Inner_Outline rotate y*-59.5}

	// Difference out the hatches:
	object {Ventral_Yellow_Hatch_Outline}
	object {Ventral_Gray60_Hatch_Outline}
	object {Ventral_Square_Inner_Hatch_Outline}
	object {Ventral_Square_Outer_Hatch_Outline}
	
	// Difference out the portholes (the rings referred to below
	// are the concentric indentions around the lower sensor array):
	#if (NO_PORTHOLES=false)
	
		// Forward portholes inside ring 1:
		object {Round_Porthole(0.3125,2,2) translate <0,-8.59,16.9577> rotate y*41}
		object {Rectangular_Porthole(1.75,0.85,2,2) rotate <0,90,0> translate <0,-7.9392,18.3996> rotate y*28}
		object {Rectangular_Porthole(1.75,0.85,2,2) rotate <0,90,0> translate <0,-7.9392,18.3996> rotate y*20}
		object {Rectangular_Porthole(1.75,0.85,2,2) rotate <0,90,0> translate <0,-7.9392,18.3996> rotate y*4}
		object {Rectangular_Porthole(1.75,0.85,2,2) rotate <0,90,0> translate <0,-7.9392,18.3996> rotate y*-4}
		object {Rectangular_Porthole(1.75,0.85,2,2) rotate <0,90,0> translate <0,-7.9392,18.3996> rotate y*-12}
		object {Rectangular_Porthole(1.75,0.85,2,2) rotate <0,90,0> translate <0,-7.9392,18.3996> rotate y*-20}

		// Forward portholes between rings 1 & 2:
		object {Round_Porthole(0.3125,2,2) translate <0,-6.8446,21.0698> rotate y*48}
		object {Round_Porthole(0.3125,2,2) translate <0,-6.8446,21.0698> rotate y*0}
		object {Round_Porthole(0.3125,2,2) translate <0,-6.8446,21.0698> rotate y*11}
		object {Rectangular_Porthole(1.75,0.85,2,2) rotate <0,90,0> translate <0,-6.8446,21.0698> rotate y*-5.5}
		
		// Forward porthole between rings 2 & 3:
		object {Round_Porthole(0.3125,2,2) translate <0,-5.2292,25.8283> rotate y*-10}
		
		// Starboard portholes inside ring 1:
		object {Rectangular_Porthole(1.75,0.85,2,2) rotate <0,90,0> translate <0,-7.9392,18.3996> rotate y*74}
		object {Rectangular_Porthole(1.75,0.85,2,2) rotate <0,90,0> translate <0,-7.9392,18.3996> rotate y*82}
		object {Rectangular_Porthole(1.75,0.85,2,2) rotate <0,90,0> translate <0,-7.9392,18.3996> rotate y*98}
		object {Rectangular_Porthole(1.75,0.85,2,2) rotate <0,90,0> translate <0,-7.9392,18.3996> rotate y*106}
		object {Round_Porthole(0.3125,2,2) translate <0,-7.9392,18.3996> rotate y*122}

		// Starboard portholes between rings 1 & 2:
		object {Rectangular_Porthole(1.75,0.85,2,2) rotate <0,90,0> translate <0,-6.8446,21.0698> rotate y*85}
		object {Round_Porthole(0.3125,2,2) translate <0,-6.8446,21.0698> rotate y*115}


		// Starboard portholes between rings 2 & 3:
		object {Round_Porthole(0.3125,2,2) translate <0,-5.2292,25.8283> rotate y*122}
		object {Round_Porthole(0.3125,2,2) translate <0,-5.2292,25.8283> rotate y*130}
		
		// Port portholes inside ring 1:
		object {Rectangular_Porthole(1.75,0.85,2,2) rotate <0,90,0> translate <0,-7.9392,18.3996> rotate y*-74}
		object {Rectangular_Porthole(1.75,0.85,2,2) rotate <0,90,0> translate <0,-7.9392,18.3996> rotate y*-82}
		object {Rectangular_Porthole(1.75,0.85,2,2) rotate <0,90,0> translate <0,-7.9392,18.3996> rotate y*-90}
		object {Rectangular_Porthole(1.75,0.85,2,2) rotate <0,90,0> translate <0,-7.9392,18.3996> rotate y*-98}
		object {Rectangular_Porthole(1.75,0.85,2,2) rotate <0,90,0> translate <0,-7.9392,18.3996> rotate y*-106}
		
		// Port portholes between rings 1 & 2:
		object {Rectangular_Porthole(1.75,0.85,2,2) rotate <0,90,0> translate <0,-6.8446,21.0698> rotate y*-83}
		object {Rectangular_Porthole(1.75,0.85,2,2) rotate <0,90,0> translate <0,-6.8446,21.0698> rotate y*-97}
		
		// Aft portholes inside ring 1:
		object {Round_Porthole(0.3125,2,2) translate <0,-7.9392,18.3996> rotate y*-176}
		object {Round_Porthole(0.3125,2,2) translate <0,-7.9392,18.3996> rotate y*-184}

	#end
}
 
#declare Lower_Primary_Hull_345_Glass = difference {

	intersection {
		
		union {
		
			object {Lower_Primary_Hull_3_Shell(-OUTER_HULL_THICKNESS-0.001,-OUTER_HULL_THICKNESS-PORTHOLE_THICKNESS)}
		 	object {Lower_Primary_Hull_4_Shell(OUTER_HULL_THICKNESS+PORTHOLE_THICKNESS,OUTER_HULL_THICKNESS+0.001)}
		 	object {Lower_Primary_Hull_5_Shell(OUTER_HULL_THICKNESS+PORTHOLE_THICKNESS,OUTER_HULL_THICKNESS+0.001)}
		}
	
		// This keeps the glass from intruding into the area where the landing pads are located: 
		cylinder {<0,-20,0>,<0,0,0>,30}
	}

	// Cut out the area occupied by the hatches:	
	object {Ventral_Yellow_Hatch_Outline}
	object {Ventral_Gray60_Hatch_Outline}
	object {Ventral_Square_Inner_Hatch_Outline}
	object {Ventral_Square_Outer_Hatch_Outline}
	
	material {Porthole_Glass_Material}
}

// Put the outermost sloping part of the lower primary hull together:
#declare Lower_Primary_Hull_7_With_Holes = difference {

	union {
		object {Lower_Primary_Hull_7_Outer_Hull} 
		object {Lower_Primary_Hull_7_Inner_Hull} 	
	}

	// Difference out the "landing pads" (the elongated triangular markings):
	object {Landing_Pad_Inner_Outline rotate y*59.5}
	object {Landing_Pad_Inner_Outline rotate y*-59.5}
	
	// Difference out the three portholes at aft port and aft starboard
	// (not sure if these ARE portholes yet, but will treat them as 
	// such for now)
	#if (NO_PORTHOLES=false)
		object {Round_Porthole(0.625,2,2) translate <0,-3.3,57.6> rotate y*108}
		object {Round_Porthole(0.625,2,2) translate <0,-3.3,57.6> rotate y*110}
		object {Round_Porthole(0.625,2,2) translate <0,-3.3,57.6> rotate y*112}
		object {Round_Porthole(0.625,2,2) translate <0,-3.3,57.6> rotate y*-108}
		object {Round_Porthole(0.625,2,2) translate <0,-3.3,57.6> rotate y*-110}
		object {Round_Porthole(0.625,2,2) translate <0,-3.3,57.6> rotate y*-112}
	#end
}

#declare Lower_Primary_Hull_7_Glass = difference {
	
	object {Lower_Primary_Hull_7_Shell(-OUTER_HULL_THICKNESS-0.001,-OUTER_HULL_THICKNESS-PORTHOLE_THICKNESS)}
	
	// This keeps the glass from intruding into the area where the landing pads are located: 
	cylinder {<0,-20,0>,<0,0,0>,53}
	
	material {Porthole_Glass_Material}
}

/*******************************************************************************
* Impulse Engines                                                              *
*******************************************************************************/
// We have to do this because texturing the dorsal and ventral surfaces of the
// cowling cause the aft end cap to have a funky, spotted texture:
#declare Impulse_Engine_Cap = difference {
	
	// Impulse cowling
	union {
	
		prism {                                
		  linear_sweep
		  linear_spline
		  -1.675,
   		   1.675,
          5,
		  <-16.8938,10.1548>,<-10.5,0>,<10.5,0>,<16.8938,10.1548>,<-16.8938,10.1548>
		}
		
		// The cylindrical edges are stretched 100% in the x-axis...
		cylinder {<-8.4469,0,10.1548>,<-5.25,0,0>,1.675 scale <2,1,1>}
		cylinder {<8.4469,0,10.1548>,<5.25,0,0>,1.675 scale <2,1,1>}
	}
	
	// Chop off all but a sliver of the aft end:
	plane {z,0}
	plane {z,0.1 inverse}
}


#declare Impulse_Engine_Cowling_Texture = texture {
	pigment {ENTERPRISE_GRAY(60)}
	finish {
	    ambient 0.05
	    brilliance 4
	    diffuse 0.75
	    metallic 0.5
	    specular 0.24
	    roughness 0.65
	    reflection 0.01
	}
	normal {
      bump_map {sys "wire_mesh.bmp" bump_size 5 use_index}
      translate <0.5,0.5,0>
      scale 1
      rotate x*90
	}
}

#declare Impulse_Engines = union {
	
	difference {

		union {

			difference {	
				
				// Impulse cowling
				union {
				
					prism {                                
					  linear_sweep
					  linear_spline
					  -1.675,
			   		   1.675,
			          5,
					  <-16.8938,10.1548>,<-10.5,0>,<10.5,0>,<16.8938,10.1548>,<-16.8938,10.1548>
					  texture {Metallic_Hull_Plating(ENTERPRISE_GRAY(80),0.75,0.24,0.01)}
					}
					
					// The cylindrical edges are stretched 100% in the x-axis...
					cylinder {<-8.4469,0,10.1548>,<-5.25,0,0>,1.675 scale <2,1,1> texture {Impulse_Engine_Cowling_Texture}}
					cylinder {<8.4469,0,10.1548>,<5.25,0,0>,1.675 scale <2,1,1> texture {Impulse_Engine_Cowling_Texture}}
				}
				
				// Chop off the ends to smooth out the cylindrical edges in the z-plane
				plane {z,0.1}
				plane {z,8 inverse}
			} 
			
			// Add the end cap:
			object {Impulse_Engine_Cap texture {Metallic_Hull_Plating(ENTERPRISE_GRAY(80),0.75,0.24,0.01)}}
		}

		// Cut out the exhaust ports
		box {<-2,1.25,-2>,<2,-1.25,2> texture {Impulse_Reactor_Texture} translate x*-4}
		box {<-2,1.25,-2>,<2,-1.25,2> texture {Impulse_Reactor_Texture} translate x*4}
		cylinder {<0,0,-2>,<0,0,2>,0.375 texture {Impulse_Reactor_Texture}}
	}
	
	// Add the engine glows
	#if (IMPULSE_POWER_PCT > 0)
		union {
			light_source {<-4,0,1> color <3,2,1>*(IMPULSE_POWER_PCT/100) fade_distance 20 fade_power 12}
			light_source {<4,0,1> color <3,2,1>*(IMPULSE_POWER_PCT/100)  fade_distance 20 fade_power 12}
			light_source {<0,0,1> color <0.25,0.25,0.5>  fade_distance 5 fade_power 5}
			bounded_by {sphere {0,75}}
		}
	#end
	
	// Add the exhaust grilles
	union {
		#local foo=1.5;
		#while (foo > -1.5)
			cylinder {<-7,foo,0.125>,<-2,foo,0.125>,0.125}
			#local foo = foo - 0.375;
		#end
		material {Porthole_Glass_Material}
	}		

	// Add the exhaust grilles
	union {
		#local foo=1.5;
		#while (foo > -1.5)
			cylinder {<2,foo,0.125>,<7,foo,0.125>,0.125}
			#local foo = foo - 0.375;
		#end
		material {Porthole_Glass_Material}
	}		
}       

/*******************************************************************************
* Running lights                                                               *
*******************************************************************************/
#declare Port_Dorsal_Running_Light =   
	object {Running_Light(1,0.25,1,0,0,false)}

#declare Starboard_Dorsal_Running_Light = 
	object {Running_Light(1,0.25,0,1,0,false)}

#declare Forward_Dorsal_Running_Light =   
	object {Running_Light(0.75,0.25,1,1,1,false)}

#declare Small_Port_Dorsal_Running_Light =   
	object {Running_Light(0.25,0.375,1,0,0,true)}

#declare Small_Port_Side_Running_Light =   
	object {Running_Light(0.25,0.375,1,1,1,false)}	

#declare Small_Starboard_Side_Running_Light =   
	object {Running_Light(0.25,0.375,1,1,1,false)}	

#declare Small_Starboard_Dorsal_Running_Light = 
	object {Running_Light(0.25,0.375,0,1,0,true)}

#declare Small_Forward_Dorsal_Running_Light = 
	object {Running_Light(0.25,0.375,1,1,1,true)}

#declare Port_Ventral_Running_Light =   
	object {Running_Light(1,0.25,1,1,1,false)}

#declare Starboard_Ventral_Running_Light =   
	object {Running_Light(1,0.25,1,1,1,false)}

/*******************************************************************************
* Ship's Registration and Markings                                             *
*******************************************************************************/
#declare Lower_Primary_Hull_Registration =
	text {
	  ttf
	  "SFAMUSAF.ttf",
	  "NCC-1701",
	  15,
	  <0.075,0,0>		// The characters are spaced a bit further apart than normal
	  scale <6,6,1>  
	}
	
#declare Upper_Primary_Hull_Registration_Shipname_Text =
	text {
	  ttf
	  "SFAMUSAF.ttf",
	  "U.S.S. ENTERPRISE",
	  10,
	  0
	  scale <5.54167,5.54167,1>  
	}

// This macro is for the "NCC-1701" text that has to be
// drawn, translated and rotated on the saucer one character
// at a time. AmarilloUSAF font scales at 1.66667:1, so to
// make the characters the correct height of 7.5 meters,
// the scaling factor s/b 12.5:
#macro Upper_Primary_Hull_Registration_BigText(srt_character)
	text {
	  ttf
	  "SFAMUSAF.ttf",
	  srt_character,
	  10,
	  0
	  scale <12.5,12.5,1>  
	}
#end

#declare Upper_Primary_Hull_Intersection_Object = union {

	object {Upper_Primary_Hull_1_With_Holes(false)} 
	object {Upper_Primary_Hull_2_Outer_Hull(false)} 
	object {Upper_Primary_Hull_3_Outer_Hull(false)}
}


// The x-axis translations in the Upper_Primary_Hull_Registration_BigText() macros are different
// for each character because the width for each character varies. x-axis translation
// is done such that each character is perfectly centered on its vertical axis.
#declare Upper_Primary_Hull_Registration = union {    
		
	intersection {
		object {Upper_Primary_Hull_Intersection_Object scale <1.0001,1.0001,1.0001> texture {Painted_Hull_Plating(ENTERPRISE_BLACK,0.75,0.22,0.03)}}	
		object {Upper_Primary_Hull_Registration_Shipname_Text rotate <90,180,0> translate <20,10,22>}
	} 
	
	intersection {
		object {Upper_Primary_Hull_Intersection_Object scale <1.0001,1.0001,1.0001> texture {Painted_Hull_Plating(ENTERPRISE_BLACK,0.75,0.22,0.03)}}
		object {Upper_Primary_Hull_Registration_BigText("N") rotate <90,180,0> translate <2.5,10,40> rotate y*39}
	}
	intersection {
		object {Upper_Primary_Hull_Intersection_Object scale <1.0001,1.0001,1.0001> texture {Painted_Hull_Plating(ENTERPRISE_BLACK,0.75,0.22,0.03)}}
		object {Upper_Primary_Hull_Registration_BigText("C") rotate <90,180,0> translate <2.5,10,40> rotate y*26}
	} 
	intersection {
		object {Upper_Primary_Hull_Intersection_Object scale <1.0001,1.0001,1.0001> texture {Painted_Hull_Plating(ENTERPRISE_BLACK,0.75,0.22,0.03)}}
		object {Upper_Primary_Hull_Registration_BigText("C") rotate <90,180,0> translate <2.5,10,40> rotate y*13}
	} 
	intersection {
		object {Upper_Primary_Hull_Intersection_Object scale <1.0001,1.0001,1.0001> texture {Painted_Hull_Plating(ENTERPRISE_BLACK,0.75,0.22,0.03)}}
		object {Upper_Primary_Hull_Registration_BigText("-") rotate <90,180,0> translate <1.9,10,40> rotate y*0}
	} 
	intersection {
		object {Upper_Primary_Hull_Intersection_Object scale <1.0001,1.0001,1.0001> texture {Painted_Hull_Plating(ENTERPRISE_BLACK,0.75,0.22,0.03)}}
		object {Upper_Primary_Hull_Registration_BigText("1") rotate <90,180,0> translate <0.7,10,40> rotate y*-12}
	} 
	intersection {
		object {Upper_Primary_Hull_Intersection_Object scale <1.0001,1.0001,1.0001> texture {Painted_Hull_Plating(ENTERPRISE_BLACK,0.75,0.22,0.03)}}
		object {Upper_Primary_Hull_Registration_BigText("7") rotate <90,180,0> translate <2.4,10,40> rotate y*-21}
	}
	intersection {
		object {Upper_Primary_Hull_Intersection_Object scale <1.0001,1.0001,1.0001> texture {Painted_Hull_Plating(ENTERPRISE_BLACK,0.75,0.22,0.03)}}
		object {Upper_Primary_Hull_Registration_BigText("0") rotate <90,180,0> translate <2.5,10,40> rotate y*-33}
	} 
	intersection {
		object {Upper_Primary_Hull_Intersection_Object scale <1.0001,1.0001,1.0001>}
		object {Upper_Primary_Hull_Registration_BigText("1") rotate <90,180,0> translate <0.7,10,40> rotate y*-42.5}
		texture {Painted_Hull_Plating(ENTERPRISE_BLACK,0.75,0.22,0.03)}
	}
}

#declare Lower_Primary_Hull_Intersection_Object = union {

 	object {Lower_Primary_Hull_4_Shell(0,-0.001)}
 	object {Lower_Primary_Hull_5_Shell(0,-0.001)}
 	object {Lower_Primary_Hull_6_Shell(0,-0.001)}
	object {Lower_Primary_Hull_7_Shell(0.001,0)}
}

#declare Lower_Primary_Hull_Port_Registration = intersection {
	
	object {Lower_Primary_Hull_Intersection_Object}
	
	object {Lower_Primary_Hull_Registration
		texture {Painted_Hull_Plating(ENTERPRISE_BLACK,0.75,0.22,0.03)}
		rotate <-90,0,0>
		translate <-54.9,-10,1.75>
	}
}

#declare Lower_Primary_Hull_Starboard_Registration = intersection {
	
	object {Lower_Primary_Hull_Intersection_Object}
	
	object {Lower_Primary_Hull_Registration
		texture {Painted_Hull_Plating(ENTERPRISE_BLACK,0.75,0.22,0.03)}
		rotate <-90,180,0>
		translate <54.9,-10,-1.75>
	}
}

// The red quarter-rings at the aft port and starboard ventral sides of the saucer section:
#declare Lower_Primary_Hull_Red_Quarter_Ring = intersection {

	object {Lower_Primary_Hull_Intersection_Object}
	
	difference {
		cylinder {<0,-100,0>,<0,100,0>,53}
		cylinder {<0,-101,0>,<0,101,0>,52.5}
		plane {x,0 rotate y*11 inverse}
		plane {x,0 rotate y*-11}
	}
	
	texture {Painted_Hull_Plating(ENTERPRISE_RED,0.75,0.22,0.03)}	
}

// The outline around the landing pads:
#declare Landing_Pad_Outline = intersection {
	
	object {Lower_Primary_Hull_Intersection_Object}
	
	difference {
		object {Landing_Pad_Outer_Outline}
		object {Landing_Pad_Inner_Outline scale <1,1.0001,1>}
	}

	texture {Metallic_Hull_Plating(ENTERPRISE_GRAY(40),0.75,0.22,0.03)}
}

// The gray outline around the L-shaped hatches:
#macro L_Hatch_Marking(port_or_starboard)
	intersection {
		
		object {Upper_Primary_Hull_1_Shell(0.0001,0)}	
		difference {
			object {L_Hatch_Outline(port_or_starboard,0,0.0001)}
			object {L_Hatch_Outline(port_or_starboard,-0.2,0.0002)}
		}
		
		translate y*0.0001
		texture {Painted_Hull_Plating(ENTERPRISE_GRAY(60),0.75,0.22,0.03)}
	}
#end 

// The little sign next to the dark gray inspection hatch on the port side:
#declare Port_Hatch_Sign = union {
	
	intersection {
		object {Lower_Primary_Hull_Intersection_Object}
		box {<20.9,-12,-0.75>,<20.1,0,0.75> rotate y*4}		
		texture {Metallic_Hull_Plating(ENTERPRISE_GOLD,0.3,0.3,0.4)}
	}
	
	intersection {
		object {Lower_Primary_Hull_Intersection_Object scale <1,1.0001,1>}		
		text {
			ttf
			"SFAMUSAF.ttf",
			"INSPECTION DOOR",
			15,
			0
			scale <0.2,0.2,1>
			rotate <-90,90,0>
			translate <20.325,-15,0.675>
		}
		
		rotate y*4
		texture {Metallic_Hull_Plating(ENTERPRISE_BLACK,0.8,0.2,0.0)}
	}

	intersection {
		object {Lower_Primary_Hull_Intersection_Object scale <1,1.0001,1>}		
		text {
			ttf
			"SFAMUSAF.ttf",
			"VENT SYSTEMS",
			15,
			0
			scale <0.2,0.2,1>
			rotate <-90,90,0>
			translate <20.55,-15,0.625>
		}
		
		rotate y*4
		texture {Metallic_Hull_Plating(ENTERPRISE_BLACK,0.8,0.2,0.0)}
	}

	intersection {
		object {Lower_Primary_Hull_Intersection_Object scale <1,1.0001,1>}		
		text {
			ttf
			"SFAMUSAF.ttf",
			"CONNECTIONS",
			15,
			0
			scale <0.2,0.2,1>
			rotate <-90,90,0>
			translate <20.775,-15,0.525>
		}
		
		rotate y*4
		texture {Metallic_Hull_Plating(ENTERPRISE_BLACK,0.8,0.2,0.0)}
	}
}

// The little sign next to the forward gray inspection hatch:
#declare Forward_Hatch_Sign = union {
	
	intersection {
		object {Lower_Primary_Hull_Intersection_Object}
		box {<-0.95,-12,20.5>,<0.95,0,20.1> rotate y*6.5}		
		texture {Metallic_Hull_Plating(ENTERPRISE_GOLD,0.3,0.3,0.4)}
	}
	
	intersection {
		object {Lower_Primary_Hull_Intersection_Object scale <1,1.0001,1>}		
		text {
			ttf
			"SFAMUSAF.ttf",
			"INSPECTION DOOR VENT",
			15,
			0
			scale <0.2,0.2,1>
			rotate <-90,180,0>
			translate <0.8875,-15,20.325>
		}
		
		rotate y*6.5
		texture {Metallic_Hull_Plating(ENTERPRISE_BLACK,0.8,0.2,0.0)}
	}

	intersection {
		object {Lower_Primary_Hull_Intersection_Object scale <1,1.0001,1>}		
		text {
			ttf
			"SFAMUSAF.ttf",
			"SYSTEMS CONNECTIONS",
			15,
			0
			scale <0.2,0.2,1>
			rotate <-90,180,0>
			translate <0.9125,-15,20.175>
		}
		
		rotate y*6.5
		texture {Metallic_Hull_Plating(ENTERPRISE_BLACK,0.8,0.2,0.0)}
	}
}

// The red pinstripes between the impulse engine wiring trunk and the command module:
#declare Dorsal_Red_Pinstripes = union {
	intersection {
		object {Upper_Primary_Hull_Intersection_Object scale <1.0001,1.0001,1.0001>}	
		box {<-0.4,0,-35>,<-0.6,10,-22.8>}
		texture {Painted_Hull_Plating(ENTERPRISE_RED,0.75,0.22,0.03)}
	}
	intersection {
		object {Upper_Primary_Hull_Intersection_Object scale <1.0001,1.0001,1.0001>}	
		box {<0.4,0,-35>,<0.6,10,-22.8>}
		texture {Painted_Hull_Plating(ENTERPRISE_RED,0.75,0.22,0.03)}
	}
} 

/*******************************************************************************
* Lower Sensor Array                                                           *
*******************************************************************************/ 
#declare Lower_Sensor_Array = union {

	// The outer rim around the silver ring:
	union {
		cylinder {<0,0.58125,0>,<0,0,0>,6.56875}
		torus {5.9875,0.58125 sturm}
		cylinder {<0,0,0>,<0,-0.58125,0>,5.9875}

		// The three little bumps around the rim:
		difference {
			union {
				object {Rounded_Cylinder(1.1625,0.25) rotate x*90 translate <0,0.25,6.56875> rotate y*0}
				object {Rounded_Cylinder(1.1625,0.25) rotate x*90 translate <0,0.25,6.56875> rotate y*120}
				object {Rounded_Cylinder(1.1625,0.25) rotate x*90 translate <0,0.25,6.56875> rotate y*240}
			}
			plane {y,0.58125 inverse}
		}

		texture {Metallic_Hull_Plating(ENTERPRISE_GRAY(80),0.73,0.24,0.03)}
	}
	
	
	// The silver ring around the dome:
	union {
		torus {4.5875,0.275 translate y*-0.58125 sturm}     
		cylinder {<0,-0.58125,0>,<0,-0.85625,0>,4.5875}
		texture {Metallic_Hull_Plating(ENTERPRISE_SILVER,0.73,0.24,0.03)}			
	}
	
	// Lower sensor dome:
	difference {
		sphere {<0,3.15625,0>,5.8625}
		sphere {<0,3.15625,0>,5.6125}	// Make it hollow
		sphere {<0,-2.09375,0>,1.0875}	// Cut out the area where the "nipple" is located
		plane {y,-0.85625 inverse}
		material {Sensor_Dome_Material}
	}

	// The "nipple" on the lower dome:
	difference {
		sphere {<0,-2.09375,0>,1.0875}
		sphere {<0,-2.09375,0>,0.8375}	// Make it hollow
		sphere {<0,3.15625,0>,5.6126}	// Cut out the area where the "nipple" meets the main dome
		material {Sensor_Dome_Material}
	} 
	
	// Light the lower dome:
	#if (NO_EXTERIOR_LIGHTS=false)
		union {
			#local foo=0;
			#while (foo<360)		
				light_source {
					<0,-1.9,0>
					color <1,1,0.9>
					fade_distance 5
					fade_power 1
					translate z*2
					rotate y*foo
				}
				#local foo=foo+60;
			#end
			bounded_by {sphere {0,75}}
		}
	#end
}

#declare Lower_Registration_Lightbar = union {
	
	union {
		
		#local bar_radius = 26.000;
		
		difference {
			
			torus {bar_radius,0.25}
			plane {x,0 rotate y*1 inverse}
			plane {x,0 rotate y*-1}
		}
	
		sphere {<0,0,0>,0.25 translate z*bar_radius rotate y*1}
		sphere {<0,0,0>,0.25 translate z*bar_radius rotate y*-1}
		
		texture {Metallic_Hull_Plating(ENTERPRISE_SILVER,0.3,0.3,0.4)}
		
		translate y*-4.9
	}

	merge {
		
		#local bar_radius = 26.125;
		
		difference {
			
			torus {bar_radius,0.125}
			plane {x,0 rotate y*0.5 inverse}
			plane {x,0 rotate y*-0.5}
		}
	
		sphere {<0,0,0>,0.125 translate z*bar_radius rotate y*0.5}
		sphere {<0,0,0>,0.125 translate z*bar_radius rotate y*-0.5}
		
		#if (NO_EXTERIOR_LIGHTS=true)
			texture {Metallic_Hull_Plating(ENTERPRISE_GRAY(75),0.3,0.3,0.4)}
		#else					
			texture {
				pigment {color rgb 1} 
				finish {
					specular 0.7      
					roughness 0.1875
					ambient 1
				}
			}
		#end

		translate y*-5.1
	}
	
	#if (NO_EXTERIOR_LIGHTS=false)	
		light_source {
			0*z
			color rgb <2,2,1.8>
			spotlight
			translate <0,-5.1,27>
			point_at <0,0,100>
			radius 50
			falloff 60
			fade_distance 30
			fade_power 10
		}  
	#end
	
	bounded_by {sphere {0,75}}
}	


/*******************************************************************************
* Impulse Wiring Trunk                                                         *
* This is the "tongue depressor" located on the dorsal aft end of the primary  *
* hull directly above the impulse engines.                                     *
*******************************************************************************/
// Port=-1, starboard=1
#macro Impulse_Wiring_Trunk_Bow_End(port_or_starboard)
difference {
	union {
		cylinder {<0,-0.5,0>,<0,1.375,0>,1.5}
		cylinder {<0,-0.5,0>,<0,0.375,0>,2.5}
		torus {1.5,1.0 translate <0,0.375,0>}
	}
	
	plane {z,0 rotate y*1.8744*port_or_starboard}    
	#if (port_or_starboard=-1)
		plane {x,0 inverse}
	#else
		plane {x,0}
	#end
	plane {y,-0.5}
}      
#end

#declare Impulse_Wiring_Trunk_1 = union {
	object {Impulse_Wiring_Trunk_Bow_End(-1)}
	object {Impulse_Wiring_Trunk_Bow_End(1)} 
	translate z*29.5
}

#declare Impulse_Wiring_Trunk_2 = difference {
	
	union {
		prism {                                
			linear_sweep
			linear_spline
			-0.5,
			1.375,
			6,
			<0.6005,2.0327>,<1.4992,29.4509>,<0,29.5>,<-1.4992,29.4509>,<-0.6005,2.0327>,<0.6005,2.0327>
		}
		prism {                                
			linear_sweep
			linear_spline
			-0.5,
			0.375,
			6,
			<1.6,2>,<2.4987,29.4182>,<0,29.5>,<-2.4987,29.4182>,<-1.6,2>,<1.6,2>
		}
		cylinder {<0.6005,0.375,2.0327>,<1.4992,0.375,29.4509>,1}
		cylinder {<-0.6005,0.375,2.0327>,<-1.4992,0.375,29.4509>,1}
	}
	
	plane {y,-0.5}
}

#declare Impulse_Wiring_Trunk_3 = difference {
	
	box {<2.2784,1.375,2.0327>,<-2.2784,-0.5,0>}
	cylinder {<4.5984,-0.5001,1.9019>,<4.5984,1.376,1.9019>,4}
	cylinder {<-4.5984,-0.5001,1.9019>,<-4.5984,1.376,1.9019>,4}
}

#declare Impulse_Wiring_Trunk_4 = difference {
	
	box {<2.2784,0.375,2.0327>,<-2.2784,-0.5,0>}
	cylinder {<4.5984,-0.5001,1.9019>,<4.5984,1.376,1.9019>,3}
	cylinder {<-4.5984,-0.5001,1.9019>,<-4.5984,1.376,1.9019>,3}
}

#declare Impulse_Wiring_Trunk_5 = difference {
	intersection {
		torus {4,1}
		cylinder {<0,0,0>,<0,1,0>,4}
	}
	plane {z,0 rotate y*1.8744 inverse}
	plane {z,-1.9019}
	plane {x,0 inverse}
	translate <4.5984,0.375,1.9019>
}

#declare Impulse_Wiring_Trunk_6 = difference {
	intersection {
		torus {4,1}
		cylinder {<0,0,0>,<0,1,0>,4}
	}
	plane {z,0 rotate y*-1.8744 inverse}
	plane {z,-1.9019}
	plane {x,0}
	translate <-4.5984,0.375,1.9019>
}

#declare Impulse_Wiring_Trunk_7 = difference {
	union {
		prism {                                
			linear_sweep
			linear_spline
			-0.5,
			0.5
			6,
			<1.375,0.25>,<2.25,0.8>,<2.25,31.5>,<0,31.5>,<0,0.25>,<1.375,0.25>
			rotate z*90
			translate <0,0,0>
		}
		difference {
			cylinder {<0,2.25,31.5>,<0,0,31.5>0.5}
			plane {z,0}
		}
	}
	cylinder {<0,2.25,-1>,<0,2.25,40>0.25}
}

#declare Impulse_Wiring_Trunk = union {
	union {
		object {Impulse_Wiring_Trunk_1}
		object {Impulse_Wiring_Trunk_2}
		object {Impulse_Wiring_Trunk_3}
		object {Impulse_Wiring_Trunk_4}
		object {Impulse_Wiring_Trunk_5}
		object {Impulse_Wiring_Trunk_6}
		rotate x*-1.25	// to follow curvature of upper primary hull
	}
	object {Impulse_Wiring_Trunk_7 rotate x*-0.5}
	texture {
	  	quilted
		texture_map {
			[0.0 Metallic_Hull_Plating(ENTERPRISE_GRAY(80),0.75,0.24,0.01)]
			[1.0 Metallic_Hull_Plating(ENTERPRISE_GRAY(50),0.80,0.20,0.00)]
		}
		control0 0
		control1 0
		scale <1,1,5>
	}
}

/*******************************************************************************
* Command Module and Bridge                                                    *
*******************************************************************************/
#declare Upper_Sensor_Array = union {

	// Lip around upper sensor dome:
	union {
		cylinder {<0,-0.3,0>,<0,0.3,0>,3}
		torus {3.0,0.3}
		texture {Metallic_Hull_Plating(ENTERPRISE_SILVER,0.73,0.24,0.03)}
	}
	
	// Upper sensor dome:
	difference {
		sphere {<0,0,0>,5.25}
		sphere {<0,0,0>,5}
		plane {y,4.1}
		material {Sensor_Dome_Material}
		translate y*-4
	} 
	
	// Light the sensor dome:
	#if (NO_EXTERIOR_LIGHTS=false)
		union {
			#local foo=0;
			#while (foo <= 360)
				light_source {
					#if (foo=0)
						<0,0,0>
					#else
						<0,0,1.5>
					#end
					color rgb <1,1,0.9>
					fade_distance 5
					fade_power 1
					#if (foo=0)
						translate y*0.7
					#else
						translate y*0.4
						rotate y*(foo)
					#end
				}  
				#local foo=foo+60;
			#end
			bounded_by {sphere {0,75}}
		}
	#end
	
	translate y*15.4
}

#macro Command_Module_Shell(chop_off_bottom)
	union {
		
		// Dimensions:			
		#local majorRadius=2.4;
		#local minorRadius=3.8;
		#local x_stretch=2.1;
		#local y_stretch=1.9;
		#local z_stretch=x_stretch;
		#local y_translate=7.709-2;
		#local z_translate=0;
		#local stretch_rear=1.75;

		// Front half of decks 2 & 3:
		difference {
			
			union {
				
				difference {
					union {
						torus {majorRadius,minorRadius}                      
						cylinder {<0,-minorRadius,0>,<0,minorRadius,0>,majorRadius} 
						scale <x_stretch,y_stretch,z_stretch>
					} 
					plane {z,-0.0001}  
				}
				
				// Rear half of decks 2 & 3:
				difference {
					union {
						torus {majorRadius,minorRadius}
						cylinder {<0,-minorRadius,0>,<0,minorRadius,0>,majorRadius} 
						scale <x_stretch,y_stretch,z_stretch>
					} 
					plane {z,0 inverse}
					scale <1,1,stretch_rear>  
				}
				
				translate <0,y_translate,z_translate>
			}
			
			// Difference out the upper primary hull:
			#if (chop_off_bottom)
				sphere {<0,-118.231,0>,126.7999}
			#end
			
			bounded_by {box {<13,13,13>,<-13,0,-25>}}
		}
	}
#end

// Making decks and bulkheads that match the profile of the command module is easy;
// just use the outline of the module shell (slightly shrunken so that the interior 
// objects don't poke through the outer hull) and make slices:
#macro Command_Module_Deck(y_offset)
	difference {
		
		object {Command_Module_Shell(false) scale 0.985}
		plane {y,y_offset-DECK_THICKNESS/2}
		plane {y,y_offset+DECK_THICKNESS/2 inverse}
		
		texture {Deck_Texture}
	}
#end  

#macro Command_Module_Longitudinal_Bulkhead(x_offset) 
	difference {
		
		object {Command_Module_Shell(true) scale 0.985}
		plane {x,x_offset-BULKHEAD_THICKNESS/2}
		plane {x,x_offset+BULKHEAD_THICKNESS/2 inverse}
		
		texture {Bulkhead_Texture}
	}
#end

#macro Command_Module_Lateral_Bulkhead(z_offset) 
	difference {
		
		object {Command_Module_Shell(true) scale 0.985}
		plane {z,z_offset-BULKHEAD_THICKNESS/2}
		plane {z,z_offset+BULKHEAD_THICKNESS/2 inverse}
		
		texture {Bulkhead_Texture}
	}
#end

#macro Bridge_Shell(chop_off_bottom)
	difference {

		union {
			
			// Bridge:
			union {
				
				// Dimensions:	
				#local majorRadius=1.85;
				#local minorRadius=4.9;
				#local y_stretch=0.6;
				 
				torus {majorRadius,minorRadius}
				cylinder {<0,-minorRadius,0>,<0,minorRadius,0>,majorRadius}
				scale <1,y_stretch,1>
			}
			
			translate y*12.6
		}

		// Chop off the area where decks 2 & 3 are located:
		#if (chop_off_bottom=true)		
			object {Command_Module_Shell(false)}
		#end
	}
#end


#declare Bridge_Module = union {

	difference {
		
		object {Bridge_Shell(true)}
		object {Bridge_Shell(false) scale 0.98 texture {Bulkhead_Texture}}
		texture {
			radial
			texture_map {
				[0.0 Metallic_Hull_Plating(ENTERPRISE_GRAY(75),0.73,0.26,0.01)]						
				[0.30 Metallic_Hull_Plating(ENTERPRISE_GRAY(80),0.73,0.26,0.01)]						
				[0.70 Metallic_Hull_Plating(ENTERPRISE_GRAY(80),0.73,0.26,0.01)]						
				[1.0 Metallic_Hull_Plating(ENTERPRISE_GRAY(75),0.73,0.26,0.01)]						
			}
			frequency 14
		} 
	}	
}
 
#declare Turbolift_Shaft = object {
	Rounded_Cylinder(80,1) rotate x*90 translate <0,-1,-6.433> scale <1,0.25,1>
	translate y*5
}

#declare Upper_Registration_Lightbar = difference {
 
 	union {
	
		union {
			
			#local bar_radius = 11.25;
			
			difference {
				
				torus {bar_radius,0.25}
				plane {x,0 rotate y*1.5 inverse}
				plane {x,0 rotate y*-1.5}
			}
		
			sphere {<0,0,0>,0.25 translate z*bar_radius rotate y*1.5}
			sphere {<0,0,0>,0.25 translate z*bar_radius rotate y*-1.5}
			
			texture {Metallic_Hull_Plating(ENTERPRISE_SILVER,0.3,0.3,0.4)}
			
			translate y*10
		}

		merge {
			
			#local bar_radius = 11.375;
			
			difference {
				
				torus {bar_radius,0.125}
				plane {x,0 rotate y*0.5 inverse}
				plane {x,0 rotate y*-0.5}
			}
		
			sphere {<0,0,0>,0.125 translate z*bar_radius rotate y*0.5}
			sphere {<0,0,0>,0.125 translate z*bar_radius rotate y*-0.5}
			
			#if (NO_EXTERIOR_LIGHTS=true)
				texture {Metallic_Hull_Plating(ENTERPRISE_GRAY(75),0.3,0.3,0.4)}
			#else					
				texture {
					pigment {color rgb 1} 
					finish {
						specular 0.7      
						roughness 0.1875
						ambient 1
					}
				}
			#end

			translate y*10.1
		}
		
		#if (NO_EXTERIOR_LIGHTS=false)	
			light_source {
				0*z
				color rgb <2,2,1.8>
				spotlight
				translate <0,10.1,12>
				point_at <0,0,100>
				radius 50
				falloff 60
				fade_distance 30
				fade_power 10
			}  
		#end
		
	}
	
	object {Command_Module_Shell(false) scale 0.99}
	
	bounded_by {sphere {0,75}}
}

#declare Command_Module_Top_Hatch_Outline = box {<1.2,13,-13.6>,<-1.2,0,-10>}

#declare Command_Module_Top_Hatch = intersection {
	
	difference {
		object {Command_Module_Shell(true) scale 0.99}
		object {Command_Module_Shell(false) scale 0.985}
	}
	
	object {Command_Module_Top_Hatch_Outline}
	
	texture {Metallic_Hull_Plating(ENTERPRISE_YELLOW,0.7,0.25,0.05)}
}
 
#declare Command_Module_Top_Hatch_Marking = intersection {
	
	difference {
		object {Command_Module_Shell(true) scale 1.00005}
		object {Command_Module_Shell(false) scale 1.0000}
	}
	
	difference {
		box {<1.5,13,-13.9>,<-1.5,0,-9.7>}
		object {Command_Module_Top_Hatch_Outline}
	}
	
	texture {Metallic_Hull_Plating(ENTERPRISE_RED,0.7,0.25,0.05)}
}

#declare Command_Module_Aft_Hatch_Outline = box {<1.0,9.5,-23>,<-1.0,7,-17>}

#declare Command_Module_Aft_Hatch = intersection {
	
	difference {
		object {Command_Module_Shell(true) scale 0.99}
		object {Command_Module_Shell(false) scale 0.985}
	}
	
	object {Command_Module_Aft_Hatch_Outline}
	
	texture {Metallic_Hull_Plating(ENTERPRISE_GRAY(75),0.75,0.22,0.03)}
}
 
#declare Command_Module_Aft_Hatch_Marking = intersection {
	
	difference {
		object {Command_Module_Shell(true) scale 1.00005}
		object {Command_Module_Shell(false) scale 1.0000}
	}
	
	difference {
		box {<1.3,9.8,-23.3>,<-1.3,6.7,-16.7>}
		object {Command_Module_Aft_Hatch_Outline}
	}
	
	texture {Metallic_Hull_Plating(ENTERPRISE_RED,0.75,0.22,0.03)}
}
 
#declare Command_Module_With_Holes = difference {
	
	object {
		Command_Module_Shell(true)
		texture {
		  	quilted
			texture_map {
				[0.0 Metallic_Hull_Plating(ENTERPRISE_GRAY(80),0.75,0.24,0.01)]
				[1.0 Metallic_Hull_Plating(ENTERPRISE_GRAY(50),0.80,0.20,0.00)]
			}
			control0 0
			control1 0
			scale <5,3,5>
		}
	}
		
	object {Command_Module_Shell(false) scale 0.98 texture {Bulkhead_Texture}}
	object {Bridge_Shell(false) scale 0.98 texture {Bulkhead_Texture}}

	object {Command_Module_Top_Hatch_Outline}
	object {Command_Module_Aft_Hatch_Outline}

	#if (NO_PORTHOLES=false)

		// Port side portholes:
		object {Round_Porthole(0.3125,1,7) translate <-11,8.781,0> rotate y*-45}
		object {Round_Porthole(0.3125,1,5) translate <-11,10.681,0> rotate y*-36}
		object {Rectangular_Porthole(1.3,0.625,1,5) translate <-10,10.681,0> rotate y*-12}
		object {Rectangular_Porthole(1.3,0.625,1,5) translate <-10,10.681,0>}
		object {Rectangular_Porthole(1.3,0.625,1,5) translate <-10,10.681,0> rotate y*12}
		object {Rectangular_Porthole(1.3,0.625,1,5) translate <-10,10.681,0> rotate y*24}
		object {Round_Porthole(0.3125,1,5) translate <-10,8.781,0> rotate y*45}

		// Starboard side portholes:
		object {Round_Porthole(0.3125,1,7) translate <11,8.7810> rotate y*45}
		object {Round_Porthole(0.3125,1,5) translate <11,10.681,0> rotate y*36}
		object {Rectangular_Porthole(1.3,0.625,1,5) translate <10,10.681,0> rotate y*12}
		object {Rectangular_Porthole(1.3,0.625,1,5) translate <10,10.681,0>}
		object {Rectangular_Porthole(1.3,0.625,1,5) translate <10,10.681,0> rotate y*-12}
		object {Rectangular_Porthole(1.3,0.625,1,5) translate <10,10.681,0> rotate y*-24}
		object {Round_Porthole(0.3125,1,5) translate <10,8.781,0> rotate y*-45}

		// Forward portholes:
		object {Round_Porthole(0.3125,1,5) translate <10,10.681,0> rotate y*-96}		
		object {Round_Porthole(0.3125,1,5) translate <10,10.681,0> rotate y*-84}		

	#end 	
}

#declare Command_Module_Glass = difference {
	object {Command_Module_Shell(true) scale 0.99}
	object {Command_Module_Shell(false) scale 0.985}
	plane {y,11.9 inverse}
	plane {z,-10}
	material {Porthole_Glass_Material}
}

#declare Command_Module_And_Bridge = union {
	
	union {
		object {Command_Module_With_Holes}
		object {Turbolift_Shaft}
		texture {Metallic_Hull_Plating(color rgb 0.7,0.75,0.19,0.06)}
	} 
	
	object {Bridge_Module}
	object {Command_Module_Glass}
	object {Upper_Sensor_Array}
	object {Running_Light(0.25,0.25,1,0,0,false) rotate z*-65 translate <6.45,13.6,0>}
	object {Running_Light(0.25,0.25,1,0,0,false) rotate z*-65 translate <6.45,13.6,0> rotate y*180}
	object {Command_Module_Top_Hatch} 
	object {Command_Module_Top_Hatch_Marking}
	object {Command_Module_Aft_Hatch} 
	object {Command_Module_Aft_Hatch_Marking}
	object {Upper_Registration_Lightbar rotate y*-30}
	object {Upper_Registration_Lightbar}
	object {Upper_Registration_Lightbar rotate y*30}
	
	// Decks and bulkheads:
	object {Command_Module_Deck(PRIMARY_HULL_DECK_1_Y_OFFSET)}
	object {Command_Module_Deck(PRIMARY_HULL_DECK_2_Y_OFFSET)}
	object {Command_Module_Longitudinal_Bulkhead(-3)}
	object {Command_Module_Longitudinal_Bulkhead(3)}
	object {Command_Module_Lateral_Bulkhead(0.8)}
	object {Command_Module_Lateral_Bulkhead(6.1)}
	object {Command_Module_Lateral_Bulkhead(-4.75)}

	#if (NO_INTERIOR_LIGHTS=false)
		union {
			light_source {<6,PRIMARY_HULL_DECK_2_Y_OFFSET+2,3> color <1,1,1> fade_power 5 fade_distance 5}
			light_source {<-6,PRIMARY_HULL_DECK_2_Y_OFFSET+2,3> color <1,1,1> fade_power 5 fade_distance 5}
			light_source {<6,PRIMARY_HULL_DECK_2_Y_OFFSET+2,-2> color <1,1,1> fade_power 5 fade_distance 5}
			light_source {<-6,PRIMARY_HULL_DECK_2_Y_OFFSET+2,-2> color <1,1,1> fade_power 5 fade_distance 5}
			light_source {<-6,PRIMARY_HULL_DECK_3_Y_OFFSET+2,8> color <1,1,1> fade_power 5 fade_distance 5}
			light_source {<6,PRIMARY_HULL_DECK_2_Y_OFFSET+2,-7> color <1,1,1> fade_power 5 fade_distance 5}
			light_source {<0,PRIMARY_HULL_DECK_2_Y_OFFSET+2,9> color <1,1,1> fade_power 5 fade_distance 5}
			bounded_by {sphere {0,75}}
		}
	#end
}


/*******************************************************************************
* Forward sensor array                                                         *
* This is actually just a light source behind the three circular portholes in  *
* the saucer section                                                           *
*******************************************************************************/
#declare Forward_Sensor_Array = union {
	box {
		<-5,-1.125,58>,<5,-0.875,58.5>
    	texture {
			pigment {color rgbft <0.8,0.8,1.0,0,1>}
			finish {
				specular 0      
				roughness 0.1
				ambient 0
			}
		}
	}
	
	#if (NO_EXTERIOR_LIGHTS=false)
		light_source {
			<0,0,60.25>
			color rgb <0.8, 0.8, 1.0>
			fade_distance 10
			fade_power 5
		}
	#end

	bounded_by {sphere {0,75}}
}

/*******************************************************************************
* Decks and bulkheads                                                          *
*******************************************************************************/
#declare Primary_Hull_Deck_6 = difference {
	
	cone {<0,1.9227,0>,63.66-OUTER_HULL_THICKNESS,<0,-2.5742,0>,61.269-OUTER_HULL_THICKNESS}	// The rim of the primary hull is where Deck 6 intersects
	plane {y,PRIMARY_HULL_DECK_6_Y_OFFSET-DECK_THICKNESS/2}
	plane {y,PRIMARY_HULL_DECK_6_Y_OFFSET+DECK_THICKNESS/2 inverse}
	box {<-10,-3.2,66>,<10,2.3,55>}	// To keep the deck out of the middle of the three forward circular portholes
	
	texture {Deck_Texture}			
}

#declare Primary_Hull_Deck_8 = cone {
	<0,PRIMARY_HULL_DECK_8_Y_OFFSET+DECK_THICKNESS/2,0>,23.5,<0,PRIMARY_HULL_DECK_8_Y_OFFSET-DECK_THICKNESS/2,0>,23.25
	texture {Deck_Texture}			
}

#declare Primary_Hull_Deck_9 = cone {
	<0,PRIMARY_HULL_DECK_9_Y_OFFSET+DECK_THICKNESS/2,0>,16,<0,PRIMARY_HULL_DECK_9_Y_OFFSET-DECK_THICKNESS/2,0>,15.5
	texture {Deck_Texture}			
}

#declare Circular_Bulkhead_12 = difference {
	cylinder {<0,PRIMARY_HULL_DECK_9_Y_OFFSET,0>,<0,PRIMARY_HULL_DECK_4_Y_OFFSET,0>,12}
	cylinder {<0,PRIMARY_HULL_DECK_9_Y_OFFSET-0.0001,0>,<0,PRIMARY_HULL_DECK_4_Y_OFFSET+1.0001,0>,12-BULKHEAD_THICKNESS}
	texture {Bulkhead_Texture}			
}

#declare Circular_Bulkhead_52 = difference {
	cylinder {<0,-2.92,0>,<0,2.35,0>,52.5}
	cylinder {<0,-2.9201,0>,<0,2.3501,0>,52.5-BULKHEAD_THICKNESS}
	texture {Bulkhead_Texture}			
}

#declare Circular_Bulkhead_60 = difference {
	cylinder {<0,-3.35,0>,<0,2.3,0>,59.9446}
	cylinder {<0,-3.3501,0>,<0,2.3001,0>,59.9446-BULKHEAD_THICKNESS}
	plane {x,0 rotate y*5 inverse}
	plane {x,0 rotate y*-5}
	texture {Bulkhead_Texture}			
}

#declare Primary_Hull = union {
 
 	// The basic shell of the primary hull:
	union {

		object {Lower_Primary_Hull_1_Outer_Hull} 
		object {Lower_Primary_Hull_2_Outer_Hull} 
		object {Lower_Primary_Hull_2_Inner_Hull} 	
		object {Lower_Primary_Hull_3456_With_Holes}
		object {Lower_Primary_Hull_7_With_Holes}
		object {Lower_Primary_Hull_8_Outer_Hull} 

		object {Upper_Primary_Hull_1_With_Holes(true)} 
		object {Upper_Primary_Hull_2_Outer_Hull(true)} 
		object {Upper_Primary_Hull_2_Inner_Hull} 
		object {Upper_Primary_Hull_3_Outer_Hull(true)} 
		object {Upper_Primary_Hull_3_Inner_Hull} 
	}

	object {Primary_Hull_Rim_With_Holes}

	// Glass:
	object {Primary_Hull_Rim_Glass} 
	object {Upper_Primary_Hull_1_Glass}
	object {Lower_Primary_Hull_345_Glass}
	object {Lower_Primary_Hull_7_Glass}
	
	// The landing pads on the lower hull:
	object {Landing_Pad rotate y*59.5}
	object {Landing_Pad rotate y*-59.5}
	object {Landing_Pad_Ring rotate y*59.5}
	object {Landing_Pad_Ring rotate y*-59.5}
	
	// Hatches:
	object {L_Hatch_Port}
	object {L_Hatch_Starboard}
	object {Ventral_Yellow_Hatch}
	object {Ventral_Gray60_Hatch}
	object {Ventral_Square_Inner_Hatch}
	object {Ventral_Square_Outer_Hatch}
	
	// Running lights:
	object {Port_Dorsal_Running_Light translate <57.9,2.42,0> rotate y*-180}
	object {Starboard_Dorsal_Running_Light translate <57.9,2.42,0>}
	object {Forward_Dorsal_Running_Light translate <57.9,2.42,0> rotate y*-90}
	
	object {Small_Port_Dorsal_Running_Light translate <62,2.3875,0> rotate y*-180}
	object {Small_Starboard_Dorsal_Running_Light translate <62,2.3875,0>}
	object {Small_Forward_Dorsal_Running_Light translate <62,2.3875,0> rotate y*-90}    
	
	object {Port_Ventral_Running_Light rotate z*180 translate <58.4,-3.3625,0> rotate y*-180}
	object {Starboard_Ventral_Running_Light rotate z*180 translate <58.4,-3.3625,0>}
	
	object {Small_Port_Side_Running_Light rotate z*-118 translate <63.45,1.5,0> rotate y*-180}
	object {Small_Starboard_Side_Running_Light rotate z*-118 translate <63.45,1.5,0>}
	
	object {Lower_Registration_Lightbar rotate y*90}
	object {Lower_Registration_Lightbar rotate y*-90}
	
	// Markings:
	object {Upper_Primary_Hull_Registration}
	object {Lower_Primary_Hull_Port_Registration}
	object {Lower_Primary_Hull_Starboard_Registration}
	object {Lower_Primary_Hull_Red_Quarter_Ring rotate y*131}
	object {Lower_Primary_Hull_Red_Quarter_Ring rotate y*-131}
	object {L_Hatch_Marking(1)}
	object {L_Hatch_Marking(-1)}
	object {Dorsal_Red_Pinstripes}
	object {Landing_Pad_Outline rotate y*59.5}
	object {Landing_Pad_Outline rotate y*-59.5}
	object {Port_Hatch_Sign}
	object {Forward_Hatch_Sign}
	  
	// Major components:
	object {Impulse_Engines translate <0,0.5,-65>}
	object {Impulse_Wiring_Trunk translate <0,2.3875,-65>}
	object {Lower_Sensor_Array translate y*-11.866}
	object {Command_Module_And_Bridge}
	object {Forward_Sensor_Array}
	
	//Decks and bulkheads:
	object {Primary_Hull_Deck_6}
	object {Primary_Hull_Deck_8}
	object {Primary_Hull_Deck_9}
	object {Circular_Bulkhead_12}
	object {Circular_Bulkhead_52}
	object {Circular_Bulkhead_60}
	
	
	// Interior lights:
	#if (NO_INTERIOR_LIGHTS = false)
	 
	 	union {
			// Lights for the lower primary hull:
			light_source {<0,PRIMARY_HULL_DECK_9_Y_OFFSET+2,13> color <1,1,0.8> fade_distance 10 fade_power 5}
			light_source {<0,PRIMARY_HULL_DECK_9_Y_OFFSET+2,13> color <1,1,0.8> fade_distance 10 fade_power 5 rotate y*24}
			light_source {<13,PRIMARY_HULL_DECK_9_Y_OFFSET+2,0> color <1,1,0.8> fade_distance 10 fade_power 5}
			light_source {<-13,PRIMARY_HULL_DECK_9_Y_OFFSET+2,0> color <1,1,0.8> fade_distance 10 fade_power 5}
			light_source {<0,PRIMARY_HULL_DECK_8_Y_OFFSET+2,13> color <1,1,0.8> fade_distance 10 fade_power 5}
			light_source {<13,PRIMARY_HULL_DECK_8_Y_OFFSET+2,0> color <1,1,0.8> fade_distance 10 fade_power 5}
			light_source {<-13,PRIMARY_HULL_DECK_8_Y_OFFSET+2,0> color <1,1,0.8> fade_distance 10 fade_power 5}
			light_source {<0,PRIMARY_HULL_DECK_8_Y_OFFSET+2,13> color <1,1,0.8> fade_distance 10 fade_power 5 rotate y*-120}
			light_source {<0,PRIMARY_HULL_DECK_7_Y_OFFSET+2,57> color <1,1,0.8> fade_distance 10 fade_power 5 rotate y*110}
			light_source {<0,PRIMARY_HULL_DECK_7_Y_OFFSET+2,57> color <1,1,0.8> fade_distance 10 fade_power 5 rotate y*-110}
			
			// Lights for the saucer rim:
			light_source {<0,PRIMARY_HULL_DECK_7_Y_OFFSET+2,61> color <1,1,0.8> fade_distance 10 fade_power 2 rotate y*45}
			light_source {<0,PRIMARY_HULL_DECK_6_Y_OFFSET+2,61> color <1,1,0.8> fade_distance 10 fade_power 2 rotate y*45}
			light_source {<0,PRIMARY_HULL_DECK_7_Y_OFFSET+2,61> color <1,1,0.8> fade_distance 10 fade_power 2 rotate y*-45}
			light_source {<0,PRIMARY_HULL_DECK_6_Y_OFFSET+2,61> color <1,1,0.8> fade_distance 10 fade_power 2 rotate y*-45}
			light_source {<0,PRIMARY_HULL_DECK_7_Y_OFFSET+2,61> color <1,1,0.8> fade_distance 10 fade_power 2 rotate y*135}
			light_source {<0,PRIMARY_HULL_DECK_6_Y_OFFSET+2,61> color <1,1,0.8> fade_distance 10 fade_power 2 rotate y*135}
			light_source {<0,PRIMARY_HULL_DECK_7_Y_OFFSET+2,61> color <1,1,0.8> fade_distance 10 fade_power 2 rotate y*-135}
			light_source {<0,PRIMARY_HULL_DECK_6_Y_OFFSET+2,61> color <1,1,0.8> fade_distance 10 fade_power 2 rotate y*-135}
			
			// Lights for the upper primary hull:
			light_source {<0,PRIMARY_HULL_DECK_6_Y_OFFSET+2,55> color <1,1,0.8> fade_distance 10 fade_power 5 rotate y*45}		
			light_source {<0,PRIMARY_HULL_DECK_6_Y_OFFSET+2,55> color <1,1,0.8> fade_distance 10 fade_power 5 rotate y*-45}		
			light_source {<0,PRIMARY_HULL_DECK_6_Y_OFFSET+2,55> color <1,1,0.8> fade_distance 10 fade_power 5 rotate y*135}		
			light_source {<0,PRIMARY_HULL_DECK_6_Y_OFFSET+2,55> color <1,1,0.8> fade_distance 10 fade_power 5 rotate y*-135}		

			bounded_by {sphere {0,75}}
		}		

	#end
}

// Together these define the yellow circle with the red ring around it:
#declare Round_Hatch = cylinder {<0,0,3>,<0,-100,3>,3.6}
#declare Round_Hatch_Outline = difference {                       
	cylinder {<0,0,3>,<0,-100,3>,4}
	cylinder {<0,-1,3>,<0,-101,3>,3.7}
}

// Together these define the "T" shaped hatch:
#declare T_Hatch = prism {
	linear_sweep
	linear_spline
	1,-101,
	9,
	<3.9,-3.9>,<-3.9,-3.9>,<-3.7,-9>,<-2,-9>,<-2,-11.9>,<2,-11.9>,<2,-9>,<3.7,-9>,<3.9,-3.9>
} 
#declare T_Hatch_Outline = difference {
	prism {
		linear_sweep
		linear_spline
		0,-100,
		9,
		<4.2,-3.6>,<-4.2,-3.6>,<-4,-9.3>,<-2.3,-9.3>,<-2.3,-12.2>,<2.3,-12.2>,<2.3,-9.3>,<4,-9.3>,<4.2,-3.6>
	} 
	object {T_Hatch}
}

// Together these define the rectangular hatch:
#declare Rectangular_Hatch = box {<1.7,0,-27.2>,<-1.7,-100,-15.8>}
#declare Rectangular_Hatch_Outline = difference {
	box {<2,0,-27.5>,<-2,-100,-15.5>}
	box {<1.7,1,-27.2>,<-1.7,-101,-15.8>}
}

// Together these define the square hatch:
#declare Square_Hatch = box {<1.7,0,-30>,<-1.7,-100,-35>}
#declare Square_Hatch_Outline = difference {
	box {<2,0,-29.7>,<-2,-100,-35.3>}
	box {<1.7,0,-30>,<-1.7,-100,-35>}
}

// Together these define the large square hatch under the fantail:
#declare Square_Fantail_Hatch = box {<3.2,-1,-53>,<-3.2,-15,-44>}
#declare Square_Fantail_Hatch_Outline = difference {
	box {<3.5,-1,-53.3>,<-3.5,-15,-43.7>}
	box {<3.2,-1,-53>,<-3.2,-16,-44>}
}

// These are the little bitty bulkhead numbers:
#macro Bulkhead_Number(bn_value,line_offset)
union {
	text {
		ttf
		"SFAMUSAF.ttf",
		bn_value,
		15,
		<0,0,0>
		scale <1.4,1.4,1>  
	}
	box {<-0.1,1.75,0>,<0.1,0.9,10> translate x*line_offset}
}
#end

// This is the double red pinstripe that runs the length of the dorsal side of the hull:
#declare Dorsal_Pinstripes = union {
	box {<-0.8,0,25>,<-1,15,-52.5>}
	box {<0.8,0,25>,<1,15,-52.5>}
	box {<-1,0,-52.3>,<1,15,-52.5>}
} 



/*******************************************************************************
* Secondary Hull Pennant                                                       *
* This is the stylized "E" located on the port and starboard sides of the      *
* secondary hull just abaft the main deflector dish. Because the pennant spans *
* four hull sections and is two different colors, it has to be declared in     *
* pieces so that each part can be intersected with the part of the hull it     *
* touches.                                                                     *
*******************************************************************************/
// The "E" part:
#declare Secondary_Hull_Pennant_E = prism {
	linear_sweep
	linear_spline
	5,-5
	13,
	<22.7,1.1>,<5.5,1.1>,<5.18,0.66>,<21.28,0.66>,<20.96,0.22>,<-11.04,0.22>,
	<-11.36,-0.22>,<20.64,-0.22>,<20.32,-0.66>,<5.5,-0.66>,<5.18,-1.1>,
	<21.1,-1.1>,<22.7,1.1>
	rotate <0,-90,-90>
}

// The part underneath the gold swoosh:
#declare Secondary_Hull_Pennant_Swoosh_Base = prism {
	linear_sweep
	linear_spline
	5,-5
	5,
	<30.25,1.1>,<23.7,1.1>,<22.1,-1.1>,<28.65,-1.1>,<30.25,1.1>
	rotate <0,-90,-90>
} 
	
// The gold swoosh:
#declare Secondary_Hull_Pennant_Swoosh = difference {
		
	union {
	
		cylinder {<5,1.785,26.635>,<-5,1.785,26.635>,0.265}
		cylinder {<5,-1.035,26.575>,<-5,-1.035,26.575>,0.375}
		cylinder {<5,0,0>,<-5,0,0>,0.75 scale <1,1.2467,1> translate <0,0.115,27.35>}

		prism {
			linear_sweep
			linear_spline
			5,-5
			7,
			<26.88,1.9>,<27.9132,0.7325>,<27.8,-0.65>,<26.85,-1.3>,<26.4064,-0.7921>,<26.4064,1.6516>,<26.88,1.9>
			rotate <0,-90,-90>
		} 
	}
	
	cylinder {<5.0001,0,0>,<-5.0001,0,0>,1.13 scale <1,1.44,1> translate <0,0.5,25.625>}	
}

#declare Pennant_Lightbar = union {
	
	union {
		
		#local bar_radius = 13.200;
		
		difference {
			
			torus {bar_radius,0.25 rotate x*90}
			plane {y,0 rotate z*1 inverse}
			plane {y,0 rotate z*-1}
		}
	
		sphere {<0,0,0>,0.25 translate x*bar_radius rotate z*1}
		sphere {<0,0,0>,0.25 translate x*bar_radius rotate z*-1}
		
		texture {Metallic_Hull_Plating(ENTERPRISE_SILVER,0.3,0.3,0.4)}
		translate z*33.25
	}

	merge {
		
		#local bar_radius = 13.35;
		
		difference {
			
			torus {bar_radius,0.125 rotate x*90}
			plane {y,0 rotate z*0.5 inverse}
			plane {y,0 rotate z*-0.5}
		}
	
		sphere {<0,0,0>,0.125 translate x*bar_radius rotate z*0.5}
		sphere {<0,0,0>,0.125 translate x*bar_radius rotate z*-0.5}
		
		#if (NO_EXTERIOR_LIGHTS=true)
			texture {Metallic_Hull_Plating(ENTERPRISE_GRAY(50),0.3,0.3,0.4)}
		#else					
			texture {
				pigment {color rgb 1} 
				finish {
					specular 0.7      
					roughness 0.1875
					ambient 1
				}
			}
		#end

		translate <0,0.05,33.15>
	}
	
	#if (NO_EXTERIOR_LIGHTS=false)	
		light_source {
			0*z
			color rgb <4,4,3.6>
			spotlight
			translate <15,0,46>
			point_at <15,0,-100>
			radius 4
			falloff 7
			fade_distance 25
			fade_power 10
		}  
	#end

	bounded_by {sphere {0,75}}
}	


/*******************************************************************************
* Main Deflector Assembly                                                      *
*******************************************************************************/
#macro Main_Deflector_Ring(ring_radius,slice_angle)
	union {
		union {
			difference {
				cylinder {<0,0,34.33>,<0,0,43.66>,ring_radius}
				cylinder {<0,0,34.33>,<0,0,43.661>,ring_radius-0.25}
			}
			torus {ring_radius-0.125,0.125 rotate x*90 translate z*43.66}
			texture {Metallic_Hull_Plating(ENTERPRISE_COPPER,0.75,0.24,0.01)}
		}
		#local plate_tx=texture {Metallic_Hull_Plating(ENTERPRISE_COPPER,0.75,0.24,0.01)}
		#local joint_tx=texture {Metallic_Hull_Plating(ENTERPRISE_GRAY(0),0.90,0.10,0.0)}
		#local panel_rot=0;
		#while (panel_rot<360)
			object {Conical_Hull_Plate(43.66,ring_radius,34.33,ring_radius,slice_angle,plate_tx,joint_tx,0,0,(43.66-34.33)/3) rotate z*panel_rot}
			// Since we can see the inside of the ring, texture that too:
			object {Conical_Hull_Plate(43.66,ring_radius-0.25001,34.33,ring_radius-0.25001,slice_angle,plate_tx,joint_tx,0,0,(43.66-34.33)/3) rotate z*panel_rot}
			#local panel_rot=panel_rot+slice_angle;				
		#end					
	}
#end

#macro Main_Deflector_Big_Cone(radius_offset,length_offset)
	cone {<0,0,33.96-length_offset>,11.5794+radius_offset,<0,0,42.12+length_offset>,9.675+radius_offset}
#end

#declare Main_Deflector_Big_Cone_Texture_Pattern_1 = union {

	#local rotation_angle = 0;
	#while (rotation_angle < 360)
		difference {
			box {<-1,0,33>,<1,12,38>}
			box {<-0.5,-0.0001,36>,<0.5,12.0001,38.0001>}
			rotate z*rotation_angle
		}
		#local rotation_angle = rotation_angle + 15;
	#end
}

#declare Main_Deflector_Big_Cone_Texture_Pattern_2 = union {

	#local rotation_angle = 0;
	#while (rotation_angle < 360)
		difference {
			box {<-1.5,0,33>,<1.5,12,39.5>}
			box {<-1.2,-0.0001,33.0001>,<1.2,12.0001,38.5>}
			rotate z*rotation_angle
		}
		#local rotation_angle = rotation_angle + 15;
	#end
}

#declare Main_Deflector_Big_Cone_Texture_Pattern_3 = union {

	#local rotation_angle = 0;
	#while (rotation_angle < 360)
		box {<-1,0,40>,<1,12,42> rotate z*rotation_angle}
		#local rotation_angle = rotation_angle + 15;
	#end
}

#declare Main_Deflector_Dish_Texture_Pattern_1 = difference {
	
	sphere {<0,0,63.72>,17.4999}
	sphere {<0,0,63.81>,17.4999}
	cylinder {<0,0,50.0001>,<0,0,39.9999>,5.4}
	plane {z,47.96 inverse}

	texture {
		radial
		texture_map {
			[0.0 Metallic_Hull_Plating(ENTERPRISE_COPPER,0.73,0.26,0.01)]						
			[0.4 Metallic_Hull_Plating(ENTERPRISE_COPPER,0.75,0.24,0.0)]						
			[0.5 Metallic_Hull_Plating(ENTERPRISE_COPPER,0.78,0.22,0.0)]						
			[0.6 Metallic_Hull_Plating(ENTERPRISE_COPPER,0.75,0.24,0.0)]						
			[1.0 Metallic_Hull_Plating(ENTERPRISE_COPPER,0.73,0.26,0.01)]						
		}
		rotate x*90
		scale 7
		frequency 48
	}
}

#declare Main_Deflector_Dish_Texture_Pattern_2 = difference  {
	
	sphere {<0,0,63.72>,17.4999}
	sphere {<0,0,63.81>,17.4999}
	cylinder {<0,0,50.0001>,<0,0,39.9999>,5.4 inverse}
	cylinder {<0,0,50.0001>,<0,0,39.9999>,2.873}
	plane {z,47.96 inverse}

	texture {
		radial
		texture_map {
			[0.0 Metallic_Hull_Plating(ENTERPRISE_COPPER,0.73,0.26,0.01)]						
			[0.4 Metallic_Hull_Plating(ENTERPRISE_COPPER,0.75,0.24,0.0)]						
			[0.5 Metallic_Hull_Plating(ENTERPRISE_COPPER,0.78,0.22,0.0)]						
			[0.6 Metallic_Hull_Plating(ENTERPRISE_COPPER,0.75,0.24,0.0)]						
			[1.0 Metallic_Hull_Plating(ENTERPRISE_COPPER,0.73,0.26,0.01)]						
		}
		rotate x*90
		scale 7
		frequency 24
	}
}

#declare Main_Deflector_Dish_Texture_Pattern_3 = difference  {
	
	sphere {<0,0,63.72>,17.4999}
	sphere {<0,0,63.81>,17.4999}
	cylinder {<0,0,50.0001>,<0,0,39.9999>,2.873 inverse}
	plane {z,47.96 inverse}

	texture {
		radial
		texture_map {
			[0.0 Metallic_Hull_Plating(ENTERPRISE_COPPER,0.73,0.26,0.01)]						
			[0.4 Metallic_Hull_Plating(ENTERPRISE_COPPER,0.75,0.24,0.0)]						
			[0.5 Metallic_Hull_Plating(ENTERPRISE_COPPER,0.78,0.22,0.0)]						
			[0.6 Metallic_Hull_Plating(ENTERPRISE_COPPER,0.75,0.24,0.0)]						
			[1.0 Metallic_Hull_Plating(ENTERPRISE_COPPER,0.73,0.26,0.01)]						
		}
		rotate x*90
		scale 7
		frequency 12
	}
}

#declare Main_Deflector_Dish_Texture = union {
	
	object {Main_Deflector_Dish_Texture_Pattern_1}
	object {Main_Deflector_Dish_Texture_Pattern_2}
	object {Main_Deflector_Dish_Texture_Pattern_3}
}

#declare Main_Deflector =
	union {
		
		// The copper ring around the whole assembly:
		union {
			Beveled_Cylinder(<0,0,32.43>,<0,0,35.2267>,11.7733,0.25) 
			texture {
				radial
				texture_map {
					[0 Metallic_Hull_Plating(ENTERPRISE_COPPER,0.75,0.24,0.01)]						
					[0.3 Metallic_Hull_Plating(ENTERPRISE_COPPER,0.72,0.27,0.1)]						
					[0.5 Metallic_Hull_Plating(ENTERPRISE_COPPER,0.70,0.29,0.1)]						
					[0.7 Metallic_Hull_Plating(ENTERPRISE_COPPER,0.72,0.27,0.1)]						
					[1 Metallic_Hull_Plating(ENTERPRISE_COPPER,0.75,0.24,0.01)]						
				}
				rotate x*90
				scale 11.7733
				frequency 30
			}
		}
		
		// Backplate behind the deflector dish:
		cylinder {
			<0,0,35.23>,<0,0,35.2267>,8.35
			texture {
			  	quilted
				texture_map {
					[0.0 Metallic_Hull_Plating(ENTERPRISE_COPPER,0.73,0.26,0.01)]
					[1.0 Metallic_Hull_Plating(ENTERPRISE_GRAY(0),0.90,0.10,0.00)]
				}
				control0 0
				control1 0
		   		scale <3,3,1>
			}
		}
		
		// The little (well, at this scale, almost 2 feet wide!) screws on the back plate:
		#local screw_count=0;
		#while (screw_count<4)
			sphere {<0,0,0> 0.375 translate y*6.875 rotate z*((screw_count*90)+45) translate z*35.23 texture {Metallic_Hull_Plating(ENTERPRISE_SILVER,0.40,0.20,0.00)}}
			#local screw_count=screw_count+1;
		#end
		
		// The big cone part:
		union {
			
			union {
				difference {
					object {Main_Deflector_Big_Cone(0,0)}
					cone {<0,0,34.33>,11.25,<0,0,42.121>,9.425}
				}			
				torus {9.55,0.125 rotate x*90 translate z*42.12}
				texture {Metallic_Hull_Plating(ENTERPRISE_GRAY(80),0.75,0.24,0.01)}
			}
			
			#local plate_tx=texture {Metallic_Hull_Plating(ENTERPRISE_GRAY(80),0.75,0.24,0.01)}
			#local joint_tx1=texture {Metallic_Hull_Plating(ENTERPRISE_GRAY(50),0.90,0.10,0.0)}
			#local joint_tx2=texture {Metallic_Hull_Plating(ENTERPRISE_GRAY(30),0.90,0.10,0.0)}
			#local panel_rot=15;
			#while (panel_rot<375)
				object {Conical_Hull_Plate(42.12,9.675,38.774,10.4559,15,plate_tx,joint_tx2,0,0,0) rotate z*(panel_rot+7.5)}
				object {Conical_Hull_Plate(42.12,9.675,38.774,10.4559,15,plate_tx,joint_tx2,0,0,0) rotate z*(panel_rot+22.5)}
				object {Conical_Hull_Plate(38.774,10.4559,33.96,11.5794,30,plate_tx,joint_tx1,0,0,0) rotate z*(panel_rot)}
				// Since we can see the inside of the cone, texture that too:
				object {Conical_Hull_Plate(42.12,9.4252,38.774,10.2090,15,plate_tx,joint_tx2,0,0,0) rotate z*(panel_rot+7.5)}
				object {Conical_Hull_Plate(42.12,9.4252,38.774,10.2090,15,plate_tx,joint_tx2,0,0,0) rotate z*(panel_rot+22.5)}
				object {Conical_Hull_Plate(38.774,10.2090,33.96, 11.3366,30,plate_tx,joint_tx1,0,0,0) rotate z*(panel_rot)}
				#local panel_rot=panel_rot+30;				
			#end			
		}
				
		// The three concentric copper rings behind the deflector dish:
		object {Main_Deflector_Ring(8.35,30)}		
		object {Main_Deflector_Ring(5.4,45)}		
		object {Main_Deflector_Ring(2.873,60)}

		// The dish support spire:
		union {
			
			// The spire, tipped by a sphere:
			union {
				cylinder {<0,0,34.33>,<0,0,44.5>,0.45625}
				sphere {<0,0,44.5>,0.45625}
			}
			
			// The thin six-sided strip of metal connecting the spire to the deflector dish:
			prism {linear_spline 0.125,-0.125,7,<0.4,0>,<0.93,0.53>,<0.93,1.35>,<-0.93,1.35>,<-0.93,0.53>,<-0.4,0>,<0.4,0> rotate z*90 translate z*44.5}

			// The smaller of the two plate-shaped objects behind the main deflector dish:
			difference {			
				union {
					cylinder {<0,0,45.84>,<0,0,46.18>,1.37}
					torus {1.37,0.34 rotate x*90 translate z*46.18}
				}
				plane {z,46.18 inverse}
			}
			
			// The larger of the two plate-shaped objects behind the main deflector dish:
			difference {			
				union {
					disc {<0,0,46.18>,z,2.6}
					torus {2.6,0.28 rotate x*90 translate z*46.46}
				}
				plane {z,46.46 inverse}
			}
			
			texture {Metallic_Hull_Plating(ENTERPRISE_COPPER,0.75,0.24,0.01)}
		}
		
		// The dish:
		union {
			
			union {
				       
				// The dish itself:
				difference {
					sphere {<0,0,63.72>,17.5}
					sphere {<0,0,63.81>,17.5}
					plane {z,47.96 inverse}
				}  
				
				// Lip around the edge:
				torus {7.475,0.135 rotate x*90 translate z*47.96}
				
				// Outer ridge inside the dish:
				difference {
					torus {5.4,0.125 rotate x*90 translate z*47.115}
					plane {z,47.115}
				}
				
				// Inner ridge inside the dish:
				difference {
					torus {2.873,0.125 rotate x*90 translate z*46.525}
					plane {z,46.525}
				}
				
				texture {Metallic_Hull_Plating(ENTERPRISE_COPPER,0.75,0.24,0.01)}
			}			
			
			object {Main_Deflector_Dish_Texture}
				
			// The cone at the base of the forward spire:
			cone {<0,0,46.30>,0.725<0,0,47.96>,0.4 texture {Metallic_Hull_Plating(ENTERPRISE_COPPER,0.75,0.24,0.01)}}
			
			// The spire, tipped by an elogated sphere:
			union {
				cone {<0,0,47.9>,0.25,<0,0,52.2>,0.175}
				sphere {<0,0,0>,0.3 translate z*26.1 scale <1,1,2>}
				texture {Metallic_Hull_Plating(ENTERPRISE_SILVER,0.75,0.24,0.01)}
			}
		} 
	}

// These objects are used to cut into the hull where the Deflector_Dish_Surround objects go:
#declare Ventral_Hole = box {<-2.91,-15,38.68>,<2.91,SECONDARY_HULL_DECK_23_Y_OFFSET,10.323>}
#declare Port_Starboard_Hole = box {<-15,2.91,38.68>,<15,-2.91, 20.3868>}

#macro Deflector_Dish_Surround_Rib(ddsr_length, ddsr_radius, ddsr_z, ddsr_port_starboard, ddsr_rotation_angle)
	object {
		Rounded_Cylinder(ddsr_length, ddsr_radius)
		translate x*(ddsr_port_starboard*13.27)
		rotate z*ddsr_rotation_angle
		translate z*ddsr_z
	}
#end

#macro Secondary_Hull_Section_1_Shell(height_offset,length_offset,use_textures)
	difference {
		
		#if (use_textures=true)
			union {
				union {
					#local panel_rot=0;
					#local plate_tx=texture {Metallic_Hull_Plating(ENTERPRISE_GRAY(80),0.76,0.22,0.02)};
					#local joint_tx=texture {Metallic_Hull_Plating(ENTERPRISE_GRAY(30),0.90,0.10,0.00)};
					#while (panel_rot<360)
						object {Conical_Hull_Plate(33.96,12.2733,32.43,13.3100,30,plate_tx,joint_tx,0,0,0) rotate z*panel_rot}
						object {Conical_Hull_Plate(32.43,13.3100,30.43,13.6067,30,plate_tx,joint_tx,0,0,0) rotate z*panel_rot}
						object {Conical_Hull_Plate(30.43,13.6067,23.28,13.4267,30,plate_tx,joint_tx,0,0,0) rotate z*panel_rot}
						#local panel_rot=panel_rot+30;
					#end
				}
			}
		#else
			union {
				cone {<0,0,33.96+length_offset>,12.2733+height_offset,<0,0,32.43-length_offset>,13.3100+height_offset}
				cone {<0,0,32.43+length_offset>,13.3100+height_offset,<0,0,30.43-length_offset>,13.6067+height_offset}
				cone {<0,0,30.43+length_offset>,13.6067+height_offset,<0,0,23.28-length_offset>,13.4267+height_offset}
			}
		#end
		
		object {Port_Starboard_Hole}
		object {Ventral_Hole} 
	}
#end

// One of three boxy projections that surround the main deflector dish assembly
#declare Starboard_Deflector_Dish_Surround = union {

	difference {
				
		// The basic box (actually a cylinder so that it can follow the hull curvature)
		cylinder {<0,0,38.68>,<0,0,20.3868>,13.31}
		
		// Chop off the top, bottom and slice it halfway into the hull:
		plane {y,2.91 inverse}
		plane {y,-2.91}
		plane {x,0}
		
		// This keeps the surround from going through the large cone in the deflector dish assembly
		object {Main_Deflector_Big_Cone(-HULL_THICKNESS-0.0001,0.0001)}
		
		// Round off the top leading edge:
		difference {
			box {<-100,0.7,0.7>,<100,-0.7,-0.7>}
			cylinder {<-100,-0.7,-0.7>,<100,-0.7,-0.7>,0.7}
			translate <0,2.91,38.68>
		}
		
		// Round off the bottom leading edge:
		difference {
			box {<-100,0.7,0.7>,<100,-0.7,-0.7>}
			cylinder {<-100,0.7,-0.7>,<100,0.7,-0.7>,0.7}
			translate <0,-2.91,38.68>
		}
		
		texture {
		  	quilted
			texture_map {
				[0.0 Metallic_Hull_Plating(ENTERPRISE_GRAY(80),0.78,0.20,0.02)]
				[1.0 Metallic_Hull_Plating(ENTERPRISE_GRAY(25),0.90,0.10,0.00)]
			}
			control0 0
			control1 0
	   		scale <7,7,10.68>
	   		translate z*33.96
		}
	}

	// "E" pennants:
	difference {

		union {

			// Starboard pennant:
			intersection {
				cylinder {<0,0,38.68>,<0,0,20.3868>,13.3101}
				object {Secondary_Hull_Pennant_Swoosh_Base translate x*12}
				texture {Painted_Hull_Plating(ENTERPRISE_RED,0.75,0.24,0.01)}
			}
		
			intersection {
				cylinder {<0,0,38.68>,<0,0,20.3868>,13.3102}
				object {Secondary_Hull_Pennant_Swoosh translate x*12}
				texture {Painted_Hull_Plating(ENTERPRISE_GOLD,0.75,0.24,0.01)}
			}		

			intersection {
				cylinder {<0,0,38.68>,<0,0,20.3868>,13.3101}
				object {Secondary_Hull_Pennant_E translate x*12}
				texture {Painted_Hull_Plating(ENTERPRISE_RED,0.75,0.24,0.01)}
			}			
		}
        
        // Have to difference out the underside or the pennant objects cut into the hull!
		cylinder {<0,0,38.68>,<0,0,20.3868>,13.31}
	}
		
	// These are the two large ribs on the side of the box:
	union {
	
		object {Deflector_Dish_Surround_Rib(8.20, 0.2, 33.58, 1, 9.5) texture {Metallic_Hull_Plating(ENTERPRISE_GRAY(80),0.75,0.24,0.01)}}
		object {Deflector_Dish_Surround_Rib(13.8, 0.2, 30.78, 1, -9.5) texture {Metallic_Hull_Plating(ENTERPRISE_GRAY(80),0.75,0.24,0.01)}}
	
		// These are the eleven small ribs that increase in size as you go down. At lower detail levels,
		// only show every other rib to help with anti-aliasing:
		object {Deflector_Dish_Surround_Rib(7.0, 0.08, 35.3, 1,  6.0) texture {Metallic_Hull_Plating(ENTERPRISE_GRAY(80),0.75,0.24,0.01)}}
		object {Deflector_Dish_Surround_Rib(7.4, 0.08, 35.1, 1,  3.6) texture {Metallic_Hull_Plating(ENTERPRISE_GRAY(80),0.75,0.24,0.01)}}
		object {Deflector_Dish_Surround_Rib(7.8, 0.08, 34.9, 1,  1.2) texture {Metallic_Hull_Plating(ENTERPRISE_GRAY(80),0.75,0.24,0.01)}}
		object {Deflector_Dish_Surround_Rib(8.2, 0.08, 34.7, 1, -1.2) texture {Metallic_Hull_Plating(ENTERPRISE_GRAY(80),0.75,0.24,0.01)}}
		object {Deflector_Dish_Surround_Rib(8.6, 0.08, 34.5, 1, -3.6) texture {Metallic_Hull_Plating(ENTERPRISE_GRAY(80),0.75,0.24,0.01)}}
		object {Deflector_Dish_Surround_Rib(9.0, 0.08, 34.3, 1, -6.0) texture {Metallic_Hull_Plating(ENTERPRISE_GRAY(80),0.75,0.24,0.01)}}
	
		#if (DETAIL_LEVEL > 3)
			object {Deflector_Dish_Surround_Rib(7.2, 0.08, 35.2, 1,  4.8) texture {Metallic_Hull_Plating(ENTERPRISE_GRAY(80),0.75,0.24,0.01)}}
			object {Deflector_Dish_Surround_Rib(7.6, 0.08, 35.0, 1,  2.4) texture {Metallic_Hull_Plating(ENTERPRISE_GRAY(80),0.75,0.24,0.01)}}
			object {Deflector_Dish_Surround_Rib(8.0, 0.08, 34.8, 1,  0.0) texture {Metallic_Hull_Plating(ENTERPRISE_GRAY(80),0.75,0.24,0.01)}}
			object {Deflector_Dish_Surround_Rib(8.4, 0.08, 34.6, 1, -2.4) texture {Metallic_Hull_Plating(ENTERPRISE_GRAY(80),0.75,0.24,0.01)}}
			object {Deflector_Dish_Surround_Rib(8.8, 0.08, 34.4, 1, -4.8) texture {Metallic_Hull_Plating(ENTERPRISE_GRAY(80),0.75,0.24,0.01)}}
		#end
	
		texture {Metallic_Hull_Plating(ENTERPRISE_GRAY(70),0.75,0.24,0.01)}
	}
}

// One of three boxy projections that surround the main deflector dish assembly
#declare Port_Deflector_Dish_Surround = union {
	
	difference {
		
		// The basic box (actually a cylinder so that it can follow the hull curvature)
		cylinder {<0,0,38.68>,<0,0,20.3868>,13.31}
		
		// Chop off the top, bottom and slice it halfway into the hull:
		plane {y,2.91 inverse}
		plane {y,-2.91}
		plane {x,0 inverse}
		
		// This keeps the surround from going through the large cone in the deflector dish assembly
		object {Main_Deflector_Big_Cone(-HULL_THICKNESS-0.0001,0.0001)}
		
		// Round off the top leading edge:
		difference {
			box {<-100,0.7,0.7>,<100,-0.7,-0.7>}
			cylinder {<-100,-0.7,-0.7>,<100,-0.7,-0.7>,0.7}
			translate <0,2.91,38.68>
		}
		
		// Round off the bottom leading edge:
		difference {
			box {<-100,0.7,0.7>,<100,-0.7,-0.7>}
			cylinder {<-100,0.7,-0.7>,<100,0.7,-0.7>,0.7}
			translate <0,-2.91,38.68>
		}
		
		texture {
		  	quilted
			texture_map {
				[0.0 Metallic_Hull_Plating(ENTERPRISE_GRAY(80),0.78,0.20,0.02)]
				[1.0 Metallic_Hull_Plating(ENTERPRISE_GRAY(25),0.90,0.10,0.00)]
			}
			control0 0
			control1 0
	   		scale <7,7,10.68>
	   		translate z*33.96
		}
	}
	
	// "E" pennants:
	difference {

		union {

			intersection {
				cylinder {<0,0,38.68>,<0,0,20.3868>,13.3101}
				object {Secondary_Hull_Pennant_Swoosh_Base translate x*-12}
				texture {Painted_Hull_Plating(ENTERPRISE_RED,0.75,0.24,0.01)}
			}
		
			intersection {
				cylinder {<0,0,38.68>,<0,0,20.3868>,13.3102}
				object {Secondary_Hull_Pennant_Swoosh translate x*-12}
				texture {Painted_Hull_Plating(ENTERPRISE_GOLD,0.75,0.24,0.01)}
			}
			
			intersection {
				cylinder {<0,0,38.68>,<0,0,20.3868>,13.3101}
				object {Secondary_Hull_Pennant_E translate x*-12}
				texture {Painted_Hull_Plating(ENTERPRISE_RED,0.75,0.24,0.01)}
			}			
		}
        
        // Have to difference out the underside or the pennant objects cut into the hull!
		cylinder {<0,0,38.68>,<0,0,20.3868>,13.31}
	}

	union {
		
		// These are the two large ribs on the side of the box:
		object {Deflector_Dish_Surround_Rib(8.20, 0.2, 33.58, -1, -9.5)  texture {Metallic_Hull_Plating(ENTERPRISE_GRAY(80),0.75,0.24,0.01)}}
		object {Deflector_Dish_Surround_Rib(13.8, 0.2, 30.78, -1, 9.5)  texture {Metallic_Hull_Plating(ENTERPRISE_GRAY(80),0.75,0.24,0.01)}}
			
		// These are the eleven small ribs that increase in size as you go down. At lower detail levels,
		// only show every other rib to help with anti-aliasing:
		object {Deflector_Dish_Surround_Rib(7.0, 0.08, 35.3, -1,-6.0) texture {Metallic_Hull_Plating(ENTERPRISE_GRAY(80),0.75,0.24,0.01)}}
		object {Deflector_Dish_Surround_Rib(7.4, 0.08, 35.1, -1,-3.6) texture {Metallic_Hull_Plating(ENTERPRISE_GRAY(80),0.75,0.24,0.01)}}
		object {Deflector_Dish_Surround_Rib(7.8, 0.08, 34.9, -1,-1.2) texture {Metallic_Hull_Plating(ENTERPRISE_GRAY(80),0.75,0.24,0.01)}}
		object {Deflector_Dish_Surround_Rib(8.2, 0.08, 34.7, -1, 1.2) texture {Metallic_Hull_Plating(ENTERPRISE_GRAY(80),0.75,0.24,0.01)}}
		object {Deflector_Dish_Surround_Rib(8.6, 0.08, 34.5, -1, 3.6) texture {Metallic_Hull_Plating(ENTERPRISE_GRAY(80),0.75,0.24,0.01)}}
		object {Deflector_Dish_Surround_Rib(9.0, 0.08, 34.3, -1, 6.0) texture {Metallic_Hull_Plating(ENTERPRISE_GRAY(80),0.75,0.24,0.01)}}
	
		#if (DETAIL_LEVEL > 3)
			object {Deflector_Dish_Surround_Rib(7.2, 0.08, 35.2, -1,-4.8) texture {Metallic_Hull_Plating(ENTERPRISE_GRAY(80),0.75,0.24,0.01)}}
			object {Deflector_Dish_Surround_Rib(7.6, 0.08, 35.0, -1,-2.4) texture {Metallic_Hull_Plating(ENTERPRISE_GRAY(80),0.75,0.24,0.01)}}
			object {Deflector_Dish_Surround_Rib(8.0, 0.08, 34.8, -1, 0.0) texture {Metallic_Hull_Plating(ENTERPRISE_GRAY(80),0.75,0.24,0.01)}}
			object {Deflector_Dish_Surround_Rib(8.4, 0.08, 34.6, -1, 2.4) texture {Metallic_Hull_Plating(ENTERPRISE_GRAY(80),0.75,0.24,0.01)}}
			object {Deflector_Dish_Surround_Rib(8.8, 0.08, 34.4, -1, 4.8) texture {Metallic_Hull_Plating(ENTERPRISE_GRAY(80),0.75,0.24,0.01)}}
		#end
		
		texture {Metallic_Hull_Plating(ENTERPRISE_GRAY(70),0.75,0.24,0.01)}
	}
}

// One of three boxy projections that surround the main deflector dish assembly
#declare Ventral_Deflector_Dish_Surround = difference {
			
	// The basic box (actually a cylinder so that it can follow the hull curvature)
	cylinder {<0,0,38.68>,<0,0,10.323>,12.9001}	// This was 12.9000 in radius; changed to 12.9001 to fix co-incident surface problem
	
	// Chop off the left and right sides and slice it halfway into the hull:
	plane {x,2.91 inverse}
	plane {x,-2.91}
	plane {y,0 inverse}
	
	// This keeps the surround from going through the large cone in the deflector dish assembly
	object {Main_Deflector_Big_Cone(-HULL_THICKNESS-0.0001,0.0001)}
	object {Secondary_Hull_Section_1_Shell(-HULL_THICKNESS-0.0001,0.0001,false)}
	cylinder {<0,0,23.28>,<0,0,10.323>,12.8}	// Sections 2 & 3
	
	// Round off the left leading edge:
	difference {
		box {<0.7,-100,0.7>,<-0.7,100,-0.7>}
		cylinder {<-0.7,-100,-0.7>,<-0.7,100,-0.7>,0.7}
		translate <2.91,0,38.68>
	}
	 
	// Round off the right leading edge:
	difference {
		box {<0.7,-100,0.7>,<-0.7,100,-0.7>}
		cylinder {<0.7,-100,-0.7>,<0.7,100,-0.7>,0.7}
		translate <-2.91,0,38.68>
	}
	
	texture {
	  	quilted
		texture_map {
			[0.0 Metallic_Hull_Plating(ENTERPRISE_GRAY(81),0.78,0.20,0.02)]
			[1.0 Metallic_Hull_Plating(ENTERPRISE_GRAY(25),0.90,0.10,0.00)]
		}
		control0 0
		control1 0
   		scale <7,7,10.68>
   		translate z*33.96
	}
}		

#declare Secondary_Hull_Section_1_Outer_Hull = union {
	
	object {Secondary_Hull_Section_1_Shell(0,0,true)}
	object {Secondary_Hull_Section_1_Shell(-0.0001,0,false)}
	texture {Metallic_Hull_Plating(ENTERPRISE_GRAY(80),0.78,0.20,0.02)}	
}

#declare Secondary_Hull_Section_1_Inner_Hull = difference {
	
	/*
	object {Secondary_Hull_Section_1_Shell(-OUTER_HULL_THICKNESS-PORTHOLE_THICKNESS,0,false)}
	object {Secondary_Hull_Section_1_Shell(-HULL_THICKNESS,0.0001,false)}	
	object {Port_Starboard_Hole}
	texture {Metallic_Hull_Plating(ENTERPRISE_DARKGREEN,0.78,0.20,0.02)}
	*/
}

#declare Secondary_Hull_Section_1 = union {

	object {Secondary_Hull_Section_1_Outer_Hull}
	object {Secondary_Hull_Section_1_Inner_Hull}
	
	// Hull markings:
	difference {

		union {

			// Bulkhead #102 marker:
			intersection {
				object {Secondary_Hull_Section_1_Shell(0.0001,0,false)}
				object {Bulkhead_Number("102",0.55) rotate y*-90 translate <13.7,0,29.45> rotate z*-52}
				texture {Painted_Hull_Plating(ENTERPRISE_BLACK,0.75,0.24,0.01)}
			}

			intersection {
				object {Secondary_Hull_Section_1_Shell(0.0001,0,false)}
				object {Bulkhead_Number("102",0.55) rotate y*90 translate <-13.7,0,30.55> rotate z*52}
				texture {Painted_Hull_Plating(ENTERPRISE_BLACK,0.75,0.24,0.01)}
			}
		}
        
        // Have to difference out the underside or the markings cut into the hull!
		object {Secondary_Hull_Section_1_Shell(-0.0001,0.0001,false)}
	}
}

#macro Secondary_Hull_Section_2_Shell(height_offset,length_offset,use_textures)
	difference {
		
		#if (use_textures=true)
			union {
				#local panel_rot=0;
				#local plate_tx=texture {Metallic_Hull_Plating(ENTERPRISE_GRAY(80),0.76,0.22,0.02)};
				#local joint_tx=texture {Metallic_Hull_Plating(ENTERPRISE_GRAY(30),0.90,0.10,0.00)};
				#while (panel_rot<360)
					object {Conical_Hull_Plate(23.28+length_offset,13.4267+height_offset,10.8-length_offset,12.9233+height_offset,30,plate_tx,joint_tx,0,0,0) rotate z*panel_rot}
					#local panel_rot=panel_rot+30;
				#end
				cone {<0,0,23.28>,13.4267,<0,0,10.8>,12.9233 texture {Metallic_Hull_Plating(ENTERPRISE_GRAY(80),0.76,0.22,0.02)}}
			}
		#else
			cone {<0,0,23.28+length_offset>,13.4267+height_offset,<0,0,10.8-length_offset>,12.9233+height_offset}
		#end
		
		// Difference out the slots for the three boxy projections surrounding the main deflector dish:
		union {
			object {Port_Starboard_Hole}
			object {Ventral_Hole}
			#if (use_textures=true)
				texture {
				  	quilted
					texture_map {
						[0.0 Metallic_Hull_Plating(ENTERPRISE_GRAY(80),0.76,0.22,0.02)]
						[1.0 Metallic_Hull_Plating(ENTERPRISE_GRAY(30),0.90,0.10,0.00)]
					}
					control0 0
					control1 0
					#local xy_scale=sin(radians(15))*13.4267*2;
					matrix <
						xy_scale,0,0,
						0,xy_scale,0,
						0,0,23.28-10.8,
						0,xy_scale/2,23.28
					>
				}
			#end
		}
	}
#end

#macro Secondary_Hull_Section_2_Shell(height_offset,length_offset,use_textures)
	#if (use_textures=true)
		union {
			#local panel_rot=0;
			#local plate_tx=texture {Metallic_Hull_Plating(ENTERPRISE_GRAY(80),0.76,0.22,0.02)};
			#local joint_tx=texture {Metallic_Hull_Plating(ENTERPRISE_GRAY(30),0.90,0.10,0.00)};
			#while (panel_rot<360)
				object {Conical_Hull_Plate(23.28+length_offset,13.4267+height_offset,10.8-length_offset,12.9233+height_offset,30,plate_tx,joint_tx,0,0,0) rotate z*panel_rot}
				#local panel_rot=panel_rot+30;
			#end
			cone {<0,0,23.28>,13.4267,<0,0,10.8>,12.9233 texture {Metallic_Hull_Plating(ENTERPRISE_GRAY(80),0.76,0.22,0.02)}}
		}
	#else
		cone {<0,0,23.28+length_offset>,13.4267+height_offset,<0,0,10.8-length_offset>,12.9233+height_offset}
	#end		
#end

#declare Secondary_Hull_Section_2_Outer_Hull = union {
	
	difference {
		object {Secondary_Hull_Section_2_Shell(0,0,true)}
		difference {
			object {Secondary_Hull_Section_2_Shell(-OUTER_HULL_THICKNESS,0.0001,false)}
			plane {y,-11}
		}
		object {Port_Starboard_Hole}
		object {Ventral_Hole}
	}
	
	texture {Metallic_Hull_Plating(ENTERPRISE_GRAY(80),0.75,0.24,0.01)}
}

#declare Secondary_Hull_Section_2_Inner_Hull = union {
	
	// Inner hull:
	difference {
		
		object {Secondary_Hull_Section_2_Shell(-OUTER_HULL_THICKNESS-PORTHOLE_THICKNESS,0,false)}
		object {Secondary_Hull_Section_2_Shell(-HULL_THICKNESS,0.0001,false)}	
		plane {y,-11}
		object {Port_Starboard_Hole}
		object {Ventral_Hole}
		texture {Bulkhead_Texture}
	}
 
 	// Bulkheads: 	
	intersection {
		union {
			box {<-15,-15,10.8>,<15,15,10.8+BULKHEAD_THICKNESS/2>}	// Half of the bulkhead separating sections 2 & 3
			box {<-15,SECONDARY_HULL_DECK_16_Y_OFFSET,20>,<15,SECONDARY_HULL_DECK_15_Y_OFFSET+5,20-BULKHEAD_THICKNESS>}
			box {<-15,SECONDARY_HULL_DECK_18_Y_OFFSET,15>,<15,SECONDARY_HULL_DECK_15_Y_OFFSET+5,15-BULKHEAD_THICKNESS>}
			box {<-4+BULKHEAD_THICKNESS/2,SECONDARY_HULL_DECK_15_Y_OFFSET,10>,<-4-BULKHEAD_THICKNESS/2,SECONDARY_HULL_DECK_15_Y_OFFSET+5,24>}
			box {< 4+BULKHEAD_THICKNESS/2,SECONDARY_HULL_DECK_15_Y_OFFSET,10>,< 4-BULKHEAD_THICKNESS/2,SECONDARY_HULL_DECK_15_Y_OFFSET+5,24>}
			box {<-6+BULKHEAD_THICKNESS/2,SECONDARY_HULL_DECK_16_Y_OFFSET,10>,<-6-BULKHEAD_THICKNESS/2,SECONDARY_HULL_DECK_15_Y_OFFSET,24>}
			box {< 6+BULKHEAD_THICKNESS/2,SECONDARY_HULL_DECK_16_Y_OFFSET,10>,< 6-BULKHEAD_THICKNESS/2,SECONDARY_HULL_DECK_15_Y_OFFSET,24>}
			box {<-8+BULKHEAD_THICKNESS/2,SECONDARY_HULL_DECK_18_Y_OFFSET,10>,<-8-BULKHEAD_THICKNESS/2,SECONDARY_HULL_DECK_16_Y_OFFSET,24>}
			box {< 8+BULKHEAD_THICKNESS/2,SECONDARY_HULL_DECK_18_Y_OFFSET,10>,< 8-BULKHEAD_THICKNESS/2,SECONDARY_HULL_DECK_16_Y_OFFSET,24>}
		}
		object {Secondary_Hull_Section_2_Shell(-OUTER_HULL_THICKNESS,0,false)}
		texture {Bulkhead_Texture}
	}
	
	// Decks:
	intersection {
		union {
			box {<-15,SECONDARY_HULL_DECK_15_Y_OFFSET-DECK_THICKNESS/2,10>,<15,SECONDARY_HULL_DECK_15_Y_OFFSET+DECK_THICKNESS/2,24>}
			box {<-15,SECONDARY_HULL_DECK_16_Y_OFFSET-DECK_THICKNESS/2,10>,<15,SECONDARY_HULL_DECK_16_Y_OFFSET+DECK_THICKNESS/2,24>}
			box {<-15,SECONDARY_HULL_DECK_17_Y_OFFSET-DECK_THICKNESS/2,10>,<15,SECONDARY_HULL_DECK_17_Y_OFFSET+DECK_THICKNESS/2,24>}
			
			difference {
				box {<-15,SECONDARY_HULL_DECK_18_Y_OFFSET-DECK_THICKNESS/2,10>,<15,SECONDARY_HULL_DECK_18_Y_OFFSET+DECK_THICKNESS/2,24>}
				object {Port_Starboard_Hole}
			}
		}
		object {Secondary_Hull_Section_2_Shell(-OUTER_HULL_THICKNESS,0,false)}
		texture {Deck_Texture}
	}
	
	// Interior lighting:
	#if (NO_INTERIOR_LIGHTS=false)
		union {
			light_source {< 5,SECONDARY_HULL_DECK_15_Y_OFFSET+2,18.8> color <1.0,1.0,0.9> fade_distance 2.5 fade_power 1}
			light_source {<-5,SECONDARY_HULL_DECK_15_Y_OFFSET+2,18.8> color <1.0,0.9,0.9> fade_distance 2.5 fade_power 1}
			light_source {< 5,SECONDARY_HULL_DECK_15_Y_OFFSET+2,13.0> color <1.0,1.0,0.9> fade_distance 2.5 fade_power 1}
			light_source {<-5,SECONDARY_HULL_DECK_15_Y_OFFSET+2,13.0> color <1.0,0.9,0.9> fade_distance 2.5 fade_power 1}
			light_source {< 7,SECONDARY_HULL_DECK_16_Y_OFFSET+2,18.1> color <0.9,0.9,1.0> fade_distance 2.5 fade_power 1}		
			light_source {<-7,SECONDARY_HULL_DECK_16_Y_OFFSET+2,18.1> color <0.9,1.0,0.9> fade_distance 2.5 fade_power 1}		
			light_source {< 9,SECONDARY_HULL_DECK_17_Y_OFFSET+2,13.0> color <1.0,1.0,1.0> fade_distance 2.5 fade_power 1}		
			light_source {<-9,SECONDARY_HULL_DECK_17_Y_OFFSET+2,13.0> color <0.9,1.0,1.0> fade_distance 2.5 fade_power 1}		
			light_source {< 9,SECONDARY_HULL_DECK_18_Y_OFFSET+2,11.5> color <0.9,0.9,1.0> fade_distance 2.5 fade_power 1}		
			light_source {<-9,SECONDARY_HULL_DECK_18_Y_OFFSET+2,11.5> color <0.9,1.0,0.9> fade_distance 2.5 fade_power 1}		

			bounded_by {sphere {0,75}}
		}
	#end	
}
 
#declare Secondary_Hull_Section_2_Glass = difference {
	
	object {Secondary_Hull_Section_2_Shell(-OUTER_HULL_THICKNESS-0.0001,0,false)}
	object {Secondary_Hull_Section_2_Shell(-OUTER_HULL_THICKNESS-PORTHOLE_THICKNESS+0.0001,0.0001,false)}
	plane {z,20 inverse}
	plane {y,0}
	material {Porthole_Glass_Material}	
}

#declare Secondary_Hull_Section_2 = difference {
	
	union {
		
		object {Secondary_Hull_Section_2_Outer_Hull}
		object {Secondary_Hull_Section_2_Inner_Hull}
		
		// "E" pennants:
		difference {
		
			union {
				
				intersection {
					object {Secondary_Hull_Section_2_Shell(0.0001,0,false)}
					// Don't do the part of the pennant that is on the port and starboard deflector surrounds:
					difference {
						object {Secondary_Hull_Pennant_E translate x*12}
						plane {z,20.38681 inverse}
					}
					texture {Painted_Hull_Plating(ENTERPRISE_RED,0.75,0.24,0.01)}
				}

				intersection {
					object {Secondary_Hull_Section_2_Shell(0.0001,0,false)}
					difference {
						object {Secondary_Hull_Pennant_E translate x*-12}
						plane {z,20.38681 inverse}
					}
					texture {Painted_Hull_Plating(ENTERPRISE_RED,0.75,0.24,0.01)}
				} 

				// Pinstripes:
				intersection {
					object {Secondary_Hull_Section_2_Shell(0.0001,0,false)}
					object {Dorsal_Pinstripes}
					texture {Painted_Hull_Plating(ENTERPRISE_RED,0.75,0.24,0.01)}
				} 
			}
			
			object {Secondary_Hull_Section_2_Shell(-HULL_THICKNESS,0.0001,false) texture {Bulkhead_Texture}}
		}
	}
	
	// Difference out the portholes:
	#if (NO_PORTHOLES=false)

		// Deck 15 portholes:
		object {Rectangular_Porthole(1.65,0.725,1,2) translate <13,0,13> rotate z*62.204}
		object {Rectangular_Porthole(1.65,0.725,1,2) translate <-13,0,13> rotate z*-62.204}
		object {Round_Porthole(0.3625,1,2) translate <13.2465,0,18.8> rotate z*60.2418}
		object {Round_Porthole(0.3625,1,2) translate <-13.2465,0,18.8> rotate z*-60.2418}

		// Deck 16 portholes:
		object {Round_Porthole(0.3625,1,2) translate <13.2,0,17.4> rotate z*41.8043}
		object {Round_Porthole(0.3625,1,2) translate <-13.2,0,17.4> rotate z*-41.8043}
		object {Round_Porthole(0.3625,1,2) translate <13.2465,0,18.8> rotate z*41.63}
		object {Round_Porthole(0.3625,1,2) translate <-13.2465,0,18.8> rotate z*-41.63}

		// Deck 17 portholes:
		object {Rectangular_Porthole(1.65,0.725,1,2) translate <13,0,13> rotate z*29.4926}
		object {Rectangular_Porthole(1.65,0.725,1,2) translate <-13,0,13> rotate z*-29.4926}

		// Deck 18 portholes:
		object {Round_Porthole(0.3625,1,2) translate <12.95,0,11.5> rotate z*17.9917}
		object {Round_Porthole(0.3625,1,2) translate <-12.95,0,11.5> rotate z*-17.9917}

	#end
}

#macro Secondary_Hull_Section_3_Shell(height_offset,length_offset,use_textures)
	difference {
		#if (use_textures=true)
			union {
				#local panel_rot=0;
				#local plate_tx=texture {Metallic_Hull_Plating(ENTERPRISE_GRAY(80),0.76,0.22,0.02)};
				#local joint_tx=texture {Metallic_Hull_Plating(ENTERPRISE_GRAY(30),0.90,0.10,0.00)};
				#while (panel_rot<360)
					object {Conical_Hull_Plate(10.8+length_offset,12.9233+height_offset,-4.7-length_offset,12.17+height_offset,30,plate_tx,joint_tx,0,0,0) rotate z*panel_rot}
					#local panel_rot=panel_rot+30;
				#end
			}
		#else
			cone {<0,0,10.8+length_offset>,12.9233+height_offset,<0,0,-4.7-length_offset>,12.17+height_offset}
		#end
		
		object {Ventral_Hole
			#if (use_textures=true)
				texture {
				  	quilted
					texture_map {
						[0.0 Metallic_Hull_Plating(ENTERPRISE_GRAY(80),0.76,0.22,0.02)]
						[1.0 Metallic_Hull_Plating(ENTERPRISE_GRAY(30),0.90,0.10,0.00)]
					}
					control0 0
					control1 0
					#local xy_scale=sin(radians(15))*12.9233*2;
					matrix <
						xy_scale,0,0,
						0,xy_scale,0,
						0,0,12.9233--4.7,
						0,xy_scale/2,-4.7
					>
				}
			#end
		}
	}	
#end

#declare Secondary_Hull_Section_3_Outer_Hull = difference {
	
	object {Secondary_Hull_Section_3_Shell(0,0,true)}
	object {Secondary_Hull_Section_3_Shell(-OUTER_HULL_THICKNESS,0.0001,false)}	
}

#declare Secondary_Hull_Section_3_Inner_Hull = union {
	
	// Inner hull:
	difference {
		object {Secondary_Hull_Section_3_Shell(-OUTER_HULL_THICKNESS-PORTHOLE_THICKNESS,0,false)}
		object {Secondary_Hull_Section_3_Shell(-HULL_THICKNESS,0.0001,false)}	
		texture {Bulkhead_Texture}
	}
 
	// Decks:
	intersection {
		union {
			box {<-15,SECONDARY_HULL_DECK_15_Y_OFFSET-DECK_THICKNESS/2,-5>,<15,SECONDARY_HULL_DECK_15_Y_OFFSET+DECK_THICKNESS/2,11>}
			box {<-15,SECONDARY_HULL_DECK_16_Y_OFFSET-DECK_THICKNESS/2,-5>,<15,SECONDARY_HULL_DECK_16_Y_OFFSET+DECK_THICKNESS/2,11>}
			box {<-15,SECONDARY_HULL_DECK_17_Y_OFFSET-DECK_THICKNESS/2,-5>,<15,SECONDARY_HULL_DECK_17_Y_OFFSET+DECK_THICKNESS/2,11>}
			box {<-15,SECONDARY_HULL_DECK_18_Y_OFFSET-DECK_THICKNESS/2,-5>,<15,SECONDARY_HULL_DECK_18_Y_OFFSET+DECK_THICKNESS/2,11>}
			box {<-15,SECONDARY_HULL_DECK_19_Y_OFFSET-DECK_THICKNESS/2,-5>,<15,SECONDARY_HULL_DECK_19_Y_OFFSET+DECK_THICKNESS/2,11>}
			box {<-15,SECONDARY_HULL_DECK_20_Y_OFFSET-DECK_THICKNESS/2,-5>,<15,SECONDARY_HULL_DECK_20_Y_OFFSET+DECK_THICKNESS/2,11>}
			box {<-15,SECONDARY_HULL_DECK_21_Y_OFFSET-DECK_THICKNESS/2,-5>,<15,SECONDARY_HULL_DECK_21_Y_OFFSET+DECK_THICKNESS/2,11>}
			box {<-15,SECONDARY_HULL_DECK_22_Y_OFFSET-DECK_THICKNESS/2,-5>,<15,SECONDARY_HULL_DECK_22_Y_OFFSET+DECK_THICKNESS/2,11>}
			box {<-15,SECONDARY_HULL_DECK_23_Y_OFFSET-DECK_THICKNESS/2,-5>,<15,SECONDARY_HULL_DECK_23_Y_OFFSET+DECK_THICKNESS/2,11>}
		}
		object {Secondary_Hull_Section_3_Shell(-OUTER_HULL_THICKNESS,0,false)}
		texture {Deck_Texture}
	}
	
 	// Bulkheads: 	
	intersection {
		union {
			box {<-15,-15,-4.7>,<15,15,-4.7+BULKHEAD_THICKNESS/2>}	// Half of the bulkhead separating sections 3 & 4
			box {<-15,-15,10.8>,<15,15,10.8-BULKHEAD_THICKNESS/2>}	// Half of the bulkhead separating sections 2 & 3
			box {<-15,SECONDARY_HULL_DECK_20_Y_OFFSET,0.10-BULKHEAD_THICKNESS/2>,<15,SECONDARY_HULL_DECK_16_Y_OFFSET,0.10+BULKHEAD_THICKNESS/2>}
			box {<-15,SECONDARY_HULL_DECK_23_Y_OFFSET,6.34-BULKHEAD_THICKNESS/2>,<15,SECONDARY_HULL_DECK_15_Y_OFFSET,6.34+BULKHEAD_THICKNESS/2>}
			box {<-15,SECONDARY_HULL_DECK_22_Y_OFFSET,3.15-BULKHEAD_THICKNESS/2>,<15,SECONDARY_HULL_DECK_17_Y_OFFSET,3.15+BULKHEAD_THICKNESS/2>}
			box {<-6+BULKHEAD_THICKNESS/2,SECONDARY_HULL_DECK_16_Y_OFFSET,-5>,<-6-BULKHEAD_THICKNESS/2,SECONDARY_HULL_DECK_15_Y_OFFSET,11>}
			box {< 6+BULKHEAD_THICKNESS/2,SECONDARY_HULL_DECK_16_Y_OFFSET,-5>,< 6-BULKHEAD_THICKNESS/2,SECONDARY_HULL_DECK_15_Y_OFFSET,11>}
			box {<-8+BULKHEAD_THICKNESS/2,SECONDARY_HULL_DECK_17_Y_OFFSET,-5>,<-8-BULKHEAD_THICKNESS/2,SECONDARY_HULL_DECK_16_Y_OFFSET,11>}
			box {< 8+BULKHEAD_THICKNESS/2,SECONDARY_HULL_DECK_17_Y_OFFSET,-5>,< 8-BULKHEAD_THICKNESS/2,SECONDARY_HULL_DECK_16_Y_OFFSET,11>}
			box {<-9+BULKHEAD_THICKNESS/2,SECONDARY_HULL_DECK_21_Y_OFFSET,-5>,<-9-BULKHEAD_THICKNESS/2,SECONDARY_HULL_DECK_17_Y_OFFSET,11>}
			box {< 9+BULKHEAD_THICKNESS/2,SECONDARY_HULL_DECK_21_Y_OFFSET,-5>,< 9-BULKHEAD_THICKNESS/2,SECONDARY_HULL_DECK_17_Y_OFFSET,11>}
			box {<-8+BULKHEAD_THICKNESS/2,SECONDARY_HULL_DECK_22_Y_OFFSET,-5>,<-8-BULKHEAD_THICKNESS/2,SECONDARY_HULL_DECK_21_Y_OFFSET,11>}
			box {< 8+BULKHEAD_THICKNESS/2,SECONDARY_HULL_DECK_22_Y_OFFSET,-5>,< 8-BULKHEAD_THICKNESS/2,SECONDARY_HULL_DECK_21_Y_OFFSET,11>}
			box {<-6+BULKHEAD_THICKNESS/2,SECONDARY_HULL_DECK_23_Y_OFFSET,-5>,<-6-BULKHEAD_THICKNESS/2,SECONDARY_HULL_DECK_22_Y_OFFSET,11>}
			box {< 6+BULKHEAD_THICKNESS/2,SECONDARY_HULL_DECK_23_Y_OFFSET,-5>,< 6-BULKHEAD_THICKNESS/2,SECONDARY_HULL_DECK_22_Y_OFFSET,11>}
		}
		object {Secondary_Hull_Section_3_Shell(-OUTER_HULL_THICKNESS,0,false)}
		texture {Bulkhead_Texture}
	}

	// Interior lighting:
	#if (NO_INTERIOR_LIGHTS=false)
		union {
			light_source {<  7,SECONDARY_HULL_DECK_16_Y_OFFSET+2,9.115> color <1.0,0.9,0.9> fade_distance 2.5 fade_power 1}		
			light_source {< -7,SECONDARY_HULL_DECK_16_Y_OFFSET+2,9.115> color <1.0,0.9,1.0> fade_distance 2.5 fade_power 1}		
			light_source {<  9,SECONDARY_HULL_DECK_17_Y_OFFSET+2,-2.30> color <1.0,1.0,1.0> fade_distance 2.5 fade_power 1}		
			light_source {< -9,SECONDARY_HULL_DECK_17_Y_OFFSET+2,-2.30> color <1.0,1.0,0.9> fade_distance 2.5 fade_power 1}		
			light_source {< 10,SECONDARY_HULL_DECK_18_Y_OFFSET+2, 7.68> color <1.0,0.9,0.9> fade_distance 2.5 fade_power 1}		
			light_source {<-10,SECONDARY_HULL_DECK_18_Y_OFFSET+2, 7.68> color <0.9,1.0,1.0> fade_distance 2.5 fade_power 1}		
			light_source {< 10,SECONDARY_HULL_DECK_18_Y_OFFSET+2, 1.30> color <1.0,1.0,1.0> fade_distance 2.5 fade_power 1}		
			light_source {<-10,SECONDARY_HULL_DECK_18_Y_OFFSET+2, 1.30> color <0.9,1.0,0.9> fade_distance 2.5 fade_power 1}		
			light_source {< 10,SECONDARY_HULL_DECK_18_Y_OFFSET+2,-2.30> color <1.0,0.9,1.0> fade_distance 2.5 fade_power 1}		
			light_source {<-10,SECONDARY_HULL_DECK_18_Y_OFFSET+2,-2.30> color <1.0,0.9,1.0> fade_distance 2.5 fade_power 1}		
			light_source {< 10,SECONDARY_HULL_DECK_19_Y_OFFSET+2,-2.30> color <0.9,0.9,1.0> fade_distance 2.5 fade_power 1}		
			light_source {<-10,SECONDARY_HULL_DECK_19_Y_OFFSET+2,-2.30> color <1.0,1.0,0.9> fade_distance 2.5 fade_power 1}		
			light_source {< 10,SECONDARY_HULL_DECK_20_Y_OFFSET+2,-3.50> color <1.0,1.0,0.9> fade_distance 2.5 fade_power 1}		
			light_source {<-10,SECONDARY_HULL_DECK_20_Y_OFFSET+2,-3.50> color <0.9,0.9,1.0> fade_distance 2.5 fade_power 1}		
			light_source {<  9,SECONDARY_HULL_DECK_22_Y_OFFSET+2, 5.00> color <1.0,1.0,1.0> fade_distance 2.5 fade_power 1}		
			light_source {< -9,SECONDARY_HULL_DECK_22_Y_OFFSET+2, 8.60> color <1.0,1.0,0.9> fade_distance 2.5 fade_power 1}		
			light_source {<  7,SECONDARY_HULL_DECK_23_Y_OFFSET+2, 9.40> color <1.0,1.0,1.0> fade_distance 2.5 fade_power 1}		
			light_source {< -7,SECONDARY_HULL_DECK_23_Y_OFFSET+2, 9.40> color <0.9,1.0,1.0> fade_distance 2.5 fade_power 1}		

			bounded_by {sphere {0,75}}
		}
	#end
}

#declare Secondary_Hull_Section_3_Glass = difference {
	
	object {Secondary_Hull_Section_3_Shell(-OUTER_HULL_THICKNESS-0.0001,0,false)}
	object {Secondary_Hull_Section_3_Shell(-OUTER_HULL_THICKNESS-PORTHOLE_THICKNESS+0.0001,0.0001,false)}
	plane {y,-12}
	material {Porthole_Glass_Material}	
}

#declare Secondary_Hull_Section_3 = difference {
	
	union {
		object {Secondary_Hull_Section_3_Outer_Hull}
		object {Secondary_Hull_Section_3_Inner_Hull}
  
  		// "E" pennants and hull markings:
  		difference {
  			
  			union {
  			    
  			    // Starboard pennant:
				intersection {
					object {Secondary_Hull_Section_3_Shell(0.0001,0,false)}
					object {Secondary_Hull_Pennant_E translate x*12}
					texture {Painted_Hull_Plating(ENTERPRISE_RED,0.75,0.24,0.01)}
				}
		
		  		// Port pennant:
				intersection {
					object {Secondary_Hull_Section_3_Shell(0.0001,0,false)}
					object {Secondary_Hull_Pennant_E translate x*-12}
					texture {Painted_Hull_Plating(ENTERPRISE_RED,0.75,0.24,0.01)}
				}

				// The yellow circle with the red ring around it on the ventral side:
				intersection {
					object {Secondary_Hull_Section_3_Shell(0.0001,0,false)}
					object {Round_Hatch}
					texture {
					  	quilted
						texture_map {
							[0.0 Metallic_Hull_Plating(ENTERPRISE_YELLOW,0.78,0.20,0.02)]
							[1.0 Metallic_Hull_Plating(ENTERPRISE_GRAY(0),0.90,0.10,0.00)]
						}
						control0 0
						control1 0
				   		scale <4,4,8>
				   		//translate z*4
					}
				}

				intersection {
					object {Secondary_Hull_Section_3_Shell(0.0001,0,false)}
					object {Round_Hatch_Outline}
					texture {Painted_Hull_Plating(ENTERPRISE_RED,0.75,0.24,0.01)}
				}

				// The T-shaped hatch:
				intersection {
					object {Secondary_Hull_Section_3_Shell(0.0001,0,false)}
					object {T_Hatch}
					texture {
					  	quilted
						texture_map {
							[0.0 Metallic_Hull_Plating(ENTERPRISE_GRAY(60),0.78,0.20,0.02)]
							[1.0 Metallic_Hull_Plating(ENTERPRISE_GRAY(0),0.90,0.10,0.00)]
						}
						control0 0
						control1 0
				   		scale <4,4,8>
					}
				}								

				intersection {
					object {Secondary_Hull_Section_3_Shell(0.0001,0,false)}
					object {T_Hatch_Outline}
					texture {Metallic_Hull_Plating(ENTERPRISE_GRAY(50),0.75,0.24,0.01)}
				}					

				// Bulkhead #705 marker:
				intersection {
					object {Secondary_Hull_Section_3_Shell(0.0001,0,false)}
					object {Bulkhead_Number("705",1.00) rotate y*-90 translate <15,0,2.25> rotate z*-50}
					texture {Painted_Hull_Plating(ENTERPRISE_BLACK,0.75,0.24,0.01)}
				}
	
				intersection {
					object {Secondary_Hull_Section_3_Shell(0.0001,0,false)}
					object {Bulkhead_Number("705",1.00) rotate y*90 translate <-15,0,4.25> rotate z*50}
					texture {Painted_Hull_Plating(ENTERPRISE_BLACK,0.75,0.24,0.01)}
				}

				// Pinstripes:
				intersection {
					object {Secondary_Hull_Section_3_Shell(0.0001,0,false)}
					object {Dorsal_Pinstripes}
					texture {Painted_Hull_Plating(ENTERPRISE_RED,0.75,0.24,0.01)}
				} 
				
			}
			
			object {Secondary_Hull_Section_3_Shell(-HULL_THICKNESS,0.0001,false) texture {Bulkhead_Texture}}	
		}
	}

	// Difference out the portholes:
	#if (NO_PORTHOLES=false)

		// Deck 16 portholes:
		object {Rectangular_Porthole(1.65,0.725,1,2) translate <12.7718,0,7.68> rotate z*43.5584}
		object {Rectangular_Porthole(1.65,0.725,1,2) translate <-12.7718,0,7.68> rotate z*-43.5584}
		object {Round_Porthole(0.3625,1,2) translate <12.8893,0,10.1> rotate z*43.0576}
		object {Round_Porthole(0.3625,1,2) translate <-12.8893,0,10.1> rotate z*-43.0576}

		// Deck 17 portholes:
		object {Rectangular_Porthole(1.65,0.725,1,2) translate <12.28,0,-2.3> rotate z*31.4109}
		object {Rectangular_Porthole(1.65,0.725,1,2) translate <-12.28,0,-2.3> rotate z*-31.4109}

		// Deck 18 portholes:
		object {Rectangular_Porthole(1.65,0.725,1,2) translate <12.23,0,-3.5> rotate z*19.0907}
		object {Rectangular_Porthole(1.65,0.725,1,2) translate <-12.23,0,-3.5> rotate z*-19.0907}
		object {Rectangular_Porthole(1.65,0.725,1,2) translate <12.34,0,-1.1> rotate z*18.9139}
		object {Rectangular_Porthole(1.65,0.725,1,2) translate <-12.34,0,-1.1> rotate z*-18.9139}
		object {Rectangular_Porthole(1.65,0.725,1,2) translate <12.46,0,1.3> rotate z*18.725}
		object {Rectangular_Porthole(1.65,0.725,1,2) translate <-12.46,0,1.3> rotate z*-18.725}
		object {Rectangular_Porthole(1.65,0.725,1,2) translate <12.77,0,7.68> rotate z*18.2542}
		object {Rectangular_Porthole(1.65,0.725,1,2) translate <-12.77,0,7.68> rotate z*-18.2542}

		// Deck 19 portholes:
		object {Round_Porthole(0.3625,1,2) translate <12.23,0,-3.5> rotate z*7.045}
		object {Round_Porthole(0.3625,1,2) translate <-12.23,0,-3.5> rotate z*-7.045}
		object {Rectangular_Porthole(1.65,0.725,1,2) translate <12.34,0,-1.1> rotate z*6.9819}
		object {Rectangular_Porthole(1.65,0.725,1,2) translate <-12.34,0,-1.1> rotate z*-6.9819}

		// Deck 20 portholes:
		object {Rectangular_Porthole(1.65,0.725,1,2) translate <12.23,0,-3.5> rotate z*-4.6901}
		object {Rectangular_Porthole(1.65,0.725,1,2) translate <-12.23,0,-3.5> rotate z*4.6901}

		// Deck 22 portholes:
		object {Rectangular_Porthole(1.65,0.725,1,2) translate <12.65,0,5> rotate z*-28.3141}
		object {Rectangular_Porthole(1.65,0.725,1,2) translate <-12.65,0,5> rotate z*28.3141}
		object {Round_Porthole(0.3625,1,2) translate <12.825,0,8.6> rotate z*-27.894}
		object {Round_Porthole(0.3625,1,2) translate <-12.825,0,8.6> rotate z*27.894}

		// Deck 23 portholes:
		object {Rectangular_Porthole(1.65,0.725,1,2) translate <12.85,0,9.4> rotate z*-41.4125}
		object {Rectangular_Porthole(1.65,0.725,1,2) translate <-12.85,0,9.4> rotate z*41.4125}

	#end

}

#macro Secondary_Hull_Section_4_Shell(height_offset,length_offset)
	cone {<0,0,-4.7+length_offset>,12.17+height_offset,<0,0,-14-length_offset>,11.6067+height_offset}
#end

#declare Secondary_Hull_Section_4_Outer_Hull = difference {
	
	object {Secondary_Hull_Section_4_Shell(0,0)}
	object {Secondary_Hull_Section_4_Shell(-OUTER_HULL_THICKNESS,0.0001)}	
}

#declare Secondary_Hull_Section_4_Inner_Hull = union {
	
	// Inner hull:
	difference {
		object {Secondary_Hull_Section_4_Shell(-OUTER_HULL_THICKNESS-PORTHOLE_THICKNESS,0)}
		object {Secondary_Hull_Section_4_Shell(-HULL_THICKNESS,0.0001)}	
		texture {Bulkhead_Texture}
	}

	// Decks:
	intersection {
		union {
			box {<-15,SECONDARY_HULL_DECK_15_Y_OFFSET-DECK_THICKNESS/2,-14>,<15,SECONDARY_HULL_DECK_15_Y_OFFSET+DECK_THICKNESS/2,-4.7>}
			box {<-15,SECONDARY_HULL_DECK_16_Y_OFFSET-DECK_THICKNESS/2,-14>,<15,SECONDARY_HULL_DECK_16_Y_OFFSET+DECK_THICKNESS/2,-4.7>}
			box {<-15,SECONDARY_HULL_DECK_17_Y_OFFSET-DECK_THICKNESS/2,-14>,<15,SECONDARY_HULL_DECK_17_Y_OFFSET+DECK_THICKNESS/2,-4.7>}
			box {<-15,SECONDARY_HULL_DECK_18_Y_OFFSET-DECK_THICKNESS/2,-14>,<15,SECONDARY_HULL_DECK_18_Y_OFFSET+DECK_THICKNESS/2,-4.7>}
			box {<-15,SECONDARY_HULL_DECK_19_Y_OFFSET-DECK_THICKNESS/2,-14>,<15,SECONDARY_HULL_DECK_19_Y_OFFSET+DECK_THICKNESS/2,-4.7>}
			box {<-15,SECONDARY_HULL_DECK_20_Y_OFFSET-DECK_THICKNESS/2,-14>,<15,SECONDARY_HULL_DECK_20_Y_OFFSET+DECK_THICKNESS/2,-4.7>}
			box {<-15,SECONDARY_HULL_DECK_21_Y_OFFSET-DECK_THICKNESS/2,-14>,<15,SECONDARY_HULL_DECK_21_Y_OFFSET+DECK_THICKNESS/2,-4.7>}
			box {<-15,SECONDARY_HULL_DECK_22_Y_OFFSET-DECK_THICKNESS/2,-14>,<15,SECONDARY_HULL_DECK_22_Y_OFFSET+DECK_THICKNESS/2,-4.7>}
			box {<-15,SECONDARY_HULL_DECK_23_Y_OFFSET-DECK_THICKNESS/2,-14>,<15,SECONDARY_HULL_DECK_23_Y_OFFSET+DECK_THICKNESS/2,-4.7>}
		}
		object {Secondary_Hull_Section_4_Shell(-OUTER_HULL_THICKNESS,0)}
		texture {Deck_Texture}
	}
	
 	// Bulkheads: 	
	intersection {
		union {
			box {<-15,-15,-4.7>,<15,15,-4.7-BULKHEAD_THICKNESS/2>}	// Half of the bulkhead separating sections 3 & 4
			box {<-15,-15,-14>,<15,15,-14+BULKHEAD_THICKNESS/2>}	// Half of the bulkhead separating sections 4 & 5
			box {<-15,SECONDARY_HULL_DECK_22_Y_OFFSET,-8.5-BULKHEAD_THICKNESS/2>,<15,SECONDARY_HULL_DECK_17_Y_OFFSET,-8.5+BULKHEAD_THICKNESS/2>}
			box {<-8+BULKHEAD_THICKNESS/2,SECONDARY_HULL_DECK_20_Y_OFFSET,-14>,<-8-BULKHEAD_THICKNESS/2,SECONDARY_HULL_DECK_17_Y_OFFSET,-4.7>}
			box {< 8+BULKHEAD_THICKNESS/2,SECONDARY_HULL_DECK_20_Y_OFFSET,-14>,< 8-BULKHEAD_THICKNESS/2,SECONDARY_HULL_DECK_17_Y_OFFSET,-4.7>}
			box {<-6+BULKHEAD_THICKNESS/2,SECONDARY_HULL_DECK_22_Y_OFFSET,-14>,<-6-BULKHEAD_THICKNESS/2,SECONDARY_HULL_DECK_21_Y_OFFSET,-4.7>}
			box {< 6+BULKHEAD_THICKNESS/2,SECONDARY_HULL_DECK_22_Y_OFFSET,-14>,< 6-BULKHEAD_THICKNESS/2,SECONDARY_HULL_DECK_21_Y_OFFSET,-4.7>}
		}
		object {Secondary_Hull_Section_4_Shell(-OUTER_HULL_THICKNESS,0)}
		texture {Bulkhead_Texture}
	}

	// Interior lighting:
	#if (NO_INTERIOR_LIGHTS=false)
		union {
			light_source {< 9,SECONDARY_HULL_DECK_18_Y_OFFSET+2, -5.90> color <1.0,1.0,0.9> fade_distance 2.5 fade_power 1}		
			light_source {<-9,SECONDARY_HULL_DECK_20_Y_OFFSET+2, -5.90> color <0.9,1.0,1.0> fade_distance 2.5 fade_power 1}		
			light_source {< 7,SECONDARY_HULL_DECK_22_Y_OFFSET+2,-10.50> color <1.0,0.9,1.0> fade_distance 2.5 fade_power 1}		
			light_source {<-7,SECONDARY_HULL_DECK_22_Y_OFFSET+2,-10.50> color <0.9,1.0,0.9> fade_distance 2.5 fade_power 1}		

			bounded_by {sphere {0,75}}
		}
	#end
}

#declare Secondary_Hull_Section_4_Glass = difference {
	
	object {Secondary_Hull_Section_4_Shell(-OUTER_HULL_THICKNESS-0.0001,0)}
	object {Secondary_Hull_Section_4_Shell(-OUTER_HULL_THICKNESS-PORTHOLE_THICKNESS+0.0001,0.0001)}
	plane {y,-12}
	material {Porthole_Glass_Material}	
}

#declare Secondary_Hull_Section_4 = difference {
	
	union {
		
		object {Secondary_Hull_Section_4_Outer_Hull}
		object {Secondary_Hull_Section_4_Inner_Hull}

		union {
			#local panel_rot=0;
			#local plate_tx=texture {Metallic_Hull_Plating(ENTERPRISE_GRAY(82),0.76,0.22,0.02)};
			#local joint_tx=texture {Metallic_Hull_Plating(ENTERPRISE_GRAY(30),0.90,0.10,0.00)};
			#while (panel_rot<360)
				object {Conical_Hull_Plate(-4.7,12.17,-14,11.6067,30,plate_tx,joint_tx,0,0,0) rotate z*panel_rot}
				#local panel_rot=panel_rot+30;
			#end
		}
		
		// "E" pennants and other hull markings:
		difference {
		
			union {
			
				// Starboard pennant:
				intersection {
					object {Secondary_Hull_Section_4_Shell(0.0001,0)}
					object {Secondary_Hull_Pennant_E translate x*12}
					texture {Painted_Hull_Plating(ENTERPRISE_RED,0.75,0.24,0.01)}
				}
		
				// Port pennant:
				intersection {
					object {Secondary_Hull_Section_4_Shell(0.0001,0)}
					object {Secondary_Hull_Pennant_E translate x*-12}
					texture {Painted_Hull_Plating(ENTERPRISE_RED,0.75,0.24,0.01)}
				}

				// The T-shaped hatch:
				intersection {
					object {Secondary_Hull_Section_4_Shell(0.0001,0)}
					object {T_Hatch}
					texture {
					  	quilted
						texture_map {
							[0.0 Metallic_Hull_Plating(ENTERPRISE_GRAY(60),0.78,0.20,0.02)]
							[1.0 Metallic_Hull_Plating(ENTERPRISE_GRAY(0),0.90,0.10,0.00)]
						}
						control0 0
						control1 0
				   		scale <4,4,8>
				   		//translate z*-6.2
					}
				}								

				intersection {
					object {Secondary_Hull_Section_4_Shell(0.0001,0)}
					object {T_Hatch_Outline}
					texture {Metallic_Hull_Plating(ENTERPRISE_GRAY(50),0.75,0.24,0.01)}
				}								
				
				// Pinstripes:
				intersection {
					object {Secondary_Hull_Section_4_Shell(0.0001,0)}
					object {Dorsal_Pinstripes}
					texture {Painted_Hull_Plating(ENTERPRISE_RED,0.75,0.24,0.01)}
				} 				
			}

			object {Secondary_Hull_Section_4_Shell(-HULL_THICKNESS,0.0001) texture {Bulkhead_Texture}}
		}
	}

	// Difference out the portholes:
	#if (NO_PORTHOLES=false)

		// Deck 18 portholes:
		object {Rectangular_Porthole(1.65,0.725,1,2) translate <12.1,0,-5.9> rotate z*19.304}
		object {Rectangular_Porthole(1.65,0.725,1,2) translate <-12.1,0,-5.9> rotate z*-19.304}
		
		// Deck 20 portholes:
		object {Rectangular_Porthole(1.65,0.725,1,2) translate <12.1,0,-5.9> rotate z*-4.7406}
		object {Rectangular_Porthole(1.65,0.725,1,2) translate <-12.1,0,-5.9> rotate z*4.7406}
		
		// Deck 22 portholes:
		object {Round_Porthole(0.3625,1,2) translate <11.825,0,-10.5> rotate z*-30.4907}
		object {Round_Porthole(0.3625,1,2) translate <-11.825,0,-10.5> rotate z*30.4907}

	#end
}

#macro Secondary_Hull_Section_5_Shell(height_offset,length_offset)
	cone {<0,0,-14+length_offset>,11.6067+height_offset,<0,0,-26.5-length_offset>,10.768+height_offset}
#end

#declare Secondary_Hull_Section_5_Outer_Hull = difference {
	
	object {Secondary_Hull_Section_5_Shell(0,0)}
	object {Secondary_Hull_Section_5_Shell(-OUTER_HULL_THICKNESS,0.0001)}	
}

#declare Secondary_Hull_Section_5_Inner_Hull = union {
	
	// Inner hull:
	difference {
		object {Secondary_Hull_Section_5_Shell(-OUTER_HULL_THICKNESS-PORTHOLE_THICKNESS,0)}
		object {Secondary_Hull_Section_5_Shell(-HULL_THICKNESS,0.0001)}	
		texture {Bulkhead_Texture}
	}

	// Decks:
	intersection {
		union {
			box {<-15,SECONDARY_HULL_DECK_15_Y_OFFSET-DECK_THICKNESS/2,-26.5>,<15,SECONDARY_HULL_DECK_15_Y_OFFSET+DECK_THICKNESS/2,-14>}
			box {<-15,SECONDARY_HULL_DECK_16_Y_OFFSET-DECK_THICKNESS/2,-26.5>,<15,SECONDARY_HULL_DECK_16_Y_OFFSET+DECK_THICKNESS/2,-14>}
			box {<-15,SECONDARY_HULL_DECK_17_Y_OFFSET-DECK_THICKNESS/2,-26.5>,<15,SECONDARY_HULL_DECK_17_Y_OFFSET+DECK_THICKNESS/2,-14>}
			box {<-15,SECONDARY_HULL_DECK_18_Y_OFFSET-DECK_THICKNESS/2,-26.5>,<15,SECONDARY_HULL_DECK_18_Y_OFFSET+DECK_THICKNESS/2,-14>}
			box {<-15,SECONDARY_HULL_DECK_19_Y_OFFSET-DECK_THICKNESS/2,-26.5>,<15,SECONDARY_HULL_DECK_19_Y_OFFSET+DECK_THICKNESS/2,-14>}
			box {<-15,SECONDARY_HULL_DECK_20_Y_OFFSET-DECK_THICKNESS/2,-26.5>,<15,SECONDARY_HULL_DECK_20_Y_OFFSET+DECK_THICKNESS/2,-14>}
			box {<-15,SECONDARY_HULL_DECK_21_Y_OFFSET-DECK_THICKNESS/2,-26.5>,<15,SECONDARY_HULL_DECK_21_Y_OFFSET+DECK_THICKNESS/2,-14>}
			box {<-15,SECONDARY_HULL_DECK_22_Y_OFFSET-DECK_THICKNESS/2,-26.5>,<15,SECONDARY_HULL_DECK_22_Y_OFFSET+DECK_THICKNESS/2,-14>}
			box {<-15,SECONDARY_HULL_DECK_23_Y_OFFSET-DECK_THICKNESS/2,-26.5>,<15,SECONDARY_HULL_DECK_23_Y_OFFSET+DECK_THICKNESS/2,-14>}
		}
		object {Secondary_Hull_Section_5_Shell(-OUTER_HULL_THICKNESS,0)}
		texture {Deck_Texture}
	}
	
 	// Bulkheads: 	
	intersection {
		union {
			box {<-15,-15,-14>,<15,15,-14-BULKHEAD_THICKNESS/2>}	// Half of the bulkhead separating sections 4 & 5
			box {<-15,-15,-26.5>,<15,15,-26.5+BULKHEAD_THICKNESS/2>}	// Half of the bulkhead separating sections 5 & 6
			box {<-15,SECONDARY_HULL_DECK_20_Y_OFFSET,-17.00-BULKHEAD_THICKNESS/2>,<15,SECONDARY_HULL_DECK_17_Y_OFFSET,-17.00+BULKHEAD_THICKNESS/2>}
			box {<-15,SECONDARY_HULL_DECK_19_Y_OFFSET,-20.50-BULKHEAD_THICKNESS/2>,<15,SECONDARY_HULL_DECK_18_Y_OFFSET,-20.50+BULKHEAD_THICKNESS/2>}
			box {<-15,SECONDARY_HULL_DECK_20_Y_OFFSET,-23.15-BULKHEAD_THICKNESS/2>,<15,SECONDARY_HULL_DECK_19_Y_OFFSET,-23.15+BULKHEAD_THICKNESS/2>}
			box {<-7+BULKHEAD_THICKNESS/2,SECONDARY_HULL_DECK_20_Y_OFFSET,-26.5>,<-7-BULKHEAD_THICKNESS/2,SECONDARY_HULL_DECK_19_Y_OFFSET,-14>}
			box {< 7+BULKHEAD_THICKNESS/2,SECONDARY_HULL_DECK_20_Y_OFFSET,-26.5>,< 7-BULKHEAD_THICKNESS/2,SECONDARY_HULL_DECK_19_Y_OFFSET,-14>}
			box {<-5+BULKHEAD_THICKNESS/2,SECONDARY_HULL_DECK_19_Y_OFFSET,-26.5>,<-5-BULKHEAD_THICKNESS/2,SECONDARY_HULL_DECK_18_Y_OFFSET,-14>}
			box {< 5+BULKHEAD_THICKNESS/2,SECONDARY_HULL_DECK_19_Y_OFFSET,-26.5>,< 5-BULKHEAD_THICKNESS/2,SECONDARY_HULL_DECK_18_Y_OFFSET,-14>}
			box {<-7+BULKHEAD_THICKNESS/2,SECONDARY_HULL_DECK_18_Y_OFFSET,-26.5>,<-7-BULKHEAD_THICKNESS/2,SECONDARY_HULL_DECK_17_Y_OFFSET,-14>}
			box {< 7+BULKHEAD_THICKNESS/2,SECONDARY_HULL_DECK_18_Y_OFFSET,-26.5>,< 7-BULKHEAD_THICKNESS/2,SECONDARY_HULL_DECK_17_Y_OFFSET,-14>}
		}
		object {Secondary_Hull_Section_5_Shell(-OUTER_HULL_THICKNESS,0)}
		texture {Bulkhead_Texture}
	}

	// Interior lighting:
	#if (NO_INTERIOR_LIGHTS=false)
		union {
			light_source {< 8,SECONDARY_HULL_DECK_18_Y_OFFSET+2,-14.7> color <1.0,1.0,1.0> fade_distance 2.5 fade_power 1}		
			light_source {<-8,SECONDARY_HULL_DECK_18_Y_OFFSET+2,-14.7> color <1.0,0.9,1.0> fade_distance 2.5 fade_power 1}		
			
			light_source {< 6,SECONDARY_HULL_DECK_19_Y_OFFSET+2,-22.0> color <0.5,0.5,0.5> fade_distance 2.5 fade_power 1}		
			light_source {< 6,SECONDARY_HULL_DECK_19_Y_OFFSET+2,-25.0> color <0.5,0.5,0.5> fade_distance 2.5 fade_power 1}		
			light_source {<-6,SECONDARY_HULL_DECK_19_Y_OFFSET+2,-22.0> color <0.5,0.5,0.45> fade_distance 2.5 fade_power 1}		
			light_source {<-6,SECONDARY_HULL_DECK_19_Y_OFFSET+2,-25.0> color <0.5,0.5,0.45> fade_distance 2.5 fade_power 1}		
			
			light_source {< 8,SECONDARY_HULL_DECK_20_Y_OFFSET+2,-20.0> color <1.0,1.0,0.9> fade_distance 2.5 fade_power 1}		
			light_source {<-8,SECONDARY_HULL_DECK_20_Y_OFFSET+2,-20.0> color <0.9,1.0,1.0> fade_distance 2.5 fade_power 1}		
			light_source {< 8,SECONDARY_HULL_DECK_20_Y_OFFSET+2,-25.0> color <1.0,1.0,0.9> fade_distance 2.5 fade_power 1}		

			bounded_by {sphere {0,75}}
		}
	#end
}

#declare Secondary_Hull_Section_5_Glass = difference {
	
	object {Secondary_Hull_Section_5_Shell(-OUTER_HULL_THICKNESS-0.0001,0)}
	object {Secondary_Hull_Section_5_Shell(-OUTER_HULL_THICKNESS-PORTHOLE_THICKNESS+0.0001,0.0001)}
	plane {y,-12}
	material {Porthole_Glass_Material}	
}

#declare Secondary_Hull_Section_5 = difference {
	
	union {
		
		object {Secondary_Hull_Section_5_Outer_Hull}
		object {Secondary_Hull_Section_5_Inner_Hull}
  
		union {
			#local panel_rot=0;
			#local plate_tx=texture {Metallic_Hull_Plating(ENTERPRISE_GRAY(80),0.76,0.22,0.02)};
			#local joint_tx=texture {Metallic_Hull_Plating(ENTERPRISE_GRAY(40),0.90,0.10,0.00)};
			#while (panel_rot<360)
				object {Conical_Hull_Plate(-14,11.6067,-26.5,10.768,30,plate_tx,joint_tx,0,0,0) rotate z*panel_rot}
				#local panel_rot=panel_rot+30;
			#end
		}

  		// Hull markings:
		difference {    
			
			union {
				
				// The rectangular hatch:
				intersection {
					object {Secondary_Hull_Section_5_Shell(0.0001,0)}
					object {Rectangular_Hatch}
					texture {
					  	quilted
						texture_map {
							[0.0 Metallic_Hull_Plating(ENTERPRISE_SILVER,0.78,0.20,0.02)]
							[1.0 Metallic_Hull_Plating(ENTERPRISE_GRAY(0),0.90,0.10,0.00)]
						}
						control0 0
						control1 0
				   		scale <4,4,10>
				   		translate z*-6.2
					}
				}								
		
				intersection {
					object {Secondary_Hull_Section_5_Shell(0.0001,0)}
					object {Rectangular_Hatch_Outline}
					texture {Metallic_Hull_Plating(ENTERPRISE_GRAY(50),0.75,0.24,0.01)}
				}								
				
				// Bulkhead #1300 marker:
				intersection {
					object {Secondary_Hull_Section_5_Shell(0.0001,0)}
					object {Bulkhead_Number("1300",1.0) rotate y*-90 translate <15,0,-23> rotate z*-49.5}
					texture {Painted_Hull_Plating(ENTERPRISE_BLACK,0.75,0.24,0.01)}
				}
	
				intersection {
					object {Secondary_Hull_Section_5_Shell(0.0001,0)}
					object {Bulkhead_Number("1300",1.0) rotate y*90 translate <-15,0,-21> rotate z*49.5}
					texture {Painted_Hull_Plating(ENTERPRISE_BLACK,0.75,0.24,0.01)}
				}
				
				// Bulkhead #1384 marker (which is half in Section_5 and half in Section_6):
				intersection {
					object {Secondary_Hull_Section_5_Shell(0.0001,0)}
					object {Bulkhead_Number("1384",1.0) rotate y*-90 translate <15,0,-27.4> rotate z*23.5}
					texture {Painted_Hull_Plating(ENTERPRISE_BLACK,0.75,0.24,0.01)}
				}
		
				intersection {
					object {Secondary_Hull_Section_5_Shell(0.0001,0)}
					object {Bulkhead_Number("1384",1.0) rotate y*90 translate <-15,0,-25.4> rotate z*-23.5}
					texture {Painted_Hull_Plating(ENTERPRISE_BLACK,0.75,0.24,0.01)}
				}				

				// Pinstripes:
				intersection {
					object {Secondary_Hull_Section_5_Shell(0.0001,0)}
					object {Dorsal_Pinstripes}
					texture {Painted_Hull_Plating(ENTERPRISE_RED,0.75,0.24,0.01)}
				} 
				
			}
	
			object {Secondary_Hull_Section_5_Shell(-HULL_THICKNESS,0.0001) texture {Bulkhead_Texture}}	
		}			
	}
    
	// Difference out the portholes:
	#if (NO_PORTHOLES=false)

		// Deck 18 portholes:
		object {Round_Porthole(0.3625,1,2) translate <11.55,0,-14.7> rotate z*20.2622}
		object {Round_Porthole(0.3625,1,2) translate <-11.55,0,-14.7> rotate z*-20.2622}
		
		// Deck 19 portholes:
		object {Rectangular_Porthole(3.20,0.725,1,2) translate <10.925,0,-24> rotate z*7.8916}
		object {Rectangular_Porthole(3.20,0.725,1,2) translate <-10.925,0,-24> rotate z*-7.8916}
		
		// Deck 20 portholes:
		object {Rectangular_Porthole(1.65,0.725,1,2) translate <10.85,0,-25.3> rotate z*-5.2882}
		object {Rectangular_Porthole(1.65,0.725,1,2) translate <-10.85,0,-25.3> rotate z*5.2882}
		object {Rectangular_Porthole(1.65,0.725,1,2) translate <11.14,0,-21> rotate z*-5.1502}
		object {Rectangular_Porthole(1.65,0.725,1,2) translate <-11.14,0,-21> rotate z*5.1502}
		object {Rectangular_Porthole(1.65,0.725,1,2) translate <11.27,0,-19> rotate z*-5.0906}
		object {Rectangular_Porthole(1.65,0.725,1,2) translate <-11.27,0,-19> rotate z*5.0906}

	#end
}

#macro Secondary_Hull_Section_6_Shell(height_offset,length_offset)
	cone {<0,0,-26.5+length_offset>,10.768+height_offset,<0,0,-38.00-length_offset>,9.94+height_offset}
#end

#declare Secondary_Hull_Section_6_Outer_Hull = difference {
	
	object {Secondary_Hull_Section_6_Shell(0,0)}
	object {Secondary_Hull_Section_6_Shell(-OUTER_HULL_THICKNESS,0.0001)}	
}

#declare Secondary_Hull_Section_6_Inner_Hull = union {
	
	// Inner hull:
	difference {
		object {Secondary_Hull_Section_6_Shell(-OUTER_HULL_THICKNESS-PORTHOLE_THICKNESS,0)}
		object {Secondary_Hull_Section_6_Shell(-HULL_THICKNESS,0.0001)}	
		texture {Bulkhead_Texture}
	}

	// Decks:
	intersection {
		union {
			box {<-15,SECONDARY_HULL_DECK_16_Y_OFFSET-DECK_THICKNESS/2,-26.5>,<15,SECONDARY_HULL_DECK_16_Y_OFFSET+DECK_THICKNESS/2,-36.125>}
			box {<-15,SECONDARY_HULL_DECK_17_Y_OFFSET-DECK_THICKNESS/2,-26.5>,<15,SECONDARY_HULL_DECK_17_Y_OFFSET+DECK_THICKNESS/2,-36.125>}
			box {<-15,SECONDARY_HULL_DECK_18_Y_OFFSET-DECK_THICKNESS/2,-26.5>,<15,SECONDARY_HULL_DECK_18_Y_OFFSET+DECK_THICKNESS/2,-36.125>}
			box {<-15,SECONDARY_HULL_DECK_19_Y_OFFSET-DECK_THICKNESS/2,-26.5>,<15,SECONDARY_HULL_DECK_19_Y_OFFSET+DECK_THICKNESS/2,-38.000>}
			box {<-15,SECONDARY_HULL_DECK_20_Y_OFFSET-DECK_THICKNESS/2,-26.5>,<15,SECONDARY_HULL_DECK_20_Y_OFFSET+DECK_THICKNESS/2,-38.000>}
			box {<-15,SECONDARY_HULL_DECK_21_Y_OFFSET-DECK_THICKNESS/2,-26.5>,<15,SECONDARY_HULL_DECK_21_Y_OFFSET+DECK_THICKNESS/2,-38.000>}
			box {<-15,SECONDARY_HULL_DECK_22_Y_OFFSET-DECK_THICKNESS/2,-26.5>,<15,SECONDARY_HULL_DECK_22_Y_OFFSET+DECK_THICKNESS/2,-38.000>}
			box {<-15,SECONDARY_HULL_DECK_23_Y_OFFSET-DECK_THICKNESS/2,-26.5>,<15,SECONDARY_HULL_DECK_23_Y_OFFSET+DECK_THICKNESS/2,-38.000>}
		}
		object {Secondary_Hull_Section_6_Shell(-OUTER_HULL_THICKNESS,0)}
		texture {Deck_Texture}
	}
	
 	// Bulkheads: 	
	intersection {
		union {
			box {<-15,-15,-26.5>,<15,15,-26.5-BULKHEAD_THICKNESS/2>}	// Half of the bulkhead separating sections 5 & 6
			box {<-15,SECONDARY_HULL_DECK_20_Y_OFFSET,-36.125-BULKHEAD_THICKNESS/2>,<15,15,-36.125+BULKHEAD_THICKNESS/2>}	// The forward end of the hangar deck
			box {<-15,SECONDARY_HULL_DECK_19_Y_OFFSET,-38>,<15,-15,-38-BULKHEAD_THICKNESS/2>}	// Half of the bulkhead separating sections 6 & 7 below deck 19
			box {<-15,SECONDARY_HULL_DECK_20_Y_OFFSET,-30-BULKHEAD_THICKNESS/2>,<15,SECONDARY_HULL_DECK_19_Y_OFFSET,-30+BULKHEAD_THICKNESS/2>}	// The forward end of the hangar deck
			box {<-6+BULKHEAD_THICKNESS/2,SECONDARY_HULL_DECK_20_Y_OFFSET,-26.5>,<-7-BULKHEAD_THICKNESS/2,SECONDARY_HULL_DECK_19_Y_OFFSET,-38>}
			box {< 6+BULKHEAD_THICKNESS/2,SECONDARY_HULL_DECK_20_Y_OFFSET,-26.5>,< 7-BULKHEAD_THICKNESS/2,SECONDARY_HULL_DECK_19_Y_OFFSET,-38>}
		}
		object {Secondary_Hull_Section_6_Shell(-OUTER_HULL_THICKNESS,0)}
		texture {Bulkhead_Texture}
	}

	// Interior lighting:
	#if (NO_INTERIOR_LIGHTS=false)
		union {

			light_source {< 7,SECONDARY_HULL_DECK_20_Y_OFFSET+2,-32.8> color <1.0,1.0,0.9> fade_distance 2.5 fade_power 1}		
			light_source {<-7,SECONDARY_HULL_DECK_20_Y_OFFSET+2,-32.8> color <0.9,1.0,1.0> fade_distance 2.5 fade_power 1}		

			bounded_by {sphere {0,75}}
		}
	#end
}

#declare Secondary_Hull_Section_6_Glass = difference {
	
	object {Secondary_Hull_Section_6_Shell(-OUTER_HULL_THICKNESS-0.0001,0)}
	object {Secondary_Hull_Section_6_Shell(-OUTER_HULL_THICKNESS-PORTHOLE_THICKNESS+0.0001,0.0001)}
	plane {y,-12}
	material {Porthole_Glass_Material}	
}

#declare Secondary_Hull_Section_6 = difference {
	
	union {
		
		object {Secondary_Hull_Section_6_Outer_Hull}
		object {Secondary_Hull_Section_6_Inner_Hull}

		union {
			#local panel_rot=0;
			#local plate_tx=texture {Metallic_Hull_Plating(ENTERPRISE_GRAY(81),0.76,0.22,0.02)};
			#local joint_tx=texture {Metallic_Hull_Plating(ENTERPRISE_GRAY(40),0.90,0.10,0.00)};
			#while (panel_rot<360)
				object {Conical_Hull_Plate(-26.5,10.768,-38,9.94,30,plate_tx,joint_tx,0,0,0) rotate z*panel_rot}
				#local panel_rot=panel_rot+30;
			#end
		}

		// Hull markings:
		difference {    
			
			union {
				
				// The rectangular hatch:   
				intersection {
					object {Secondary_Hull_Section_6_Shell(0.0001,0)}
					object {Rectangular_Hatch}
					texture {
					  	quilted
						texture_map {
							[0.0 Metallic_Hull_Plating(ENTERPRISE_SILVER,0.78,0.20,0.02)]
							[1.0 Metallic_Hull_Plating(ENTERPRISE_GRAY(0),0.90,0.10,0.00)]
						}
						control0 0
						control1 0
				   		scale 4
				   		translate z*-2.5
					}
				}								
		
				intersection {
					object {Secondary_Hull_Section_6_Shell(0.0001,0)}
					object {Rectangular_Hatch_Outline}
					texture {Metallic_Hull_Plating(ENTERPRISE_GRAY(50),0.75,0.24,0.01)}
				}	

				// The square hatch:
				intersection {
					object {Secondary_Hull_Section_6_Shell(0.0001,0)}
					object {Square_Hatch}
					texture {
					  	quilted
						texture_map {
							[0.0 Metallic_Hull_Plating(ENTERPRISE_SILVER,0.78,0.20,0.02)]
							[1.0 Metallic_Hull_Plating(ENTERPRISE_GRAY(0),0.90,0.10,0.00)]
						}
						control0 0
						control1 0
				   		scale 4
				   		translate z*-2.5
					}
				}								
		
				intersection {
					object {Secondary_Hull_Section_6_Shell(0.0001,0)}
					object {Square_Hatch_Outline}
					texture {Painted_Hull_Plating(ENTERPRISE_RED,0.75,0.24,0.01)}
				}								

				// Bulkhead #1384 marker (which is half in Section_5 and half in Section_6):
				intersection {
					object {Secondary_Hull_Section_6_Shell(0.0001,0)}
					object {Bulkhead_Number("1384",1.0) rotate y*-90 translate <15,0,-27.4> rotate z*23.5}
					texture {Painted_Hull_Plating(ENTERPRISE_BLACK,0.75,0.24,0.01)}
				}
	
				intersection {
					object {Secondary_Hull_Section_6_Shell(0.0001,0)}
					object {Bulkhead_Number("1384",1.0) rotate y*90 translate <-15,0,-25.4> rotate z*-23.5}
					texture {Painted_Hull_Plating(ENTERPRISE_BLACK,0.75,0.24,0.01)}
				}
				
				// Pinstripes:
				intersection {
					object {Secondary_Hull_Section_6_Shell(0.0001,0)}
					object {Dorsal_Pinstripes}
					texture {Painted_Hull_Plating(ENTERPRISE_RED,0.75,0.24,0.01)}
				} 
				
				// The infamous "Tailpipe" joke sign:
				intersection {
					object {Secondary_Hull_Section_6_Shell(0.0001,0)}
					box {<0,0.5,-32.25>,<15,-0.375,-34.5>}		
					texture {Metallic_Hull_Plating(ENTERPRISE_GOLD,0.3,0.3,0.4)}
					rotate z*24
				}
				
				intersection {
					object {Secondary_Hull_Section_6_Shell(0.0002,0)}
					text {
						ttf
						"SFAMUSAF.ttf",
						"TAIL PIPE",
						15,
						0
						scale <0.25,0.25,1>
						rotate <0,-90,0>
						translate <15,0,-33.875>
						rotate z*25
					}
					
					texture {Metallic_Hull_Plating(ENTERPRISE_BLACK,0.8,0.2,0.0)}
				}
			
				intersection {
					object {Secondary_Hull_Section_6_Shell(0.0002,0)}
					text {
						ttf
						"SFAMUSAF.ttf",
						"SOCKET ADJUSTMENT",
						15,
						0
						scale <0.25,0.25,1>
						rotate <0,-90,0>
						translate <15,0,-34.4>
						rotate z*23.75
					}
					
					texture {Metallic_Hull_Plating(ENTERPRISE_BLACK,0.8,0.2,0.0)}
				}
			
				intersection {
					object {Secondary_Hull_Section_6_Shell(0.0002,0)}
					text {
						ttf
						"SFAMUSAF.ttf",
						"ACCESS",
						15,
						0
						scale <0.25,0.25,1>
						rotate <0,-90,0>
						translate <15,0,-33.75>
						rotate z*22.5
					}
					
					texture {Metallic_Hull_Plating(ENTERPRISE_BLACK,0.8,0.2,0.0)}
				} 

				intersection {
					object {Secondary_Hull_Section_6_Shell(0.0001,0)}
					box {<0,0.5,-32.25>,<-15,-0.375,-34.5>}		
					texture {Metallic_Hull_Plating(ENTERPRISE_GOLD,0.3,0.3,0.4)}
					rotate z*-24
				}
				
				intersection {
					object {Secondary_Hull_Section_6_Shell(0.0002,0)}
					text {
						ttf
						"SFAMUSAF.ttf",
						"TAIL PIPE",
						15,
						0
						scale <0.25,0.25,1>
						rotate <0,90,0>
						translate <-15,0,-32.85>
						rotate z*-25
					}
					
					texture {Metallic_Hull_Plating(ENTERPRISE_BLACK,0.8,0.2,0.0)}
				}
			
				intersection {
					object {Secondary_Hull_Section_6_Shell(0.0002,0)}
					text {
						ttf
						"SFAMUSAF.ttf",
						"SOCKET ADJUSTMENT",
						15,
						0
						scale <0.25,0.25,1>
						rotate <0,90,0>
						translate <-15,0,-32.325>
						rotate z*-23.75
					}
					
					texture {Metallic_Hull_Plating(ENTERPRISE_BLACK,0.8,0.2,0.0)}
				}
			
				intersection {
					object {Secondary_Hull_Section_6_Shell(0.0002,0)}
					text {
						ttf
						"SFAMUSAF.ttf",
						"ACCESS",
						15,
						0
						scale <0.25,0.25,1>
						rotate <0,90,0>
						translate <-15,0,-32.95>
						rotate z*-22.5
					}
					
					texture {Metallic_Hull_Plating(ENTERPRISE_BLACK,0.8,0.2,0.0)}
				} 
			}
	
			object {Secondary_Hull_Section_6_Shell(-HULL_THICKNESS,0.0001) texture {Bulkhead_Texture}}
		}				
	}

	// Difference out the portholes:
	#if (NO_PORTHOLES=false)
	
		// Deck 20 portholes:
		object {Rectangular_Porthole(1.65,0.725,1,2) translate <10.27,0,-34> rotate z*-5.5878}
		object {Rectangular_Porthole(1.65,0.725,1,2) translate <-10.27,0,-34> rotate z*5.5878}
		object {Rectangular_Porthole(1.65,0.725,1,2) translate <10.43,0,-31.6> rotate z*-5.5018}
		object {Rectangular_Porthole(1.65,0.725,1,2) translate <-10.43,0,-31.6> rotate z*5.5018}
		
	#end
}

// This is the aft section where most of the hangar deck lies:
#macro Secondary_Hull_Section_7_Shell(height_offset,length_offset)
	cone {<0,0,-38.00+length_offset>,9.94+height_offset,<0,0,-58.92-length_offset>,8.58+height_offset}		
#end

#declare Secondary_Hull_Section_7_Outer_Hull = difference {

	union {
		#local panel_rot=0;
		#local plate_tx=texture {Metallic_Hull_Plating(ENTERPRISE_GRAY(80),0.76,0.22,0.02)};
		#local joint_tx=texture {Metallic_Hull_Plating(ENTERPRISE_GRAY(30),0.90,0.10,0.00)};
		#while (panel_rot<360)
			object {Conical_Hull_Plate(-38.00,9.94,-58.92,8.58,30,plate_tx,joint_tx,0,0,(-38--58.92)/2) rotate z*panel_rot}
			#local panel_rot=panel_rot+30;
		#end
		object {Secondary_Hull_Section_7_Shell(0,0)}

		difference {
			
			union {
				
				// Bulkhead #1837 marker
				intersection {
					object {Secondary_Hull_Section_7_Shell(0.0001,0)}
					object {Bulkhead_Number("1837",1.0) rotate y*-90 translate <15,0,-51.2> rotate z*-11}
					texture {Painted_Hull_Plating(ENTERPRISE_BLACK,0.75,0.24,0.01)}
				}
	
				intersection {
					object {Secondary_Hull_Section_7_Shell(0.0001,0)}
					object {Bulkhead_Number("1837",1.0) rotate y*90 translate <-15,0,-49.2> rotate z*11}
					texture {Painted_Hull_Plating(ENTERPRISE_BLACK,0.75,0.24,0.01)}
				} 
				
				// Pinstripes:
				intersection {
					object {Secondary_Hull_Section_7_Shell(0.0001,0)}
					object {Dorsal_Pinstripes}
					texture {Painted_Hull_Plating(ENTERPRISE_RED,0.75,0.24,0.01)}
				} 
				
			}
			
			object {Secondary_Hull_Section_7_Shell(0,0)}
		}

	}
	
	difference {
		object {Secondary_Hull_Section_7_Shell(-OUTER_HULL_THICKNESS,0.0001)}	
		plane {y,0}
	}

	// This takes the "bite" out of the bottom
	cylinder {
		<-100,-11.6,-28.6>,<100,-11.6,-28.6>,9 scale <1,1,1.9673>
		texture {
		  	quilted
			texture_map {
				[0.0 Metallic_Hull_Plating(ENTERPRISE_GRAY(81),0.78,0.20,0.02)]
				[1.0 Metallic_Hull_Plating(ENTERPRISE_GRAY(30),0.90,0.10,0.00)]
			}
			control0 0
			control1 0
	   		scale <4.2,4.2,6.97333333>
	   		translate z*-28.6
		}
	}
	
	// This takes the "bite" out of the aft end
	#local scale_factor=2.7982456;
	cylinder {
		<-100,-2.595/scale_factor,-58.92>,<100,-2.595/scale_factor,-58.92>,2.85 scale <1,scale_factor,1>
		texture {
		  	quilted
			texture_map {
				[0.0 Metallic_Hull_Plating(ENTERPRISE_GRAY(81),0.78,0.20,0.02)]
				[1.0 Metallic_Hull_Plating(ENTERPRISE_GRAY(30),0.90,0.10,0.00)]
			}
			control0 0
			control1 0
	   		scale <5,9,6.97333333>
	   		translate z*-58.92
		}
	}
}

// If we don't put this endcap in place, you can see the inner/outer hull
// "sandwich" on the aft end:
#declare Secondary_Hull_Section_7_Endcap = difference {

	object {Secondary_Hull_Section_7_Shell(0,0)}
	
	difference {
		object {Secondary_Hull_Section_7_Shell(-HULL_THICKNESS,0.0001)}	
		plane {y,0}
	}

	// This takes the "bite" out of the aft end
	#local scale_factor=2.7982456;
	cylinder {<-100,-2.595/scale_factor,-58.92>,<100,-2.595/scale_factor,-58.92>,2.85 scale <1,scale_factor,1>}

	// No need for the end cap below this point...
	plane {y,0}            
	
	// ...or in front of this point:
	plane {z,-54.5 inverse}
}

#declare Secondary_Hull_Section_7_Inner_Hull = difference {
	
	object {Secondary_Hull_Section_7_Shell(-OUTER_HULL_THICKNESS-PORTHOLE_THICKNESS,0)}
	object {Secondary_Hull_Section_7_Shell(-HULL_THICKNESS,0.0001)}	
	
	// TODO: For now, no inner hull below deck 19:
	plane {y,0}
	
	// This takes the "bite" out of the aft end
	#local scale_factor=2.7982456;
	cylinder {<-100,-2.595/scale_factor,-58.92>,<100,-2.595/scale_factor,-58.92>,2.85 scale <1,scale_factor,1>}
}

#declare Secondary_Hull_Section_7_Glass = difference {
	
	object {Secondary_Hull_Section_7_Shell(-OUTER_HULL_THICKNESS-0.0001,0)}
	object {Secondary_Hull_Section_7_Shell(-OUTER_HULL_THICKNESS-PORTHOLE_THICKNESS+0.0001,0.0001)}

	// No glass below deck 19:
	plane {y,0}  
	
	// Nor any glass behind this point on the z-axis:
	plane {z,-51}
	
	material {Porthole_Glass_Material}	
}

#declare Secondary_Hull_Section_7 = difference {
	
	union {
		
		object {Secondary_Hull_Section_7_Outer_Hull}	
		
		object {Secondary_Hull_Section_7_Inner_Hull texture {Bulkhead_Texture}}	
		
		object {
			Secondary_Hull_Section_7_Endcap
			texture {
			  	quilted
				texture_map {
					[0.0 Metallic_Hull_Plating(ENTERPRISE_GRAY(81),0.78,0.20,0.02)]
					[1.0 Metallic_Hull_Plating(ENTERPRISE_GRAY(30),0.90,0.10,0.00)]
				}
				control0 0
				control1 0
		   		scale <5,9,6.97333333>
		   		translate z*-58.92
			}
		}

		// The square fantail hatch:
		difference {
			intersection {
				object {Square_Fantail_Hatch_Outline}
				cylinder {<-100,-11.6,-28.6>,<100,-11.6,-28.6>,9 scale <1,1,1.9673>}
			}
			cylinder {<-100,-11.6,-28.6>,<100,-11.6,-28.6>,8.99999 scale <1,1,1.9673>}
			texture {Painted_Hull_Plating(ENTERPRISE_RED,0.75,0.24,0.01)}
		}
	
		difference {
			intersection {
				object {Square_Fantail_Hatch}
				cylinder {<-100,-11.6,-28.6>,<100,-11.6,-28.6>,9 scale <1,1,1.9673>}
			}
			cylinder {<-100,-11.6,-28.6>,<100,-11.6,-28.6>,8.99999 scale <1,1,1.9673>}
			texture {
			  	quilted
				texture_map {
					[0.0 Metallic_Hull_Plating(ENTERPRISE_GRAY(60),0.78,0.20,0.02)]
					[1.0 Metallic_Hull_Plating(ENTERPRISE_GRAY(30),0.90,0.10,0.00)]
				}
				control0 0
				control1 0
		   		scale <5,9,6.97333333>
		   		translate z*-58.92
			}
		}
	}

	// Punch out the portholes:
	#if (NO_PORTHOLES=false)
		
		// Deck 16 portholes:
		object {Round_Porthole(0.3625,1,5) translate <8.5,0,-41.3> rotate z*62}
		object {Round_Porthole(0.3625,1,5) translate <-8.5,0,-41.3> rotate z*-62}
		object {Round_Porthole(0.3625,1,5) translate <8.5,0,-47.8> rotate z*58}
		object {Round_Porthole(0.3625,1,5) translate <-8.5,0,-47.8> rotate z*-58}
		
		// Deck 17 portholes:
		object {Round_Porthole(0.3625,1,5) translate <8.5,0,-42.6> rotate z*42}
		object {Round_Porthole(0.3625,1,5) translate <-8.5,0,-42.6> rotate z*-42}
		object {Round_Porthole(0.3625,1,5) translate <8.5,0,-44.6> rotate z*42.5}
		object {Round_Porthole(0.3625,1,5) translate <-8.5,0,-44.6> rotate z*-42.5}

		// Deck 18 portholes:
		object {Round_Porthole(0.3625,1,5) translate <8.5,0,-44.6> rotate z*25}
		object {Round_Porthole(0.3625,1,5) translate <-8.5,0,-44.6> rotate z*-25}
		object {Rectangular_Porthole(1.65,0.725,1,5) translate <8.5,0,-46.6> rotate z*25.3}
		object {Rectangular_Porthole(1.65,0.725,1,5) translate <-8.5,0,-46.6> rotate z*-25.3}
		object {Rectangular_Porthole(1.65,0.725,1,5) translate <8.5,0,-49> rotate z*25.6}
		object {Rectangular_Porthole(1.65,0.725,1,5) translate <-8.5,0,-49> rotate z*-25.6}

	#end
	
	// Temporary light source for entire hangar deck:
	#if (NO_INTERIOR_LIGHTS=false)
		union {
			light_source {<0,5,-45> color <1.0,1.0,1.0> fade_distance 5 fade_power 1}
			bounded_by {sphere {0,75}}
		}
	#end
}

/*
// The track for the hangar bay doors:
#declare Hangar_Bay_Door_Track =
	difference {
		difference {
			sphere {<0,0,-53>,7}
			sphere {<0,0,-53>,6.75}
		}
		plane {y,-0.25}
		plane {z,0 inverse}
	}


*/

// This is the fantail:
#macro Secondary_Hull_Fantail_Shell(height_offset,radius_offset)
	difference {
		cylinder {<0,-0.0001+height_offset,-52>,<0,-2.6-height_offset,-52>,8.25+radius_offset}			
		plane {z,-54.4999+radius_offset inverse}
	}
#end

#declare Secondary_Hull_Fantail_Outer_Hull = difference {
	object {Secondary_Hull_Fantail_Shell(0,0)}
	object {Secondary_Hull_Fantail_Shell(-OUTER_HULL_THICKNESS,-OUTER_HULL_THICKNESS)}
}

#declare Secondary_Hull_Fantail_Inner_Hull = union {
	
	difference {
		object {Secondary_Hull_Fantail_Shell(-OUTER_HULL_THICKNESS-PORTHOLE_THICKNESS,-OUTER_HULL_THICKNESS-PORTHOLE_THICKNESS)}
		object {Secondary_Hull_Fantail_Shell(-HULL_THICKNESS,-HULL_THICKNESS)}
	}
	
	// We have to build a little "room" for each of the five landing
	// lights or their colors will bleed into each other:
	box {<2.625,-0.25,-57>,<2.375,-2.35,-59.7334>}
	box {<1.425,-0.25,-57>,<1.675,-2.35,-59.9757>}
	box {<-1.425,-0.25,-57>,<-1.675,-2.35,-59.9757>}
	box {<-2.625,-0.25,-57>,<-2.375,-2.35,-59.7334>}
	box {<-6.35,-0.25,-57.125>,<6.35,-2.35,-56.875>}
	
	texture {Bulkhead_Texture}
}

#declare Secondary_Hull_Fantail_Glass = difference {
	object {Secondary_Hull_Fantail_Shell(-OUTER_HULL_THICKNESS,-OUTER_HULL_THICKNESS)}
	object {Secondary_Hull_Fantail_Shell(-OUTER_HULL_THICKNESS-PORTHOLE_THICKNESS,-OUTER_HULL_THICKNESS-PORTHOLE_THICKNESS)}
	material {Porthole_Glass_Material}
}

#macro Landing_Light(ll_length, ll_red, ll_green, ll_blue, ll_fd)
	union {
		
		box {
			<-ll_length/2,-0.125,-0.125>,<ll_length/2,0.125,0.125>
	    	texture {
				pigment {color rgbft <ll_red,ll_green,ll_blue,0,1>}
				finish {
					specular 0      
					roughness 0.1
					ambient 0
				}
			}
		}
		
		#if (NO_EXTERIOR_LIGHTS=false)
			light_source {
				<0,0,0>
				color rgb <ll_red, ll_green, ll_blue>
				fade_distance ll_fd
				fade_power 10
			}
		#end

		bounded_by {sphere {0,75}}
	}
	
#end

#declare Secondary_Hull_Fantail = difference {
	
	union {        

		object {Secondary_Hull_Fantail_Outer_Hull}
		object {Secondary_Hull_Fantail_Inner_Hull}
		object {Landing_Light(1.50,1,0,0,3) rotate y*-30 translate <3.5,-1,-58.25>} 
		object {Landing_Light(1.00,1,1,0,3) rotate z*90 translate <2,-1.3125,-58>}
		object {Landing_Light(2.25,0,1,0,3) translate <0,-1,-59>}
		object {Landing_Light(1.00,1,1,0,3) rotate z*90 translate <-2,-1.3125,-58>}
		object {Landing_Light(1.50,1,0,0,3) rotate y*30 translate <-3.5,-1,-58.25>}
	}
	
	// Punch out the landing light portholes:
	object {Rectangular_Porthole(1.5,0.375,3,3) translate <3.5,-1,-60.25>}
	object {Rectangular_Porthole(0.375,1,3,3) translate <2,-1.3125,-60.25>}
	object {Rectangular_Porthole(2.25,0.375,3,3) translate <0,-1,-60.25>}
	object {Rectangular_Porthole(0.375,1,3,3) translate <-2,-1.3125,-60.25>}
	object {Rectangular_Porthole(1.5,0.375,3,3) translate <-3.5,-1,-60.25>}
} 

/*******************************************************************************
* Running lights                                                               *
*******************************************************************************/
// This isn't a "canon" light, but all aircraft have a flashing red beacon
// on their belly, so the Enterprise gets one too! (Besides, the movie
// Enterprise had one, so I'm going to assume that this light was just never
// quite visible from the TV angles we saw back in the Sixties...!)
#declare Secondary_Hull_Ventral_Beacon = object {
	Beacon(1,0.2,1,0,0,false)
	rotate z*180
	translate <0,-12.85,9>
}

// The large and small beacons on the aft port and starboard sides:
#macro Secondary_Hull_PS_Large_Beacon(rotation_angle)
	object {
		Beacon(0.375,0.25,1,1,0,false)
		rotate x*-3.7
		translate <0,9.35,-46.6>
		rotate z*rotation_angle
	}
#end
 
#macro Secondary_Hull_PS_Small_Beacon(rotation_angle)
	object {
		Beacon(0.25,0.25,1,1,1,true)
		rotate x*-3.7
		translate <0,9.5,-44.6>
		rotate z*rotation_angle
	}
#end

// The small green running lights on the aft dorsal side, near the hangar deck:
#macro Secondary_Hull_Dorsal_Green_Running_Light(y_translation,z_translation)
	object {
		Running_Light(0.25,0.375,0,1,0,true)
		rotate x*-3.7
		translate <0,y_translation,z_translation>
	}
#end

// The red beacon between the two green running lights:
#declare Secondary_Hull_Dorsal_Red_Beacon = object {
	Beacon (0.625,0.25,1,0,0,true)
	rotate x*-3.7
	translate <0,9.45,-44.6>
}

// The huge homing beacon above the hangar deck:
#declare Secondary_Hull_Homing_Beacon = object {
	Beacon (2,0.1,0.5,0.5,0.25,true)
	rotate x*-3.7
	translate <0,8.85,-55>
}


/*******************************************************************************
* Decks and bulkheads                                                          *
* Someday this model will be a "virtual Enterprise" with actual interior rooms *
* and contents. For now, we define some decks and bulkheads so that when you   *
* look through the portholes you don't see a hollow ship!                      *
* In the secondary hull decks are numbered starting from the top. Bulkheads    *
* are either in the z-plane or the x-plane and are numbered nnnX where         *
* nnn=z-plane coordinates (for lateral bulkheads) or x-plane (for longitudinal *
* bulkheads) and X="Z" for lateral and "X" for longitudinal bulkheads.         *
*******************************************************************************/
// This bulkhead is the aft end of the hangar deck, around the clamshell doors:
#declare Secondary_Hull_Bulkhead_neg54Z = difference {
	
	// Basic wall:
	cone {<0,0,-54.5-BULKHEAD_THICKNESS/2>,8.75,<0,0,-54.5+BULKHEAD_THICKNESS/2>,8.77}
	
	// Area where the clamshell doors are located:
	sphere {<0,0,-53>,7.5}
	
	// Bulkhead does not extend below deck 19:
	plane {y,-0.125}
	
	// Don't put bulkhead through control room atop the clamshell doors:
	cylinder {<0,8.85,-54.5>,<0,5.91,-54.5>,1.95}
		
	texture {Metallic_Hull_Plating(ENTERPRISE_GRAY(50),0.75,0.24,0.01)}
}

#declare Secondary_Hull_Deck_19_Section_7 = prism {
	linear_sweep
	linear_spline
	0.0001,-0.25,
	5,
	<9.74,-38.00>,<-9.74,-38.00>,<-8.65,-54.5>,<8.65,-54.5>,<9.74,-38.00>
	texture {Bulkhead_Texture}
}

#declare Secondary_Hull_Deck_19_Fantail = difference {
	cylinder {<0,0.0001,-52>,<0,-0.25,-52>,8.2499}			
	plane {z,-54.5 inverse}
	texture {Bulkhead_Texture}
}

#declare Base_Secondary_Hull = union {
	
	object {Secondary_Hull_Section_1}
	object {Secondary_Hull_Section_2}
	object {Secondary_Hull_Section_3}
	object {Secondary_Hull_Section_4}
	object {Secondary_Hull_Section_5}
	object {Secondary_Hull_Section_6}
	object {Secondary_Hull_Section_7}

	object {
		Secondary_Hull_Fantail
		texture {
		  	quilted
			texture_map {
				[0.0 Metallic_Hull_Plating(ENTERPRISE_GRAY(81),0.78,0.20,0.02)]
				[1.0 Metallic_Hull_Plating(ENTERPRISE_GRAY(30),0.90,0.10,0.00)]
			}
			control0 0
			control1 0
	   		scale <4.2,4.2,4>
	   		translate z*-58.92
		}		
	}
	
	// Porthole glass:
	object {Secondary_Hull_Section_2_Glass}
	object {Secondary_Hull_Section_3_Glass}
	object {Secondary_Hull_Section_4_Glass}
	object {Secondary_Hull_Section_5_Glass}
	object {Secondary_Hull_Section_6_Glass}
	object {Secondary_Hull_Section_7_Glass}
	object {Secondary_Hull_Fantail_Glass}

	// Decks and bulkheads:
	object {Secondary_Hull_Deck_19_Section_7}	
	object {Secondary_Hull_Deck_19_Fantail}	
	object {Secondary_Hull_Bulkhead_neg54Z}
}

/******************************************************************************
* Hangar Bay                                                                  *
******************************************************************************/
#macro Hangar_Bay_Door_Wedge(start_degrees,end_degrees,radius_offset,rotation_angle,wedge_color)
	difference {
		difference {
			sphere {<0,0,0>,7.5-radius_offset}
			sphere {<0,0,0>,7.5-radius_offset-0.125}
		}
		plane {y,-0}
		plane {z,0 inverse}
		plane {z,0 rotate y*(90-start_degrees) inverse} 
		plane {z,0 rotate y*(90-end_degrees)}
		rotate y*rotation_angle 
		texture {Metallic_Hull_Plating(wedge_color,0.75,0.24,0.01)}
	}
#end
		
#macro Hangar_Bay_Doors(open_pct)
	union {
		
		// The clamshell doors:
		union {

			#local open_factor = open_pct/100;

			object {Hangar_Bay_Door_Wedge(90,72,0.000,0,ENTERPRISE_GRAY(80))}
			object {Hangar_Bay_Door_Wedge(73,54,0.125,-18*open_factor,ENTERPRISE_GRAY(75))}
			object {Hangar_Bay_Door_Wedge(55,36,0.250,-36*open_factor,ENTERPRISE_GRAY(80))}
			object {Hangar_Bay_Door_Wedge(37,18,0.375,-54*open_factor,ENTERPRISE_GRAY(75))}
			object {Hangar_Bay_Door_Wedge(19,0,0.5,-72*open_factor,ENTERPRISE_GRAY(80))}
			object {Hangar_Bay_Door_Wedge(0,-19,0.5,72*open_factor,ENTERPRISE_GRAY(75))}
			object {Hangar_Bay_Door_Wedge(-18,-37,0.375,54*open_factor,ENTERPRISE_GRAY(80))}
			object {Hangar_Bay_Door_Wedge(-36,-55,0.250,36*open_factor,ENTERPRISE_GRAY(75))}
			object {Hangar_Bay_Door_Wedge(-54,-73,0.125,18*open_factor,ENTERPRISE_GRAY(80))}
			object {Hangar_Bay_Door_Wedge(-72,-90,0.000,0,ENTERPRISE_GRAY(75))}

			translate z*-53 
		}           
			
		// The control room (?) above the doors:
		union {
			
			difference {
				cylinder {<0,8.85,-54.5>,<0,5.91,-54.5>,1.95}
				cylinder {<0,8.60,-54.5>,<0,6.16,-54.5>,1.70 texture {Bulkhead_Texture}}
				object {Rectangular_Porthole(2,1,3,2) translate <0,7,-56.45>}
				texture {Metallic_Hull_Plating(ENTERPRISE_GRAY(80),0.75,0.24,0.01)}
			}
   
   			//  Little bitty wall to keep you from seeing the clamshell doors
   			// which intrude into the compartment
			box {
				<-1.75,8.8,-54.375>,<1.75,6,-54.5>
				texture {Bulkhead_Texture}
			}

			difference {
				cylinder {<0,8.80,-54.5>,<0,5.95,-54.5>,1.825}
				cylinder {<0,8.81,-54.5>,<0,5.96,-54.5>,1.7625}
				material {Porthole_Glass_Material}
			}    			  
			
			#if (NO_INTERIOR_LIGHTS=false)		
				light_source {<0,8.5,-56> color <0.5,0.5,0.3> fade_distance 10 fade_power 5}	// hangar deck control room light source
			#end

			bounded_by {sphere {0,75}}
		}		
	}		
#end

#macro Interconnecting_Dorsal_Spotlight(rot)
	union {

		object {Beacon(0.25,0.25,1.0,1.0,0.9,true) translate <0,12.75,6.8> rotate z*rot}
	
		#if (NO_EXTERIOR_LIGHTS=false)	
			light_source {
				0*z
				color rgb <2,2,1.8>
				spotlight
				translate <0,13,6.8>
				rotate z*rot
				point_at <0,25,25>
				radius 12.5
				falloff 25
				fade_distance 35
				fade_power 10
			}  
		#end
		
		bounded_by {sphere {0,75}}
	}
#end

#declare Secondary_Hull = union {

	// The basic secondary hull:	
	object {Base_Secondary_Hull}

	// Running lights:
	object {Secondary_Hull_PS_Large_Beacon(-96)}
	object {Secondary_Hull_PS_Large_Beacon(96)}	
	object {Secondary_Hull_PS_Small_Beacon(-95.6)}
	object {Secondary_Hull_PS_Small_Beacon(95.6)}     
	object {Secondary_Hull_Dorsal_Green_Running_Light(9.625,-42.6)}
	object {Secondary_Hull_Dorsal_Red_Beacon}
	object {Secondary_Hull_Dorsal_Green_Running_Light(9.375,-46.6)}
	object {Secondary_Hull_Homing_Beacon}
	
	// Macro/micro detail features:
	object {Hangar_Bay_Doors(HANGAR_BAY_DOORS_OPEN_PCT)}
	object {Main_Deflector}
	object {Starboard_Deflector_Dish_Surround}
	object {Port_Deflector_Dish_Surround}
	object {Ventral_Deflector_Dish_Surround}
	object {Secondary_Hull_Ventral_Beacon}
	object {Pennant_Lightbar}
	object {Pennant_Lightbar rotate z*180}
	
	object {Interconnecting_Dorsal_Spotlight(15)}
	object {Interconnecting_Dorsal_Spotlight(-15)}
	
	// Guidelines:
	/*
	#local apparent_y=-1;
	#local apparent_z=-46.6;
	cylinder {<20,apparent_y,-100>,<20,apparent_y,100>,0.0625 texture {pigment {Red} finish {ambient 1}}}
	cylinder {<-100,-20,apparent_z>,<100,-20,apparent_z>,0.0625 texture {pigment {Green} finish {ambient 1}}}
	cylinder {<-100,20,apparent_z>,<100,20,apparent_z>,0.0625 texture {pigment {Green} finish {ambient 1}}}	
	*/
}

/*******************************************************************************
* Measurement constants                                                        *
* All units of length are expressed in meters.                                 *
*******************************************************************************/
#declare WARP_NACELLE_MAX_RADIUS = 7.969;                  // Each warp nacelle is not cylindrical, but rather a truncated cone that tapers from fore to aft
#declare WARP_NACELLE_MIN_RADIUS = 6.513;                     
#declare WARP_NACELLE_LENGTH = 128.288;                    // Length of just the conical nacelle section, not the overall length
#declare WARP_NACELLE_ENDCAP_LENGTH = 11.863;              // Corrogated cap at the aft end of each warp nacelle
#declare WARP_NACELLE_ENDCAP_COLLAR_LENGTH = 2.188;        // Cylindrical collar between the endcap and the warp nacelle body

#declare AFT_INTERCOOLER_OFFSET = 3.179;                   // Distance from aft end of nacelle to aft end of intercooler

#declare FSMFC_OFFSET_ANGLE = 38;                          // Offset angle of first stage magnatomic flux constrictors below the Bussard collectors
#declare FSMFC_Z_OFFSET = 62.5;                            // Z-axis offset of constrictors from the centerpoint of the warp nacelle


/*******************************************************************************
* Textures and macros                                                          *
*******************************************************************************/
#macro Warp_Nacelle_Body(radius_offset, length_offset)
	cone {
		<0,0,-WARP_NACELLE_LENGTH/2-(length_offset/2)>, WARP_NACELLE_MIN_RADIUS+radius_offset, <0,0,WARP_NACELLE_LENGTH/2+(length_offset/2)>, WARP_NACELLE_MAX_RADIUS+radius_offset
	}
#end

/*******************************************************************************		
* First-stage magnatomic flux constrictors                                     *
* (a.k.a. the little boxes under the Bussard collector assembly)               *
*******************************************************************************/
#local FSMFC_LENGTH = 12.5;
#local FSMFC_WIDTH = 4.15;
#local FSMFC_DEPTH = 0.75;

#declare First_Stage_Magnatomic_Flux_Constrictor_Step1 =
	difference {
		cylinder {<0,0,-FSMFC_LENGTH/2>,<0,0,FSMFC_LENGTH/2>,WARP_NACELLE_MAX_RADIUS+FSMFC_DEPTH}
		cylinder {<0,0,-FSMFC_LENGTH/2-0.0001>,<0,0,FSMFC_LENGTH/2+0.0001>,WARP_NACELLE_MAX_RADIUS-1}		
		plane {x,-FSMFC_WIDTH/2}
		plane {x,FSMFC_WIDTH/2 inverse}
		plane {y,0 inverse} 
		//plane {z,10.3 rotate x*45 inverse}	// This doesn't accurately plane off the angled edges...
		//plane {z,-9.6 rotate x*-75}           // see "Step2" and "Step3"...
}

// We have to use elongated spheres to intersect off the leading and trailing
// edges of the flux constrictors. Using z-plane differencing causes the 
// cylindrical constrictors to have convex ends on their ventral side, when
// the edges should be nearly straight. Since the angle of the bevel is not
// the same for each end, we have to do this in two steps...

// The front half, with a 45-degree bevel:
#declare First_Stage_Magnatomic_Flux_Constrictor_Step2 =  
	difference {
		intersection {
			object {First_Stage_Magnatomic_Flux_Constrictor_Step1}
			sphere {<0,4,0.525>,11 scale <1,1.5,1>}
		}
		// See below for why we slice this in two one meter
		// behind the centerpoint:
		plane {z,-1}
	}

// The rear half, with a 15-degree bevel:
#declare First_Stage_Magnatomic_Flux_Constrictor_Step3 =  
	difference {
		intersection {
			object {First_Stage_Magnatomic_Flux_Constrictor_Step1}
			sphere {<0,4,-1.95>,11 scale <1,1.28,1>}
		}
		// Because the above intersection sphere is flatter, it
		// starts intersecting with the FRONT part of this half
		// of the flux chiller. So, we move the chopping line 
		// between steps 2 and 3 one meter back (and forward
		// again slightly here to avoid coincident lines) so that
		// we don't see a divot in the back half of the chiller: 
		plane {z,-0.999 inverse}
	}

// Put the two halves together:
#declare First_Stage_Magnatomic_Flux_Constrictor =  
	union {
		object {First_Stage_Magnatomic_Flux_Constrictor_Step2}
		object {First_Stage_Magnatomic_Flux_Constrictor_Step3}
		texture {
			gradient z
			texture_map {
				[0.0 Metallic_Hull_Plating(ENTERPRISE_GRAY(70),0.72,0.27,0.01)]
				[0.5 Metallic_Hull_Plating(ENTERPRISE_GRAY(65),0.76,0.24,0.00)]
				[1.0 Metallic_Hull_Plating(ENTERPRISE_GRAY(70),0.72,0.27,0.01)]
			}
			scale <1,1,5>
		}
	}


/*******************************************************************************
* Intercoolers                                                                 *
* This is one tough mother to model accurately. The outer torus diameter at    *
* the aft end of the intercooler is greater than at the front, but this model  *
* makes the intercoolers symmetrical. It's not noticable from a distance, and  *
* only a close examination would reveal the flaw.                              *
* The overall length of an intercooler is determined by the formula            *
* (IC_TORUS_MAJOR + IC_TORUS_MINOR + IC_OUTER_TORUS_ORIGIN)*2                  *
*******************************************************************************/

#local IC_TUBE_DIAMETER = 1.375;
#local IC_TORUS_MAJOR = 2;
#local IC_TORUS_MINOR = IC_TUBE_DIAMETER/2;
#local IC_OUTER_TORUS_ORIGIN = 12.779;
#local IC_INNER_TORUS_ORIGIN = IC_OUTER_TORUS_ORIGIN-IC_TUBE_DIAMETER;  
#local IC_OVERALL_HEIGHT = 3.525;
#local IC_EXTENSION_HEIGHT = IC_OVERALL_HEIGHT-(IC_TORUS_MAJOR+IC_TORUS_MINOR)+1;

#declare Intercooler_1 =
	difference {
		cylinder {<0,-IC_TORUS_MINOR-0.00001,0>,<0,IC_TORUS_MINOR+0.00001,0>,IC_TORUS_MAJOR} // have to have slight offset or coincident surfaces occur
		torus {IC_TORUS_MAJOR,IC_TORUS_MINOR}
	}
 
#declare Intercooler_2 = 
	difference {
		union {
			torus {IC_TORUS_MAJOR, IC_TORUS_MINOR}
			cylinder {<0,-IC_TORUS_MINOR,0>,<0,IC_TORUS_MINOR,0>,IC_TORUS_MAJOR}
		}
		plane {x, 0 inverse}
		plane {x, 0 rotate y*-90}      
		object {Intercooler_1 translate x*(IC_OUTER_TORUS_ORIGIN-IC_INNER_TORUS_ORIGIN)}
	}

#declare Intercooler_3 = 
	difference {
		torus {IC_TORUS_MAJOR, IC_TORUS_MINOR}
		plane {x, 0 inverse}
		plane {x, 0 rotate y*-90}      
	}

#declare Intercooler_Rib =
	box {<-IC_INNER_TORUS_ORIGIN,-0.0625,0.125>,<IC_INNER_TORUS_ORIGIN,0.0625,-0.125>}

#declare Intercooler_Tube = 
	union {
		cylinder {<-IC_INNER_TORUS_ORIGIN,0,0>,<IC_INNER_TORUS_ORIGIN,0,0>,IC_TUBE_DIAMETER/2}
		#if (DETAIL_LEVEL >= 3)
			object {Intercooler_Rib translate z*IC_TORUS_MINOR rotate x*-60}
			object {Intercooler_Rib translate z*IC_TORUS_MINOR rotate x*-30}
			object {Intercooler_Rib translate z*IC_TORUS_MINOR rotate x*0}
			object {Intercooler_Rib translate z*IC_TORUS_MINOR rotate x*30}
			object {Intercooler_Rib translate z*IC_TORUS_MINOR rotate x*60}
		#end
	}
		
#declare Intercooler_4 = 
	union {
		difference {	
			union { 
				cylinder {<-IC_OUTER_TORUS_ORIGIN,0,IC_TORUS_MAJOR>,<IC_OUTER_TORUS_ORIGIN,0,IC_TORUS_MAJOR>,IC_TUBE_DIAMETER/2}
				difference {
					box {<-IC_OUTER_TORUS_ORIGIN,-IC_TORUS_MINOR,IC_TORUS_MAJOR>,<IC_OUTER_TORUS_ORIGIN,IC_TORUS_MINOR,IC_TORUS_MAJOR-IC_TORUS_MINOR>}
					object {Intercooler_1 translate x*-IC_INNER_TORUS_ORIGIN}
					object {Intercooler_1 translate x*IC_INNER_TORUS_ORIGIN}
				}
				object {Intercooler_3 translate x*-IC_INNER_TORUS_ORIGIN}		
				object {Intercooler_3 rotate z*-180 translate x*IC_INNER_TORUS_ORIGIN}		
			}
			cylinder {<-IC_INNER_TORUS_ORIGIN,0,IC_TORUS_MAJOR>,<IC_INNER_TORUS_ORIGIN,0,IC_TORUS_MAJOR>,IC_TUBE_DIAMETER+0.0001}
		}
		object {Intercooler_Tube translate z*IC_TORUS_MAJOR}
	}

#declare Intercooler_5 = 
	union {
		box {<-IC_TORUS_MINOR,-IC_TORUS_MINOR,-IC_EXTENSION_HEIGHT/2>,<IC_TORUS_MINOR,IC_TORUS_MINOR,IC_EXTENSION_HEIGHT/2>}
		cylinder {<-IC_TORUS_MINOR,0,-IC_EXTENSION_HEIGHT/2>,<-IC_TORUS_MINOR,0,IC_EXTENSION_HEIGHT/2>, IC_TORUS_MINOR}
		cylinder {<IC_TORUS_MINOR,0,-IC_EXTENSION_HEIGHT/2>,<IC_TORUS_MINOR,0,IC_EXTENSION_HEIGHT/2>, IC_TORUS_MINOR}
	}

#declare Intercooler_Grille_Texture = texture {
	pigment {ENTERPRISE_GRAY(60)}
	finish {
	    ambient 0.05
	    brilliance 4
	    diffuse 0.75
	    metallic 0.5
	    specular 0.24
	    roughness 0.65
	    reflection 0.01
	}
	normal {
      bump_map {sys "intercooler_bumps.bmp" bump_size 5 use_index}
      translate <0.5,0.5,0>
      scale 3
      rotate x*90
	}
}

#declare Intercooler_Grille =
	box {
		<-IC_OUTER_TORUS_ORIGIN-IC_TUBE_DIAMETER,-0.1,IC_TORUS_MAJOR>,<IC_OUTER_TORUS_ORIGIN+IC_TUBE_DIAMETER,0.1,-IC_EXTENSION_HEIGHT>
		texture {Intercooler_Grille_Texture}
	}
            
#declare Intercooler_Fin = 
	union {
		box {<-4.25,-0.125,0.375>,<0,0.125,-IC_EXTENSION_HEIGHT>}
		cylinder {<-4.25,0,0.375>,<0,0,0.375>,0.125}
		box {<0,-0.125,0>,<0.375,0.125,-IC_EXTENSION_HEIGHT>}
		cylinder {<0.375,0,0>,<0.375,0,-IC_EXTENSION_HEIGHT>,0.125}
		difference {
			union {
				torus {0.375, 0.125}
				cylinder {<0,-0.125,0>,<0,0.125,0>,0.375}
			}
			plane {x, 0}
			plane {x, 0 rotate y*-90}      
		}
		texture {Metallic_Hull_Plating(ENTERPRISE_GRAY(80),0.75,0.24,0.01)}
	}

// This is a basic intercooler without the forward fin or grille:
#declare Intercooler_Assembly = 
	union {
		object {Intercooler_2 translate x*-IC_OUTER_TORUS_ORIGIN}
		object {Intercooler_2 rotate z*-180 translate x*IC_OUTER_TORUS_ORIGIN}
		object {Intercooler_4}
		object {Intercooler_5 translate <-(IC_INNER_TORUS_ORIGIN+IC_TORUS_MAJOR+IC_TORUS_MINOR),0,-IC_EXTENSION_HEIGHT/2>}
		object {Intercooler_5 translate <(IC_INNER_TORUS_ORIGIN+IC_TORUS_MAJOR+IC_TORUS_MINOR),0,-IC_EXTENSION_HEIGHT/2>}
		texture {Metallic_Hull_Plating(ENTERPRISE_GRAY(80),0.75,0.24,0.01)}
	}

// This is an intercooler with the grille and the forward-projecting fin:
#declare Aft_Intercooler_Assembly =
	union {
		object {Intercooler_Assembly}
		object {Intercooler_Grille} 
		object {Intercooler_Fin translate x*(IC_TORUS_MAJOR+IC_TORUS_MINOR+IC_OUTER_TORUS_ORIGIN+4)}		
	}

/*******************************************************************************
* Bussard Collector                                                            *
*******************************************************************************/
// Component dimensions:
#local BC_OVERFLUX_VENT_LENGTH = 3.000;   // Four concentric rings just aft of the Bussard Collector Collar
#local BC_COLLAR_LENGTH = 4.000;          // Cylindrical collar abaft the lip arount the Bussard Collector
#local BC_LIP_LENGTH = 0.900;             // Conical lip around the semispherical Bussard Collector
#local BC_DOME_RADIUS = 7.500;            // Sphere at the fore end of each warp nacelle

// Position of each component:
#local BC_OVERFLUX_VENT_OFFSET = 0.000;
#local BC_COLLAR_OFFSET = BC_OVERFLUX_VENT_LENGTH;
#local BC_LIP_OFFSET = BC_OVERFLUX_VENT_LENGTH + BC_COLLAR_LENGTH;
#local BC_DOME_OFFSET = BC_OVERFLUX_VENT_LENGTH + BC_COLLAR_LENGTH + BC_LIP_LENGTH;    

#declare Outer_Bussard_Collector_Dome_Texture = texture {
	radial
	texture_map {
	    [0.0 	pigment {color rgbt <0.9,0.6,0.5,0.1>} finish {ambient WARP_POWER_LEVEL/100 diffuse 0 brilliance 0 reflection 0 specular 0}]		    
		[0.4 	pigment {color rgbt <0.9,0.6,0.5,0.05>} finish {ambient WARP_POWER_LEVEL/200 diffuse 0 brilliance 0 reflection 0 specular 0}]
		[0.5 	pigment {color rgbt <0.9,0.6,0.5,0.0>} finish {ambient WARP_POWER_LEVEL/200 diffuse 0 brilliance 0 reflection 0 specular 0}]
		[0.6 	pigment {color rgbt <0.9,0.6,0.5,0.05>} finish {ambient WARP_POWER_LEVEL/200 diffuse 0 brilliance 0 reflection 0 specular 0}]
	    [1.0 	pigment {color rgbt <0.9,0.6,0.5,0.1>} finish {ambient WARP_POWER_LEVEL/100 diffuse 0 brilliance 0 reflection 0 specular 0}]		    
	}
	rotate x*90
	scale 7.5
	frequency 12
}

#declare Outer_Bussard_Collector_Dome_Interior = interior {
	ior 1
	fade_distance 1
	fade_power 1001
	fade_color rgb <0.9,0.9,0.9>
}
	
#declare Outer_Bussard_Collector_Dome_Material = material {
	texture {Outer_Bussard_Collector_Dome_Texture} 
	interior {Outer_Bussard_Collector_Dome_Interior}
}

#declare Inner_Bussard_Collector_Dome_Texture = texture {
	pigment {color rgbt <1,1,1,0.0625>}
	finish {
		ambient 0.7
		diffuse 0 
		brilliance 0 
		reflection 0 
		specular 0
	}
}

#macro Bussard_Collector_Xmas_Light(emit_color,rotation_angle,brightness_factor)
	#local adjusted_brightness_factor=brightness_factor*(WARP_POWER_LEVEL/100)*10;
	media {
		intervals 1
		samples 100
		confidence 0.99
		variance 1/128
		ratio 1
		emission rgb emit_color*adjusted_brightness_factor
		method 2
		jitter 0
		density {spherical scale 2}
		translate <0,BC_DOME_RADIUS-2.5,2.5>		
		rotate z*rotation_angle
	}	
#end

#macro Inner_Bussard_Collector_Dome_Interior(direction_vector)

	ior 1
	fade_distance 0.5
	fade_power 1001
	fade_color rgb <0.9,0.9,0.9>

		 
	// Arrange the colored lights in opposite directions
	// depending on the spin direction, and pulse the lights
	// in the OPPOSITE direction of spin: 
	#local switch_factor=mod(frame_number,30); 
	#local brightness_factor=array[10];
	#local brightness_factor[0]=2;
	#local brightness_factor[1]=2;
	#local brightness_factor[2]=2;
	#local brightness_factor[3]=2;
	#local brightness_factor[4]=2;
	#local brightness_factor[5]=2;
	#local brightness_factor[6]=2;
	#local brightness_factor[7]=2;
	#local brightness_factor[8]=2;
	#local brightness_factor[9]=2;
	#switch(switch_factor)
		#range(0,2)
			#local brightness_factor[0]=3;
			#local brightness_factor[1]=4;
			#local brightness_factor[2]=5;
			#local brightness_factor[3]=6;
			#local brightness_factor[4]=5;
			#local brightness_factor[5]=4;
			#local brightness_factor[6]=3;
		#break
		#range(3,5)
			#local brightness_factor[1]=3;
			#local brightness_factor[2]=4;
			#local brightness_factor[3]=5;
			#local brightness_factor[4]=6;
			#local brightness_factor[5]=5;
			#local brightness_factor[6]=4;
			#local brightness_factor[7]=3;
		#break
		#range(6,8)
			#local brightness_factor[2]=3;
			#local brightness_factor[3]=4;
			#local brightness_factor[4]=5;
			#local brightness_factor[5]=6;
			#local brightness_factor[6]=5;
			#local brightness_factor[7]=4;
			#local brightness_factor[8]=3;
		#break
		#range(9,11)
			#local brightness_factor[3]=3;
			#local brightness_factor[4]=4;
			#local brightness_factor[5]=5;
			#local brightness_factor[6]=6;
			#local brightness_factor[7]=5;
			#local brightness_factor[8]=4;
			#local brightness_factor[9]=3;
		#break
		#range(12,14)
			#local brightness_factor[4]=3;
			#local brightness_factor[5]=4;
			#local brightness_factor[6]=5;
			#local brightness_factor[7]=6;
			#local brightness_factor[8]=5;
			#local brightness_factor[9]=4;
			#local brightness_factor[0]=3;
		#break
		#range(15,17)
			#local brightness_factor[5]=3;
			#local brightness_factor[6]=4;
			#local brightness_factor[7]=5;
			#local brightness_factor[8]=6;
			#local brightness_factor[9]=5;
			#local brightness_factor[0]=4;
			#local brightness_factor[1]=3;
		#break
		#range(18,20)
			#local brightness_factor[6]=3;
			#local brightness_factor[7]=4;
			#local brightness_factor[8]=5;
			#local brightness_factor[9]=6;
			#local brightness_factor[0]=5;
			#local brightness_factor[1]=4;
			#local brightness_factor[2]=3;
		#break
		#range(21,23)
			#local brightness_factor[7]=3;
			#local brightness_factor[8]=4;
			#local brightness_factor[9]=5;
			#local brightness_factor[0]=6;
			#local brightness_factor[1]=5;
			#local brightness_factor[2]=4;
			#local brightness_factor[3]=3;
		#break
		#range(24,26)
			#local brightness_factor[8]=3;
			#local brightness_factor[9]=4;
			#local brightness_factor[0]=5;
			#local brightness_factor[1]=6;
			#local brightness_factor[2]=5;
			#local brightness_factor[3]=4;
			#local brightness_factor[4]=3;
		#break
		#else
			#local brightness_factor[9]=3;
			#local brightness_factor[0]=4;
			#local brightness_factor[1]=5;
			#local brightness_factor[2]=6;
			#local brightness_factor[3]=5;
			#local brightness_factor[4]=4;
			#local brightness_factor[5]=3;
		#break
	#end
	#if (WARP_POWER_LEVEL > 0)
		#if (direction_vector=-1)
			Bussard_Collector_Xmas_Light(<1.0,1.0,1.0>,  0,brightness_factor[0])
			Bussard_Collector_Xmas_Light(<0.0,1.0,1.0>, 36,brightness_factor[1])
			Bussard_Collector_Xmas_Light(<1.0,0.5,0.5>, 72,brightness_factor[2])
			Bussard_Collector_Xmas_Light(<1.0,1.0,0.5>,108,brightness_factor[3])
			Bussard_Collector_Xmas_Light(<0.0,1.0,1.0>,144,brightness_factor[4])
			Bussard_Collector_Xmas_Light(<0.0,0.0,1.0>,180,brightness_factor[5])
			Bussard_Collector_Xmas_Light(<1.0,1.0,0.5>,216,brightness_factor[6])
			Bussard_Collector_Xmas_Light(<1.0,1.0,0.5>,252,brightness_factor[7])
			Bussard_Collector_Xmas_Light(<1.0,0.0,0.0>,288,brightness_factor[8])
			Bussard_Collector_Xmas_Light(<0.0,0.0,1.0>,324,brightness_factor[9])
		#else
			Bussard_Collector_Xmas_Light(<0.0,0.0,1.0>,324,brightness_factor[9])
			Bussard_Collector_Xmas_Light(<1.0,0.0,0.0>,288,brightness_factor[8])
			Bussard_Collector_Xmas_Light(<1.0,1.0,0.5>,252,brightness_factor[7])
			Bussard_Collector_Xmas_Light(<1.0,1.0,0.5>,216,brightness_factor[6])
			Bussard_Collector_Xmas_Light(<0.0,0.0,1.0>,180,brightness_factor[5])
			Bussard_Collector_Xmas_Light(<0.0,1.0,1.0>,144,brightness_factor[4])
			Bussard_Collector_Xmas_Light(<1.0,1.0,0.5>,108,brightness_factor[3])
			Bussard_Collector_Xmas_Light(<1.0,0.5,0.5>, 72,brightness_factor[2])
			Bussard_Collector_Xmas_Light(<0.0,1.0,1.0>, 36,brightness_factor[1])
			Bussard_Collector_Xmas_Light(<1.0,1.0,1.0>,  0,brightness_factor[0])
		#end
	#end
#end

#macro Inner_Bussard_Collector_Dome_Material(direction_vector)
	texture {Inner_Bussard_Collector_Dome_Texture} 
	interior {Inner_Bussard_Collector_Dome_Interior(direction_vector)}
#end

// This macro renders the dome. A positive direction_vector rotates the collector clockwise 
// (for the port nacelle) and a negative value rotates it counter-clockwise.
#macro Bussard_Collector_Dome(direction_vector)
	union {		
		
		#local rotation_factor=WARP_NACELLE_RPM/60/ANIM_FRAMES_PER_SECOND;		
		
		// Outer dome: 
		sphere {
			<0,0,0> BC_DOME_RADIUS
 			material {Outer_Bussard_Collector_Dome_Material}
 			hollow on
			#if (WARP_NACELLE_RPM>0)
				rotate z*frame_number*rotation_factor*360*direction_vector
			#end
		} 
		 
		// Inner dome: 
		sphere {
			<0,0,0> BC_DOME_RADIUS-0.0001
			material {Inner_Bussard_Collector_Dome_Material(direction_vector)}
			hollow on
		} 
	}    
#end

#declare Bussard_Collector_Collar_Panel_Texture = texture {
	quilted
	texture_map {
		[0.0 Metallic_Hull_Plating(ENTERPRISE_GRAY(85),0.78,0.20,0.02)]
		[1.0 Metallic_Hull_Plating(ENTERPRISE_GRAY(25),0.90,0.10,0.00)]
	}
	control0 0.66
	control1 0
   	scale <1,4.17255864,BC_COLLAR_LENGTH>
   	translate <0,1,0>
}

#declare Bussard_Collector_Collar_Panels = union {
	#local rotation_angle=0;
	#while (rotation_angle<=360)
		intersection {
			difference {
				cylinder {<0,0,0>, <0,0,BC_COLLAR_LENGTH>, WARP_NACELLE_MAX_RADIUS+0.000001}
				cylinder {<0,0,-1>, <0,0,BC_COLLAR_LENGTH+1>, WARP_NACELLE_MAX_RADIUS}
			}	
			box {<0,-2.086279,0>,<WARP_NACELLE_MAX_RADIUS+5,2.086279,BC_COLLAR_LENGTH>}
			texture {Bussard_Collector_Collar_Panel_Texture}
			rotate z*rotation_angle
			#local rotation_angle=rotation_angle+30;
		} 
	#end
} 

// This macro renders the entire Bussard Collector assembly. It's a macro
// so that the artist change the direction of rotation for each nacelle:
#macro Bussard_Collector(direction_vector)
	union {  
		
		// The vents just aft of the Bussard collector collar:
		difference {
			union {
				#local BC_OVERFLUX_VENT_BLADE_LENGTH = BC_OVERFLUX_VENT_LENGTH/4;
				#declare BOVentCount = 0;
				#while (BOVentCount < 4)
					cone {<0,0,BOVentCount*BC_OVERFLUX_VENT_BLADE_LENGTH>, WARP_NACELLE_MAX_RADIUS, <0,0,BC_OVERFLUX_VENT_BLADE_LENGTH+(BOVentCount*BC_OVERFLUX_VENT_BLADE_LENGTH)>, WARP_NACELLE_MAX_RADIUS-BC_OVERFLUX_VENT_BLADE_LENGTH
				 		texture {
				 			gradient z
				 			texture_map {
				 				[0.0 Metallic_Hull_Plating(ENTERPRISE_GRAY(60),0.79,0.19,0.02)]
				 				[1.0 Metallic_Hull_Plating(ENTERPRISE_GRAY(0),0.79,0.19,0.02)]
				 			}   
				 			translate z*BOVentCount*BC_OVERFLUX_VENT_BLADE_LENGTH
				 		}
					}
				  #declare BOVentCount = BOVentCount+1;
				#end
			} 
			
		}
		
		// The cylindical section around between the vents and the Bussard collector dome:
		object {Bussard_Collector_Collar_Panels translate z*BC_COLLAR_OFFSET}
		cylinder {<0,0,BC_COLLAR_OFFSET>,<0,0,BC_COLLAR_OFFSET-0.125>,WARP_NACELLE_MAX_RADIUS texture {Metallic_Hull_Plating(ENTERPRISE_GRAY(60),0.75,0.24,0.01)}}
		
		// The lip around the bussard collector dome:
		difference {
			
			cone {<0,0,0>, WARP_NACELLE_MAX_RADIUS , <0,0,BC_LIP_LENGTH>, BC_DOME_RADIUS+0.125}
			cylinder {<0,0,100>,<0,0,-100>,BC_DOME_RADIUS}
			
			// The three cutouts for the hold-down strips (see below):
			#local cutout_count = 1;
			#while (cutout_count <= 3)
				box {
					<-0.25,0,0>,<0.25,-100,100>
					rotate z*(120*cutout_count)
			 	}
				#local cutout_count = cutout_count + 1;	 		
		 	#end         
		 	translate z*BC_LIP_OFFSET
		  	texture {
		  		radial
		  		texture_map {
		  			[0.0 Metallic_Hull_Plating(ENTERPRISE_GRAY(75),0.75,0.24,0.01)]
		  			[0.5 Metallic_Hull_Plating(ENTERPRISE_GRAY(80),0.75,0.24,0.01)]
		  			[1.0 Metallic_Hull_Plating(ENTERPRISE_GRAY(75),0.75,0.24,0.01)]
		  		}
		  		rotate x*90
		  		scale 7.5
		  		frequency 15
		  	}		
		} 
		
		// The three little metal strips that appear to "hold down" the Bussard collector dome:
		#local strip_count = 1;
		#while (strip_count <= 3)
			union {
				box {<-0.25,-0.0625,0>,<0.25,0.0625,1.25>}
				cylinder {<0,-0.0625,1.25>,<0,0.0625,1.25>,0.25}
				sphere {<0,-0.0625,0.375>,0.125}
				sphere {<0,-0.0625,1.125>,0.125}
				translate <0,-BC_DOME_RADIUS,BC_LIP_OFFSET>
				rotate z*(120*strip_count)
				texture {Metallic_Hull_Plating(ENTERPRISE_SILVER,0.8,0.17,0.03)}
			}
			#local strip_count = strip_count + 1;
		#end
		
		
		// The bussard collector dome itself:
		object {Bussard_Collector_Dome(direction_vector) translate z*BC_DOME_OFFSET}
	}
#end

/*******************************************************************************
* Nacelle Hood                                                                 *
* Not sure what else to call it... this is the dark gray hood on the underside *
* of the nacelle just forward of the nacelle pylon.                            *
*******************************************************************************/
#declare Nacelle_Hood = difference {
	object {Warp_Nacelle_Body(0.001,0)}
	plane {z, 32.5}
	plane {y, -4.75 inverse}
	object {Rounded_Cylinder(100,4) translate <-7,-4,0>}
	object {Rounded_Cylinder(100,4) translate <7,-4,0>}
	texture {
		quilted
		texture_map {
			[0.0 Metallic_Hull_Plating(ENTERPRISE_GRAY(55),0.72,0.27,0.01)]
			[1.0 Metallic_Hull_Plating(ENTERPRISE_GRAY(0),0.90,0.10,0.00)]
		}
		control0 0
		control1 0
		scale <6,6,12.5>
	}
}


/*******************************************************************************
* Nacelle End Cap                                                              *
* This is the corrogated endcap and ball assembly at aft end of each nacelle.  *
* Also known by the ungainly moniker of "space energy/matter source (field     *
* restoration) cowling"                                                        *
*******************************************************************************/
#declare Nacelle_End_Cap_Panel_Texture = texture {
	quilted
	texture_map {
    	[0.0 Metallic_Hull_Plating(ENTERPRISE_GRAY(80),0.75,0.24,0.01)]
    	[1.0 Metallic_Hull_Plating(ENTERPRISE_GRAY(60),0.90,0.10,0.00)]
	} 
   	scale <1,1.6,2>
   	translate <WARP_NACELLE_MIN_RADIUS,0,-WARP_NACELLE_ENDCAP_COLLAR_LENGTH>
}

#declare Nacelle_End_Cap_Panels = union {
	#local rotation_angle=0;
	#while (rotation_angle<=360)
		intersection {
			difference {
				cylinder {<0,0,-0.25>, <0,0,-WARP_NACELLE_ENDCAP_COLLAR_LENGTH+0.25>, WARP_NACELLE_MIN_RADIUS+0.000001}
				cylinder {<0,0,-1>, <0,0,-WARP_NACELLE_ENDCAP_COLLAR_LENGTH-1>, WARP_NACELLE_MIN_RADIUS}
			}
			#local y_scale=0.850125;
			box {<0,y_scale,-0.25>,<WARP_NACELLE_MIN_RADIUS+1,-y_scale,-(WARP_NACELLE_ENDCAP_COLLAR_LENGTH-0.25)>}
			texture {Nacelle_End_Cap_Panel_Texture}
			rotate z*rotation_angle
			#local rotation_angle=rotation_angle+15;
		} 
	#end
} 


#declare Nacelle_End_Cap_Ball_Texture=
	texture {
	    pigment {rgbt <1,1,1,0.5>}
	    finish {
	        ambient (WARP_POWER_LEVEL*0.0075)
	        diffuse 0
	        reflection 0.5
	        phong 0.3
	        phong_size 60
	    }
	}

#declare Nacelle_End_Cap_Ball_Interior =
	interior {
		ior 1.5
		fade_power 2
		fade_distance 5
		fade_color <1,1,0.95>
		#if (WARP_POWER_LEVEL>0)
		media {
			intervals 1
			samples 10
			confidence 0.99
			variance 1/128
			ratio 1
			emission rgb (WARP_POWER_LEVEL/100)
			method 2
			jitter 0
			density {spherical scale 5}
		}
		#end
	}
	
#declare Nacelle_End_Cap_Ball_Material =
	material {texture {Nacelle_End_Cap_Ball_Texture} interior {Nacelle_End_Cap_Ball_Interior}}

#macro Nacelle_End_Cap_Light (bc_red, bc_green, bc_blue, rotation_angle, brightness_factor)
	light_source {
		#local adjusted_brightness_factor=brightness_factor*(WARP_POWER_LEVEL/100);
		y*0
		color rgb <bc_red*adjusted_brightness_factor,bc_green*adjusted_brightness_factor,bc_blue*adjusted_brightness_factor>
		fade_distance 2 // was 7.5
		fade_power 1 
	} 
#end
  
#declare Nacelle_End_Cap_Step_1 = 
	union {
		cylinder {<0,0,0>,<0,0,-0.25>,WARP_NACELLE_MIN_RADIUS-0.25 texture {Metallic_Hull_Plating(ENTERPRISE_DARKSLATEGRAY,0.80,0.19,0.01)}}
		cylinder {<0,0,-0.25>,<0,0,-(WARP_NACELLE_ENDCAP_COLLAR_LENGTH-0.25)> WARP_NACELLE_MIN_RADIUS texture {Metallic_Hull_Plating(ENTERPRISE_RED,0.75,0.24,0.01)}}
		cylinder {<0,0,-(WARP_NACELLE_ENDCAP_COLLAR_LENGTH-0.25)>,<0,0,-WARP_NACELLE_ENDCAP_COLLAR_LENGTH>,WARP_NACELLE_MIN_RADIUS-0.25 texture {Metallic_Hull_Plating(ENTERPRISE_DARKSLATEGRAY,0.80,0.19,0.01)}}
		object {Nacelle_End_Cap_Panels}
	} 

#declare Nacelle_End_Cap_Step_2 =
	difference {
		cylinder {<0,0,0>,<0,0,-WARP_NACELLE_ENDCAP_LENGTH>,WARP_NACELLE_MIN_RADIUS}
		// The following loop differences out the cap with tiny cylinders to give it 
		// a corrugated look; much nicer looking in closeup shots but really slows down
		// rendering speed because of the low anti-aliasing threshold required:
		#if (DETAIL_LEVEL >= 3)
			#declare Count=0;
			#while (Count < 120) 
				cylinder {<0,0,0.1> <0,0,-WARP_NACELLE_ENDCAP_LENGTH-0.1>, 0.125 
					translate x*-WARP_NACELLE_MIN_RADIUS rotate z*(3*Count)
				}
				#declare Count=Count+1;
			#end
		#end
 		texture {Metallic_Hull_Plating(ENTERPRISE_DARKSLATEGRAY,0.75,0.24,0.01)}		
	}

// Ohhh, this was a bitch to figure out. This step intersects and differences
// out the curvature of the end cap. I took a side photo of the original 
// shooting model and figured out the two curves' origins and radii, and then
// tweaked the size and position until a smooth sweep was achieved. Blecch.
#declare Nacelle_End_Cap_Step_3 =       
	difference {
		intersection { 
			object {Nacelle_End_Cap_Step_2}
  			union {
    			box { <-20,-10,-6.1>, <20,2,0> }
    			cylinder {<-20,9.325,-2.625>, <20,9.325,-2.625>, 9}
  			}
		}
		cylinder {<-20,-7.39,-9.3>, <20,-7.39,-9.3>, 9}
		texture {
			quilted
			texture_map {
		    	[0.0 Metallic_Hull_Plating(ENTERPRISE_DARKSLATEGRAY,0.75,0.24,0.01)]
		    	[1.0 Metallic_Hull_Plating(ENTERPRISE_DARKSLATEGRAY,0.90,0.10,0.00)]
			} 
		   	scale <1,3,1>
		   	//translate <WARP_NACELLE_MIN_RADIUS,0,-WARP_NACELLE_ENDCAP_COLLAR_LENGTH>
		}
	}

// I used pretty much the same technique here: find the radius and then measure
// the origin's offset in the x-z plane:
#declare Nacelle_End_Cap_Ball =
	union { 
		difference {
			sphere {<0,0,0> 5 hollow on}
			plane {z,0 inverse rotate x*-50}
			material {Nacelle_End_Cap_Ball_Material}
		}
		#if (WARP_POWER_LEVEL > 0)
			object {Nacelle_End_Cap_Light(1,1,1,0,7) translate <0,-0,-4.75> rotate x*-20}
		#end
	}
	
#declare Nacelle_End_Cap =
	union {
		
		difference {		
			object {Nacelle_End_Cap_Step_1}
			sphere {<0,0,-6.5>, 5 texture {Metallic_Hull_Plating(ENTERPRISE_SILVER,0.4,0.4,0.2)}}
		}
		difference {
			object {Nacelle_End_Cap_Step_3 translate z*-WARP_NACELLE_ENDCAP_COLLAR_LENGTH}
			sphere {<0,0,-6.5>, 5 texture {Metallic_Hull_Plating(ENTERPRISE_SILVER,0.4,0.4,0.2)}}
		}
		object {Nacelle_End_Cap_Ball translate <0,0,-6.5>}
	} 

/*******************************************************************************
* Decals                                                                       *
*******************************************************************************/
#declare Nacelle_Registration_Text =
	text {
	  ttf
	  "SFAMUSAF.ttf",
	  "NCC-1701",
	  10,
	  <0.025,0,0>
	  scale <7,7,1>  
	}

// These are the red parts of the pennant:
#declare Nacelle_Pennant_Red = union {
	
	prism {
		linear_sweep
		linear_spline
		5,-5,
		5,
		<-22.3,0.6>,<-44.25,0.5>,<-45,-0.5>,<-22.3,-0.6>,<-22.3,0.6>
	}
	
	prism {
		linear_sweep
		linear_spline
		5,-5,
		5,     
		<3.4,0.8>,<3.4,-0.8>,<38,-1.1>,<39.5,1.1>,<3.4,0.8>
	}
	
	prism {
		linear_sweep
		linear_spline
		5,-5,
		5,     
		<40.5,1.1>,<39,-1.1>,<45.5,-1.1>,<47,1.1>,<40.5,1.1>
	}
	
	rotate <0,-90,-90>
}

// This is the gold swoosh (stolen from secondary.inc, which is why the final translation and scaling is required):
#declare Nacelle_Pennant_Swoosh = difference {
		
	union {
	
		cylinder {<5,1.785,26.635>,<-5,1.785,26.635>,0.265}
		cylinder {<5,-1.035,26.575>,<-5,-1.035,26.575>,0.375}
		cylinder {<5,0,0>,<-5,0,0>,0.75 scale <1,1.2467,1> translate <0,0.115,27.35>}

		prism {
			linear_sweep
			linear_spline
			5,-5
			7,
			<26.88,1.9>,<27.9132,0.7325>,<27.8,-0.65>,<26.85,-1.3>,<26.4064,-0.7921>,<26.4064,1.6516>,<26.88,1.9>
			rotate <0,-90,-90>
		} 
	}
	
	cylinder {<5.0001,0,0>,<-5.0001,0,0>,1.13 scale <1,1.44,1> translate <0,0.5,25.625>}	
	
	translate <0,-0.25,12.75>
	
	scale 1.1
}

#declare Starboard_Nacelle_Registration = difference {
                                                      
	union {
  		
		intersection {
			object {Warp_Nacelle_Body(0.0001, 0)}
			object {Nacelle_Pennant_Red translate x*8}
			texture {Painted_Hull_Plating(ENTERPRISE_RED,0.75,0.24,0.01)}			
		}

		intersection {
			object {Warp_Nacelle_Body(0.0002, 0)}
			object {Nacelle_Pennant_Swoosh translate x*8} 
			texture {Painted_Hull_Plating(ENTERPRISE_GOLD,0.75,0.24,0.01)}
		}   
		
		intersection {
			object {Warp_Nacelle_Body(0.0001, 0)}
			object {Nacelle_Registration_Text rotate <0,-90,0> translate <10,-2,-21.25>}
			texture {Painted_Hull_Plating(ENTERPRISE_BLACK,0.75,0.24,0.01)}
		}
	}
	
	plane {x,0} 
	object {Warp_Nacelle_Body(0,0)}	
}

#declare Port_Nacelle_Registration = difference {
                                                      
	union {
  		
		intersection {
			object {Warp_Nacelle_Body(0.0001, 0)}
			object {Nacelle_Pennant_Red translate x*-8}
			texture {Painted_Hull_Plating(ENTERPRISE_RED,0.75,0.24,0.01)}			
		}

		intersection {
			object {Warp_Nacelle_Body(0.0002, 0)}
			object {Nacelle_Pennant_Swoosh translate x*-8} 
			texture {Painted_Hull_Plating(ENTERPRISE_GOLD,0.75,0.24,0.01)}
		}   
		
		intersection {
			object {Warp_Nacelle_Body(0.0001, 0)}
			object {Nacelle_Registration_Text rotate <0,90,0> translate <-10,-2,2.25>}
			texture {Painted_Hull_Plating(ENTERPRISE_BLACK,0.75,0.24,0.01)}
		}
	}
	
	plane {x,0 inverse} 
	object {Warp_Nacelle_Body(0,0)}	
}

// This is the red outline around the ventral inspection hatch:
#declare Inspection_Hatch_Outline = difference {
	
	intersection {
		box {<3.2,0,6>,<-3.2,-10,30>}
		object {Warp_Nacelle_Body(0.0001, 0)}
	}
	
	box {<2.9,1,6.3>,<-2.9,-11,29.7>}
	object {Warp_Nacelle_Body(0,0)}

	texture {Painted_Hull_Plating(ENTERPRISE_RED,0.75,0.24,0.01)}
}

// Sadly, this is a "fake" spotlight that doesn't actually light the registration.
// I couldn't get a satisfactory falloff and focus of the light beam when I tried
// positioning the actual spotlight light source at the location of the physical
// representation of the spotlight, so I faked it by putting the actual light
// source about 3 meters above where the housing is located.
#declare Nacelle_Registration_Light_Housing = union {
	cylinder {<-7.5,0,12>,<-6.5,0,14>,0.5 texture {Metallic_Hull_Plating(ENTERPRISE_RED,0.75,0.24,0.01)}}
	#if (NO_EXTERIOR_LIGHTS=false)
		sphere {<-7.75,0,12>,0.125 texture {pigment {color rgb <1,1,1>} finish {ambient 1.0}}}
	#end
}

#declare Nacelle_Registration_Light_Source =
	light_source {
		0*x
		color rgb <4,4,3.6>
		spotlight
		translate <-10,0,20>
		point_at <-7.1,0,-10>
		radius 0.5
		falloff 7.5
		fade_distance 35
		fade_power 10
	}


/*******************************************************************************
* Final Stage Magnatomic Flux Chillers                                         *
* (the rectangular corrugated grilles at the inboard and outboard aft          *
* end of each nacelle)                                                         *
*******************************************************************************/
#local FLUX_CHILLER_LENGTH = 8.85;
#local FLUX_CHILLER_HEIGHT = 4.5;

#declare Final_Stage_Magnatomic_Flux_Chiller =
	difference {
		box {<-1,FLUX_CHILLER_HEIGHT/2,-FLUX_CHILLER_LENGTH/2>, <1,-FLUX_CHILLER_HEIGHT/2,FLUX_CHILLER_LENGTH/2>}
		// The following loop differences out the chiller with tiny cylinders to give it 
		// a corrugated look; similar to the technique used on the nacelle end cap.
		#if (DETAIL_LEVEL >= 3)
			#declare Count=0;
			#while (Count <= 16) 
				cylinder {<1,FLUX_CHILLER_HEIGHT/2-Count*.28125,-10> <1,FLUX_CHILLER_HEIGHT/2-Count*.28125,10>, 0.125}
				#declare Count=Count+1.25;
			#end		
		#end
 		texture {Metallic_Hull_Plating(ENTERPRISE_DARKSLATEGRAY,0.75,0.24,0.01)}		
	}

/*******************************************************************************
* Main energy stage magnatomic flux chiller                                    *
* The multi-grille assembly on the inboard side of each nacelle                *
*******************************************************************************/
#declare Magnatomic_Flux_Grille_Texture = 
  texture {
    image_pattern {gif "grille_texture.gif"}
    texture_map {
    	[0.0 Metallic_Hull_Plating(ENTERPRISE_BLACK,0,0,0)]
    	[1.0 Metallic_Hull_Plating(ENTERPRISE_SILVER,0.70,0.10,0.20)]
    } 
    translate x*-0.25
    rotate x*-90
    scale 5/4
}

#declare Main_Energy_Stage_Magnatomic_Flux_Chiller = 
	union {
	
		// The prism-shaped aft end of the assembly:
		union {
			difference {
				union {
					prism {                                
						linear_sweep
						linear_spline
				  		-0.01,
				   		0.5,
				  		5,
				  		<0.25,-48>,<1.75,-43>,<-1.75,-43>,<-0.25,-48>,<0.25,-48>
				  	}
					cylinder {<0.25,0,-48>,<1.9741,0,-42.253>,0.5}
					cylinder {<-0.25,0,-48>,<-1.9741,0,-42.253>,0.5}
			  	}
			  	plane {z,-43 inverse}
			}
			cylinder {<-1.75,0,-43>,<1.75,0,-43>,0.5}
		}
		
		// The long part of the assembly:
		union {
		
			// The longer of the two grilles...
			union {       
			
				// The grille facing:
				box {<-2,0.25,-43.25>,<2,-0.25,4.75> texture {Magnatomic_Flux_Grille_Texture}}
				
				// Top tube:
				difference {
					object {Rounded_Cylinder(50,0.5) translate <-1.75,0,-20> texture {Metallic_Hull_Plating(ENTERPRISE_GRAY(65),0.7,0.2,0.1)}}
					plane {z,-43}
				}
		
				// Bottom tube:		
				difference {
					object {Rounded_Cylinder(50,0.5) translate <1.75,0,-20> texture {Metallic_Hull_Plating(ENTERPRISE_GRAY(65),0.7,0.2,0.1)}}
					plane {z,-43}
				}
			 
			 	// Round off the end of the grille facing:
				cylinder {<-2,0,4.75>,<2,0,4.75>,0.25 texture {Metallic_Hull_Plating(ENTERPRISE_SILVER,0.7,0.2,0.1)}}				
			}
			
			// The two little tubes that are above and below the aft point where the 
			// inboard intercooler mates to the warp nacelle:
			object {Rounded_Cylinder(2.75,0.5) translate <+1.75,0,6.875> texture {Metallic_Hull_Plating(ENTERPRISE_GRAY(65),0.7,0.2,0.1)}}			
			object {Rounded_Cylinder(2.75,0.5) translate <-1.75,0,6.875> texture {Metallic_Hull_Plating(ENTERPRISE_GRAY(65),0.7,0.2,0.1)}}						
			
			// The shorter of the two grilles... this is the one under the inboard intercooler:
			union {       
			
				// The grille facing, rounded off on both ends:
				box {<-2,0.25,9>,<2,-0.25,33> texture {Magnatomic_Flux_Grille_Texture}}
				cylinder {<-2,0,9>,<2,0,9>,0.25 texture {Metallic_Hull_Plating(ENTERPRISE_SILVER,0.7,0.2,0.1)}}
				cylinder {<-2,0,33>,<2,0,33>,0.25 texture {Metallic_Hull_Plating(ENTERPRISE_SILVER,0.7,0.2,0.1)}}
				
				// Top and bottom tubes:
				object {Rounded_Cylinder(24.5,0.5) translate <-1.75,0,21> texture {Metallic_Hull_Plating(ENTERPRISE_GRAY(65),0.7,0.2,0.1)}}
				object {Rounded_Cylinder(24.5,0.5) translate  <1.75,0,21> texture {Metallic_Hull_Plating(ENTERPRISE_GRAY(65),0.7,0.2,0.1)}}			 
			}
		}
         
        // The control reactor, whose major component conveniently enough 
        // is an intercooler assembly without the inset grille:
		union {
			object {Intercooler_Assembly rotate <-90,-90,0> translate <0,0.5,21>}
			union {
				difference {
					prism {                                
						linear_sweep
						linear_spline
				  		0.5,
				  		-2,
				  		7,
				  		<0.875,-4.5>,<1.5,0>,<1.5,4.5>,<-1.5,4.5>,<-1.5,0>,<-0.875,-4.5>,<0.875,-4.5>
				  		sturm
					}
					
					plane {z,0 translate <0,1,1.25> rotate x*-70 inverse}
				}
				cylinder {<0.75,0.375,1>,<0.75,0.125,2>,0.25}
				cylinder {<-0.75,0.375,1>,<-0.75,0.125,2>,0.25}
		  		translate <0,1.5,39>
			}
		}
		
	  	texture {Metallic_Hull_Plating(ENTERPRISE_GRAY(65),0.7,0.2,0.1)}		
	}

/*******************************************************************************
* Warp Nacelle Casing                                                          *
* This is the nacelle body with the main energy stage magnatomic flux chiller  *
* array differenced out and added in. The differencing is done on the top of   *
* the casing so that the port and starboard nacelles can both use it (port     *
* rotates it -90 degrees; starboard rotates it 90 degrees)                     *
*******************************************************************************/
#macro Warp_Nacelle_Hull_Panel_Texture(xy_scale,z_scale,z_offset,panel_color,joint_color)
	quilted
	texture_map {
		[0.0 Metallic_Hull_Plating(panel_color,0.75,0.24,0.01)]
		[1.0 Metallic_Hull_Plating(joint_color,0.90,0.10,0.00)]
	}
	control0 0
	control1 0
	scale <xy_scale,xy_scale,z_scale>
	translate <0,y_scale,z_scale/2+z_offset>
#end

#macro Warp_Nacelle_Hull_Rectangular_Panel(x_offset,slice_angle,translate_angle,z_length,z_offset,panel_color,joint_color,y_scale_adjust,z_scale_adjust)
	difference {
		#local y_scale = sin(radians(slice_angle/2))*((WARP_NACELLE_MAX_RADIUS+WARP_NACELLE_MIN_RADIUS)/2)*2;
		object {Warp_Nacelle_Body(x_offset,0)}
		object {Warp_Nacelle_Body(x_offset-0.000001,0.000001)}
		union {
			plane {y,0 rotate z*-slice_angle/2}
			plane {y,0 rotate z*slice_angle/2 inverse}
			plane {z,z_offset-z_length/2}
			plane {z,z_offset+z_length/2 inverse}
		}
		texture {Warp_Nacelle_Hull_Panel_Texture(y_scale*y_scale_adjust,z_length*z_scale_adjust,z_offset,panel_color,joint_color)}
		rotate z*translate_angle
	}	
#end

#declare Warp_Nacelle_Hull_Plating = union {

	#local rotation_angle=0;
	#while (rotation_angle<=340)	
		object{Warp_Nacelle_Hull_Rectangular_Panel(0.0000001,20,rotation_angle,8,WARP_NACELLE_LENGTH/2-4,ENTERPRISE_GRAY(80),ENTERPRISE_GRAY(60),1,1)}
		#local rotation_angle=rotation_angle+20;
	#end
 
	// These are the joints between large plating sections:	 	
	#local rotation_angle=0;
	#while (rotation_angle<=300)	
		object{Warp_Nacelle_Hull_Rectangular_Panel(0.0000001,60,rotation_angle,2,WARP_NACELLE_LENGTH/2-9,ENTERPRISE_GRAY(80),ENTERPRISE_GRAY(60),1,1)}
		object{Warp_Nacelle_Hull_Rectangular_Panel(0.0000001,60,rotation_angle+30,2,WARP_NACELLE_LENGTH/2-33,ENTERPRISE_GRAY(80),ENTERPRISE_GRAY(60),1,1)}
		object{Warp_Nacelle_Hull_Rectangular_Panel(0.0000001,60,rotation_angle,2,WARP_NACELLE_LENGTH/2-61,ENTERPRISE_GRAY(80),ENTERPRISE_GRAY(60),1,1)}
		object{Warp_Nacelle_Hull_Rectangular_Panel(0.0000001,60,rotation_angle+30,2,WARP_NACELLE_LENGTH/2-85,ENTERPRISE_GRAY(80),ENTERPRISE_GRAY(60),1,1)}
		object{Warp_Nacelle_Hull_Rectangular_Panel(0.0000001,60,rotation_angle,2,WARP_NACELLE_LENGTH/2-113,ENTERPRISE_GRAY(80),ENTERPRISE_GRAY(60),1,1)}
		#local rotation_angle=rotation_angle+60;
	#end
	
	#local rotation_angle=15;
	#while (rotation_angle<=345)	
		object{Warp_Nacelle_Hull_Rectangular_Panel(0.0000001,30,rotation_angle,22,WARP_NACELLE_LENGTH/2-21,ENTERPRISE_GRAY(80),ENTERPRISE_GRAY(60),1,1)}
		object{Warp_Nacelle_Hull_Rectangular_Panel(0.0000001,30,rotation_angle,22,WARP_NACELLE_LENGTH/2-73,ENTERPRISE_GRAY(80),ENTERPRISE_GRAY(60),1,1)}
		object{Warp_Nacelle_Hull_Rectangular_Panel(0.0000001,30,rotation_angle,14.288,-WARP_NACELLE_LENGTH/2+7.144,ENTERPRISE_GRAY(80),ENTERPRISE_GRAY(60),1,1)}
		#local rotation_angle=rotation_angle+30;
	#end

	#local rotation_angle=0;
	#while (rotation_angle<=330)	
		object{Warp_Nacelle_Hull_Rectangular_Panel(0.0000001,30,rotation_angle,26,WARP_NACELLE_LENGTH/2-47,ENTERPRISE_GRAY(80),ENTERPRISE_GRAY(60),1,1)}
		object{Warp_Nacelle_Hull_Rectangular_Panel(0.0000001,30,rotation_angle,26,WARP_NACELLE_LENGTH/2-99,ENTERPRISE_GRAY(80),ENTERPRISE_GRAY(60),1,1)}
		#local rotation_angle=rotation_angle+30;
	#end

} 

#declare Warp_Nacelle_Casing = union {

	difference {
  
  		union {
			object {Warp_Nacelle_Body(0,0)}
			object {Warp_Nacelle_Hull_Plating}			
		}
  
		difference {

			prism {                                
				linear_sweep
				linear_spline
		  		-51,
		   		40,
		  		6,
		  		<0,-1>,<4,-1>,<2.5,1>,<-2.5,1>,<-4,-1>,<0,-1>
			  	rotate x*89.3498
			  	translate y*6.75
		  	} 

		  	plane {y,-6.75 rotate x*15}
		  	plane {y,-13.25 rotate x*-30}
		  	
		  	texture {Metallic_Hull_Plating(ENTERPRISE_GRAY(80),0.75,0.24,0.01)}
		}
	}

	object {Main_Energy_Stage_Magnatomic_Flux_Chiller rotate x*-0.6502 translate y*5.625}
}

/*******************************************************************************
* Nacelle Pylon                                                                *
* The nacelle pylons have their positional center at their base inside the     *
* secondary hull to make rotating and positioning them easier.                 *
*******************************************************************************/  

#macro Warp_Nacelle_Pylon_Hull_Panel_Texture(hp_height,hp_width,joint_color)  
	quilted
	texture_map {
		[0.0 Metallic_Hull_Plating(ENTERPRISE_GRAY(85),0.75,0.24,0.01)]
		[1.0 Metallic_Hull_Plating(joint_color,0.90,0.10,0.00)]
	}
	control0 0
	control1 0
	scale <1,hp_height,hp_width>
	translate <0,hp_height/2,hp_width/2>
#end   

#macro Warp_Nacelle_Pylon_Hull_Panel(hp_height,hp_width,x_offset,y_offset,z_offset)
	box {
		<0.125,hp_height/2,hp_width/2>,<-0.125,-hp_height/2,-hp_width/2>
		texture {Warp_Nacelle_Pylon_Hull_Panel_Texture(hp_height,hp_width,ENTERPRISE_GRAY(50))}
		translate <x_offset,y_offset,z_offset>
	}
#end

#declare Warp_Nacelle_Pylon_Hull_Paneling = union {
	object {Warp_Nacelle_Pylon_Hull_Panel(14,4.1625,1.075,7,-2.08125)}
	object {Warp_Nacelle_Pylon_Hull_Panel(14,4.1625,1.075,7,2.08125)}
	object {Warp_Nacelle_Pylon_Hull_Panel(12,2.08125,1.075,20,-3.121875)}
	object {Warp_Nacelle_Pylon_Hull_Panel(12,4.1625,1.075,20,0)}
	object {Warp_Nacelle_Pylon_Hull_Panel(12,2.08125,1.075,20,3.121875)}
	object {Warp_Nacelle_Pylon_Hull_Panel(10,4.1625,1.075,31,-2.08125)}
	object {Warp_Nacelle_Pylon_Hull_Panel(10,4.1625,1.075,31,2.08125)}
	object {Warp_Nacelle_Pylon_Hull_Panel(12,2.08125,1.075,42,-3.121875)}
	object {Warp_Nacelle_Pylon_Hull_Panel(12,4.1625,1.075,42,0)}
	object {Warp_Nacelle_Pylon_Hull_Panel(12,2.08125,1.075,42,3.121875)}
	object {Warp_Nacelle_Pylon_Hull_Panel(10,4.1625,1.075,53,-2.08125)}
	object {Warp_Nacelle_Pylon_Hull_Panel(10,4.1625,1.075,53,2.08125)}

	object {Warp_Nacelle_Pylon_Hull_Panel(14,4.1625,-1.075,7,-2.08125)}
	object {Warp_Nacelle_Pylon_Hull_Panel(14,4.1625,-1.075,7,2.08125)}
	object {Warp_Nacelle_Pylon_Hull_Panel(12,2.08125,-1.075,20,-3.121875)}
	object {Warp_Nacelle_Pylon_Hull_Panel(12,4.1625,-1.075,20,0)}
	object {Warp_Nacelle_Pylon_Hull_Panel(12,2.08125,-1.075,20,3.121875)}
	object {Warp_Nacelle_Pylon_Hull_Panel(12,2.08125,-1.075,31,-3.121875)}
	object {Warp_Nacelle_Pylon_Hull_Panel(12,4.1625,-1.075,31,0)}
	object {Warp_Nacelle_Pylon_Hull_Panel(12,2.08125,-1.075,31,3.121875)}
	object {Warp_Nacelle_Pylon_Hull_Panel(12,2.08125,-1.075,42,-3.121875)}
	object {Warp_Nacelle_Pylon_Hull_Panel(12,4.1625,-1.075,42,0)}
	object {Warp_Nacelle_Pylon_Hull_Panel(12,2.08125,-1.075,42,3.121875)}
	object {Warp_Nacelle_Pylon_Hull_Panel(12,2.08125,-1.075,53,-3.121875)}
	object {Warp_Nacelle_Pylon_Hull_Panel(12,4.1625,-1.075,53,0)}
	object {Warp_Nacelle_Pylon_Hull_Panel(12,2.08125,-1.075,53,3.121875)}
}

/**************************************************************************************
* Pylon grille. This is not currently used but is declared here for convenience. If   *
* you want to show the Enterprise with the original dullsville grille inserts in her  *
* warp nacelle pylons, use this Warp_Nacelle_Pylon_Grille_Texture instead of the blue *
* glowing tubing texture.                                                             *
**************************************************************************************/ 
#declare Warp_Nacelle_Pylon_Grille_Texture = texture {
	pigment {ENTERPRISE_GRAY(60)}
	finish {
	    ambient 0.05
	    brilliance 4
	    diffuse 0.75
	    metallic 0.5
	    specular 0.24
	    roughness 0.65
	    reflection 0.01
	}
	normal {
      bump_map {sys "pylon_grille.bmp" bump_size 1 use_index}
      translate <0.5,0.5,0>
      scale 1
	}
}

// Starboard=1, port=-1
#macro Warp_Nacelle_Pylon_Casing(port_or_starboard)
union {
	difference {
		union {   
	
			object {Warp_Nacelle_Pylon_Hull_Paneling}
			cylinder {<0,0,(-10.7250/2)+(2.4000/2)>, <0,61.150,(-10.7250/2)+(2.4000/2)>, 2.4000/2 texture {Warp_Nacelle_Pylon_Hull_Panel_Texture(10,2.4,ENTERPRISE_GRAY(0))}}
			cylinder {<0,0,(10.7250/2)-(2.4000/2)>, <0,61.150,(10.7250/2)-(2.4000/2)>, 2.4000/2 texture {Warp_Nacelle_Pylon_Hull_Panel_Texture(10,2.4,ENTERPRISE_GRAY(0))}}
		}
	
		// Difference out the portholes:
		#if (NO_PORTHOLES=false)
			object {Rectangular_Porthole(1.65,0.725,1,1) translate <1.2,19,port_or_starboard>}
			object {Rectangular_Porthole(1.65,0.725,1,1) translate <1.2,45,port_or_starboard>}
			object {Rectangular_Porthole(1.65,0.725,1,1) translate <1.2,48.5,port_or_starboard>}
		#end
	
		// Difference out the grille areas:
		#local grille_count=0;
		#while (grille_count<4)
			#local grille_count=grille_count+1;
			object {Rectangular_Porthole(4.5,8.5,1,1) translate <-1.2,12.5+9.25*grille_count,0>}
		#end
	}
	
	// This wall subdivides the pylon along the centerline of its x-axis:
	 box {<-0.25,0,(-10.7250/2)+(2.4000/2)>, <0.25,61.150,(10.7250/2)-(2.4000/2)> texture {Metallic_Hull_Plating(ENTERPRISE_SILVER,0.75,0.24,0.01)}}
}
#end


#declare Warp_Nacelle_Pylon_Glowtube_Texture = texture {

    pigment {rgbt <0,0,1,0.75>}

    finish {
        diffuse 0
        reflection 0
        specular 0
        roughness 1
    }
}

#declare Warp_Nacelle_Pylon_Glowtube_Interior = interior {
	ior 1
	fade_distance 10
	fade_power 1
	fade_color rgb <0.95,0.95,0.95>
	#if (WARP_POWER_LEVEL>0)
	media {
		intervals 1
		samples 10
		confidence 0.99
		variance 1/128
		ratio 1
		emission rgb <WARP_POWER_LEVEL/60,WARP_POWER_LEVEL/60,WARP_POWER_LEVEL/20>
		method 2
		jitter 0
		density {cylindrical scale <0.25,60,0.25>}
	}		
	#end
}
	
#declare Warp_Nacelle_Pylon_Glowtube_Material = material {
	texture {Warp_Nacelle_Pylon_Glowtube_Texture} 
	interior {Warp_Nacelle_Pylon_Glowtube_Interior}
}

// Here is where we part company with the "canon" model and 
// add movie-era Enterprise glowing blue tubes in the grille areas:
#declare Warp_Nacelle_Pylon_Glowtubes = union {
	#local tube_offset=-2.1875;
	#while (tube_offset<=2.1875)
		cylinder {<0,-30,0>,<0,30,0>,0.25 hollow on material {Warp_Nacelle_Pylon_Glowtube_Material} translate <-0.7,30,tube_offset>}
		#local tube_offset=tube_offset+0.7;
	#end
	#if (WARP_POWER_LEVEL>0)
		#local fp = 1;
		#local fd = 0.125;
		light_source {
			<-0.5,12.5,0> 
			color rgb <0.25,0.25,7>*(WARP_POWER_LEVEL/100)
			fade_power fp
			fade_distance fd
		}
		light_source {
			<-0.5,21.75,0> 
			color rgb <0.25,0.25,7>*(WARP_POWER_LEVEL/100)
			fade_power fp
			fade_distance fd
		}
		light_source {
			<-0.5,31.25,0> 
			color rgb <0.25,0.25,7>*(WARP_POWER_LEVEL/100)
			fade_power fp
			fade_distance fd
		}
		light_source {
			<-0.5,40.75,0> 
			color rgb <0.25,0.25,7>*(WARP_POWER_LEVEL/100)
			fade_power fp
			fade_distance fd
		}
	#end
}

#declare Warp_Nacelle_Pylon_Glass = box {
	<1.1,0,(-10.7250/2)+(2.4000/2)>, <1.0,61.150,(10.7250/2)-(2.4000/2)>
	material {Porthole_Glass_Material}
}

#declare Port_Warp_Nacelle_Pylon = union {

	object {Warp_Nacelle_Pylon_Casing(-1)}
	object {Warp_Nacelle_Pylon_Glass}
	object {Warp_Nacelle_Pylon_Glowtubes}
	
	#if (NO_INTERIOR_LIGHTS=false)
		light_source {
			<1,45,-1> 
			color rgb <1,1,0.8> 
			fade_power 10
			fade_distance 1
		}
	#end
}

#declare Starboard_Warp_Nacelle_Pylon = union {

	object {Warp_Nacelle_Pylon_Casing(1)}
	object {Warp_Nacelle_Pylon_Glass}
	object {Warp_Nacelle_Pylon_Glowtubes}

	#if (NO_INTERIOR_LIGHTS=false)
		light_source {
			<1,19,1> 
			color rgb <1,1,0.8>
			fade_power 10
			fade_distance 1
		}
		light_source {
			<1,48.5,1> 
			color rgb <1,1,0.8>
			fade_power 10
			fade_distance 1
		}
	#end
}



/*******************************************************************************
* Port Warp Nacelle                                                            *
*******************************************************************************/
#declare Port_Warp_Nacelle = union {         
	
	object {Port_Nacelle_Registration}
	object {Aft_Intercooler_Assembly rotate <-90,-90,0> translate <0,WARP_NACELLE_MIN_RADIUS+1.55,-WARP_NACELLE_LENGTH/2+(IC_TORUS_MAJOR + IC_TORUS_MINOR + IC_OUTER_TORUS_ORIGIN+AFT_INTERCOOLER_OFFSET)> rotate <-0.64,0,45>}
	object {Aft_Intercooler_Assembly rotate <-90,-90,0> translate <0,WARP_NACELLE_MIN_RADIUS+1.55,-WARP_NACELLE_LENGTH/2+(IC_TORUS_MAJOR + IC_TORUS_MINOR + IC_OUTER_TORUS_ORIGIN+AFT_INTERCOOLER_OFFSET)> rotate <-0.64,0,-45>}
	object {Final_Stage_Magnatomic_Flux_Chiller rotate z*180 translate <-WARP_NACELLE_MIN_RADIUS,0,-WARP_NACELLE_LENGTH/2+2.9+FLUX_CHILLER_LENGTH/2>}
	object {Final_Stage_Magnatomic_Flux_Chiller translate <WARP_NACELLE_MIN_RADIUS,0,-WARP_NACELLE_LENGTH/2+2.9+FLUX_CHILLER_LENGTH/2>}
	object {Warp_Nacelle_Casing rotate z*-90}
	object {Bussard_Collector(1) translate z*(WARP_NACELLE_LENGTH/2)}
	object {Nacelle_End_Cap translate z*(-WARP_NACELLE_LENGTH/2)}
	object {Nacelle_Registration_Light_Housing}
	#if (NO_EXTERIOR_LIGHTS=false)
		object {Nacelle_Registration_Light_Source}
	#end
	object {Running_Light(0.5,0.25,1,0,0,false) translate <0,WARP_NACELLE_MIN_RADIUS,-WARP_NACELLE_LENGTH/2+5>}
	object {First_Stage_Magnatomic_Flux_Constrictor translate <0,0,FSMFC_Z_OFFSET>}
	object {First_Stage_Magnatomic_Flux_Constrictor translate <0,0,FSMFC_Z_OFFSET> rotate z*FSMFC_OFFSET_ANGLE}
	object {First_Stage_Magnatomic_Flux_Constrictor translate <0,0,FSMFC_Z_OFFSET> rotate z*-FSMFC_OFFSET_ANGLE}
	object {Inspection_Hatch_Outline}  
	object {Nacelle_Hood}
}
	
/*******************************************************************************
* Starboard Warp Nacelle                                                       *
*******************************************************************************/
#declare Starboard_Warp_Nacelle = union {

	object {Aft_Intercooler_Assembly rotate <-90,-90,0> translate <0,WARP_NACELLE_MIN_RADIUS+1.55,-WARP_NACELLE_LENGTH/2+(IC_TORUS_MAJOR + IC_TORUS_MINOR + IC_OUTER_TORUS_ORIGIN+AFT_INTERCOOLER_OFFSET)> rotate <-0.64,0,45>}
	object {Aft_Intercooler_Assembly rotate <-90,-90,0> translate <0,WARP_NACELLE_MIN_RADIUS+1.55,-WARP_NACELLE_LENGTH/2+(IC_TORUS_MAJOR + IC_TORUS_MINOR + IC_OUTER_TORUS_ORIGIN+AFT_INTERCOOLER_OFFSET)> rotate <-0.64,0,-45>}
	object {Final_Stage_Magnatomic_Flux_Chiller rotate z*180 translate <-WARP_NACELLE_MIN_RADIUS,0,-WARP_NACELLE_LENGTH/2+2.9+FLUX_CHILLER_LENGTH/2>}
	object {Final_Stage_Magnatomic_Flux_Chiller translate <WARP_NACELLE_MIN_RADIUS,0,-WARP_NACELLE_LENGTH/2+2.9+FLUX_CHILLER_LENGTH/2>}
	object {Warp_Nacelle_Casing rotate z*90}
	object {Starboard_Nacelle_Registration}
	object {Bussard_Collector(-1) translate z*(WARP_NACELLE_LENGTH/2)}
	object {Nacelle_End_Cap translate z*(-WARP_NACELLE_LENGTH/2)}
	object {Nacelle_Registration_Light_Housing rotate z*180}
	#if (NO_EXTERIOR_LIGHTS=false)
		object {Nacelle_Registration_Light_Source rotate z*180}
	#end
	object {Running_Light(0.5,0.25,0,1,0,false) translate <0,WARP_NACELLE_MIN_RADIUS,-WARP_NACELLE_LENGTH/2+5>}
	object {First_Stage_Magnatomic_Flux_Constrictor translate <0,0,FSMFC_Z_OFFSET>}
	object {First_Stage_Magnatomic_Flux_Constrictor translate <0,0,FSMFC_Z_OFFSET> rotate z*FSMFC_OFFSET_ANGLE}
	object {First_Stage_Magnatomic_Flux_Constrictor translate <0,0,FSMFC_Z_OFFSET> rotate z*-FSMFC_OFFSET_ANGLE}
	object {Inspection_Hatch_Outline}
	object {Nacelle_Hood}
}

/*******************************************************************************
* Measurement constants                                                        *
* All units of length are expressed in meters.                                 *
*******************************************************************************/
#declare INTERCONNECTING_PYLON_DEPTH = 4.8; // The thickness of the pylon, measured from outer wall to outer wall

// This prism is used both for the outer walls and glass and
// for the inner structural core:
#macro Interconnecting_Pylon_Prism(prism_depth)
prism {                                
	linear_sweep
	linear_spline
	-prism_depth/2,
	prism_depth/2,
	6,
	<5.5569,14.5942>,<-23.4661,-12.2624>,<-29.1215,-16.6921>,<-9.9147,-16.6921>,<36.9823,14.5942>,<5.5569,14.5942>
}
#end

// This macro draws two panels per invocation (one for port and one for starboard).
// Panels that partially run off of the prism are intersected so that they don't
// exceed the area of the prism.
#macro Interconnecting_Pylon_Hull_Panel(y_offset,z_offset,panel_width,panel_height,base_color,specularity)
	#local offset_sign=-1;
	#while (offset_sign<=1)
		intersection {
			box {<0.00001,panel_height/2,panel_width/2>,<-0.00001,-panel_height/2,-panel_width/2> translate <(INTERCONNECTING_PYLON_DEPTH/2+0.00001)*offset_sign,y_offset,z_offset>}
			object {Interconnecting_Pylon_Prism(10) rotate <0,-90,-90>}
			texture {
				quilted
				texture_map {
					[0.0 Metallic_Hull_Plating(ENTERPRISE_GRAY(base_color),0.99-specularity,specularity,0.01)] // Plate texture
					[1.0 Metallic_Hull_Plating(ENTERPRISE_GRAY(base_color-20),0.90,0.10,0.00)] // Joint texture
				}
				control0 0
				control1 0
				scale <1,panel_height,panel_width>
				translate <(INTERCONNECTING_PYLON_DEPTH/2+0.00001)*offset_sign,y_offset+panel_height/2,z_offset+panel_width/2>
			}
		}
		#local offset_sign=offset_sign+2;
	#end
#end

#macro Interconnecting_Pylon_Trailing_Upper_Edge_Panel(z_start,z_end,z_scale_override,base_color,specularity)
	difference {
		cylinder {<0,0,z_start>,<0,0,z_end>,INTERCONNECTING_PYLON_DEPTH/2}
		plane {x,0 inverse}
		texture {
			quilted
			texture_map {
				[0.0 Metallic_Hull_Plating(ENTERPRISE_GRAY(base_color),0.99-specularity,specularity,0.01)] // Plate texture
				[1.0 Metallic_Hull_Plating(ENTERPRISE_GRAY(base_color-20),0.9,0.1,0)] // Joint texture
			}
			control0 0
			control1 0
			#if (z_scale_override!=0)    
				#local z_scale=z_scale_override;
			#else
				#local z_scale=z_end-z_start;
			#end
			#local xy_scale=INTERCONNECTING_PYLON_DEPTH/2;
			scale <xy_scale,xy_scale,z_scale>
			translate <0,0,z_start>
		}
		translate <-6.9375,0,0>
		rotate y*47.2202
	}
#end

#macro Interconnecting_Pylon_Leading_Edge_Panel(z_start,z_end,z_scale_override,base_color,specularity)
	difference {
		cylinder {<0,0,z_start>,<0,0,z_end>,INTERCONNECTING_PYLON_DEPTH/2 scale <2,1,1>}
		plane {x,0}
		texture {
			quilted
			texture_map {
				[0.0 Metallic_Hull_Plating(ENTERPRISE_GRAY(base_color),0.99-specularity,specularity,0.01)] // Plate texture
				[1.0 Metallic_Hull_Plating(ENTERPRISE_GRAY(base_color-20),0.9,0.1,0)] // Joint texture
				
			}
			control0 0
			control1 0
			#if (z_scale_override!=0)    
				#local z_scale=z_scale_override;
			#else
				#local z_scale=z_end-z_start;
			#end
			#local xy_scale=INTERCONNECTING_PYLON_DEPTH/2;
			scale <xy_scale,xy_scale,z_scale>
			translate <0,0,z_start>
		}
		translate <8.3834,0,0>
		rotate y*56.2916
	}
#end

#declare Interconnecting_Pylon_Trailing_Upper_Edge = union {
	object {Interconnecting_Pylon_Trailing_Upper_Edge_Panel( -0.50, 10.00,0,80,0.24)}
	object {Interconnecting_Pylon_Trailing_Upper_Edge_Panel( -1.95, -0.50,0,70,0.24)}
	object {Interconnecting_Pylon_Trailing_Upper_Edge_Panel( -4.15, -1.95,0,70,0.22)}
	object {Interconnecting_Pylon_Trailing_Upper_Edge_Panel( -9.30, -4.15,0,80,0.25)}
	object {Interconnecting_Pylon_Trailing_Upper_Edge_Panel(-15.18, -9.30,0,80,0.26)}
	object {Interconnecting_Pylon_Trailing_Upper_Edge_Panel(-16.63,-15.18,0,80,0.24)}
	object {Interconnecting_Pylon_Trailing_Upper_Edge_Panel(-16.63,-15.18,0,80,0.24)}
	object {Interconnecting_Pylon_Trailing_Upper_Edge_Panel(-20.30,-16.63,0,80,0.27)}
	object {Interconnecting_Pylon_Trailing_Upper_Edge_Panel(-25.60,-20.30,0,80,0.27)}
} 

#declare Interconnecting_Pylon_Trailing_Lower_Edge = difference {
	#local z_start=-40;
	#local z_end=-25;
	cylinder {<0,0,z_start>,<0,0,z_end>,INTERCONNECTING_PYLON_DEPTH/2}
	plane {x,0 inverse}
	texture {
		quilted
		texture_map {
			[0.0 Metallic_Hull_Plating(ENTERPRISE_GRAY(80),0.77,0.22,0.01)] // Plate texture
			[1.0 Metallic_Hull_Plating(ENTERPRISE_GRAY(40),0.9,0.1,0)] // Joint texture
		}
		control0 0
		control1 0
		#local z_scale=z_start-z_end;
		#local xy_scale=INTERCONNECTING_PYLON_DEPTH/2;
		scale <xy_scale,xy_scale,z_scale>
		translate <0,0,z_end>
	}
	translate <-4.8162,0,0>
	rotate y*51.9295
} 

#declare Interconnecting_Pylon_Leading_Edge = union {
	object {Interconnecting_Pylon_Leading_Edge_Panel(21.10,36.00,7,80,0.24)}
	object {Interconnecting_Pylon_Leading_Edge_Panel(19.30,21.10,0,70,0.24)}
	object {Interconnecting_Pylon_Leading_Edge_Panel(16.51,19.30,0,70,0.22)}
	object {Interconnecting_Pylon_Leading_Edge_Panel(10.10,16.51,0,80,0.26)}
	object {Interconnecting_Pylon_Leading_Edge_Panel( 3.00,10.10,0,80,0.24)}
	object {Interconnecting_Pylon_Leading_Edge_Panel(-3.41, 3.00,0,80,0.25)}
	object {Interconnecting_Pylon_Leading_Edge_Panel(-10.0,-3.41,0,80,0.24)}
	object {Interconnecting_Pylon_Leading_Edge_Panel(-15.0,-10.0,0,80,0.25)}
} 

#declare Interconnecting_Pylon_Hull_Paneling = union {

	// Decks 7 & 8:
	union {Interconnecting_Pylon_Hull_Panel(6.76,-2.025,6.35,4,80,0.25)}
	union {Interconnecting_Pylon_Hull_Panel(6.76, 4.150,6.00,4,80,0.27)}
	union {Interconnecting_Pylon_Hull_Panel(6.76,10.150,6.00,4,80,0.26)}
	union {Interconnecting_Pylon_Hull_Panel(6.76,14.400,2.50,4,75,0.24)}
	union {Interconnecting_Pylon_Hull_Panel(6.76,18.650,6.00,4,80,0.27)}
	union {Interconnecting_Pylon_Hull_Panel(6.76,25.025,6.75,4,80,0.25)}

	// Upper separation plane:
	union {Interconnecting_Pylon_Hull_Panel(4.26,-4.05,4.4,1,70,0.26)}
	union {Interconnecting_Pylon_Hull_Panel(4.26, 1.15,6.0,1,70,0.28)}
	union {Interconnecting_Pylon_Hull_Panel(4.26, 7.15,6.0,1,70,0.27)}
	union {Interconnecting_Pylon_Hull_Panel(4.26,13.15,6.0,1,70,0.25)}
	union {Interconnecting_Pylon_Hull_Panel(4.26,19.65,7.0,1,70,0.26)}

	// Lower separation plane:
	union {Interconnecting_Pylon_Hull_Panel(3.01,-6.35,3.0,1.5,70,0.24)}
	union {Interconnecting_Pylon_Hull_Panel(3.01,-1.85,6.0,1.5,70,0.25)}
	union {Interconnecting_Pylon_Hull_Panel(3.01, 4.15,6.0,1.5,70,0.24)}
	union {Interconnecting_Pylon_Hull_Panel(3.01,10.15,6.0,1.5,70,0.27)}
	union {Interconnecting_Pylon_Hull_Panel(3.01,16.95,7.6,1.5,70,0.24)}
	
	// Decks 9 & 10:
	union {Interconnecting_Pylon_Hull_Panel( 0.51,-9.925,3.75,3.5,80,0.26)}
	union {Interconnecting_Pylon_Hull_Panel( 0.51,-5.050,6.00,3.5,80,0.23)}
	union {Interconnecting_Pylon_Hull_Panel(-0.49,-0.800,2.50,5.5,75,0.25)}
	union {Interconnecting_Pylon_Hull_Panel( 0.51, 2.300,3.70,3.5,80,0.24)}
	union {Interconnecting_Pylon_Hull_Panel( 0.51, 7.150,6.00,3.5,80,0.26)}
	union {Interconnecting_Pylon_Hull_Panel( 0.51,14.400,8.50,3.5,80,0.25)}

	// Decks 11 & 12:
	union {Interconnecting_Pylon_Hull_Panel(-3.24,-14.500,4.60,4,80,0.24)}
	union {Interconnecting_Pylon_Hull_Panel(-3.24, -8.625,7.15,4,80,0.26)}
	union {Interconnecting_Pylon_Hull_Panel(-3.24, -3.550,3.00,4,80,0.27)}
	union {Interconnecting_Pylon_Hull_Panel(-3.24,  4.075,7.25,4,80,0.25)}
	union {Interconnecting_Pylon_Hull_Panel(-3.24, 10.575,5.75,4,80,0.26)}
	
	// Decks 12 & 13:
	union {Interconnecting_Pylon_Hull_Panel(-5.74,-15.550,3.00,1.0,80,0.27)}
	union {Interconnecting_Pylon_Hull_Panel(-5.74,-11.050,6.00,1.0,80,0.24)}
	union {Interconnecting_Pylon_Hull_Panel(-5.74, -5.050,6.00,1.0,80,0.25)}
	union {Interconnecting_Pylon_Hull_Panel(-7.49,-17.500,4.50,2.5,80,0.25)}
	union {Interconnecting_Pylon_Hull_Panel(-8.74,-14.000,2.50,5.0,75,0.24)}
	union {Interconnecting_Pylon_Hull_Panel(-7.49, -9.275,6.95,2.5,75,0.26)}
	union {Interconnecting_Pylon_Hull_Panel(-7.49, -3.925,3.75,2.5,75,0.25)}
	union {Interconnecting_Pylon_Hull_Panel(-5.99, -0.800,2.50,5.5,75,0.27)}
	union {Interconnecting_Pylon_Hull_Panel(-6.99,  3.950,7.00,3.5,80,0.24)}
	
	// Deck 14:
	union {Interconnecting_Pylon_Hull_Panel(-11.24,-22.00,7.5,5.0,80,0.24)}
	union {Interconnecting_Pylon_Hull_Panel(-11.24,-16.75,3.0,5.0,80,0.25)}
	union {Interconnecting_Pylon_Hull_Panel(-12.49,-14.00,2.5,2.5,75,0.25)}
	union {Interconnecting_Pylon_Hull_Panel(-11.24,-11.25,3.0,5.0,80,0.24)}
	union {Interconnecting_Pylon_Hull_Panel(-11.24, -6.75,6.0,5.0,80,0.25)}
	union {Interconnecting_Pylon_Hull_Panel(-11.24, -0.75,6.0,5.0,80,0.24)}	
}

// This is the definition of the basic shape of the interconnecting pylon:
#macro Base_Interconnecting_Pylon(apply_textures)
	union {
		difference {
			union {
				
				union {
					
					object {Interconnecting_Pylon_Prism(INTERCONNECTING_PYLON_DEPTH)}
		
					// The top and bottom of the trailing edge of the pylon is rounded off with two half cylinders,
					// the lower one skewed slightly further back:
					#if (apply_textures=true)
						object {Interconnecting_Pylon_Trailing_Upper_Edge}
					#else
						cylinder {<5.5569,0,14.5942>,<-23.4661,0,-12.2624>,INTERCONNECTING_PYLON_DEPTH/2}
					#end

					#if (apply_textures=true)
						object {Interconnecting_Pylon_Trailing_Lower_Edge}
					#else
						cylinder {<-23.4661,0,-12.2624>,<-29.1215,0,-16.6921>,INTERCONNECTING_PYLON_DEPTH/2}
					#end
					
					// The half-cylinder that forms the leading edge of the pylon is stretched 2x in the x-axis:
					#if (apply_textures=true)
						object {Interconnecting_Pylon_Leading_Edge}
					#else
						cylinder {<-4.95735,0,-16.6921>,<18.49115,0,14.5942>,INTERCONNECTING_PYLON_DEPTH/2 scale <2,1,1>}
					#end
	
					// Rotate to the correct orientation:
					rotate <0,-90,-90>
				}

				#if (apply_textures=true)
					object {Interconnecting_Pylon_Hull_Paneling}
				#end
			}
			
			// Chop off the top and bottom:
			plane {y,8.76 inverse}	// This cuts off the top at deck 6
			plane {y,-15.365}		// This cuts off the bottom at deck 15			
		}		
	}
#end

// The outer hull layer:
#declare Outer_Pylon_Hull = difference {
	
	#local scaling_factor = (INTERCONNECTING_PYLON_DEPTH-(OUTER_HULL_THICKNESS*2))/INTERCONNECTING_PYLON_DEPTH;
	
	object {Base_Interconnecting_Pylon(true)}
	object {Base_Interconnecting_Pylon(false) scale scaling_factor}
}

// The glass sandwich layer:
#declare Pylon_Glass = difference {

	#local outer_scaling_factor = (INTERCONNECTING_PYLON_DEPTH-(OUTER_HULL_THICKNESS*2)-0.0002)/INTERCONNECTING_PYLON_DEPTH;
	#local inner_scaling_factor = (INTERCONNECTING_PYLON_DEPTH-(OUTER_HULL_THICKNESS*2+PORTHOLE_THICKNESS*2))/INTERCONNECTING_PYLON_DEPTH;

	object {Base_Interconnecting_Pylon(false) scale outer_scaling_factor}
	object {Base_Interconnecting_Pylon(false) scale inner_scaling_factor}
	
	material {Porthole_Glass_Material}
}

// The inner hull layer:
#declare Inner_Pylon_Hull = difference {
	
	#local outer_scaling_factor = (INTERCONNECTING_PYLON_DEPTH-(OUTER_HULL_THICKNESS*2+PORTHOLE_THICKNESS*2+0.0002))/INTERCONNECTING_PYLON_DEPTH;
	#local inner_scaling_factor = (INTERCONNECTING_PYLON_DEPTH-HULL_THICKNESS*2)/INTERCONNECTING_PYLON_DEPTH;
	
	object {Base_Interconnecting_Pylon(false) scale outer_scaling_factor}
	object {Base_Interconnecting_Pylon(false) scale inner_scaling_factor}
	
	texture {Bulkhead_Texture}
}

// This places a core divider in the middle of the pylon
// so that you don't look inside the windows and see
// through to the other side!
#declare Interconnecting_Pylon_Core_Bulkhead = difference {

	Interconnecting_Pylon_Prism(2.33) 

	// Chop off the top and bottom:
	plane {z,8.76 inverse}	// This cuts off the top at deck 6
	plane {z,-15.365}		// This cuts off the bottom at deck 15

	// Rotate to the correct orientation:
	rotate <0,-90,-90>

	texture {Bulkhead_Texture}
}

/**************** Decks *****************/
#macro Interconnecting_Pylon_Deck(deck_offset)
	intersection {
		
		object {Base_Interconnecting_Pylon(false) scale 0.99}		
		box {<-INTERCONNECTING_PYLON_DEPTH/2,-DECK_THICKNESS/2+deck_offset,-30>,<INTERCONNECTING_PYLON_DEPTH/2,DECK_THICKNESS/2+deck_offset,40>}
		texture {Deck_Texture}
	}
#end

#declare Interconnecting_Pylon_Decks = union {
	object {Interconnecting_Pylon_Deck(INTERCONNECTING_DECK_7_Y_OFFSET)}
	object {Interconnecting_Pylon_Deck(INTERCONNECTING_DECK_8_Y_OFFSET)}
	object {Interconnecting_Pylon_Deck(INTERCONNECTING_DECK_9_Y_OFFSET)}
	object {Interconnecting_Pylon_Deck(INTERCONNECTING_DECK_10_Y_OFFSET)}
	object {Interconnecting_Pylon_Deck(INTERCONNECTING_DECK_11_Y_OFFSET)}
	object {Interconnecting_Pylon_Deck(INTERCONNECTING_DECK_12_Y_OFFSET)}
	object {Interconnecting_Pylon_Deck(INTERCONNECTING_DECK_13_Y_OFFSET)}
	object {Interconnecting_Pylon_Deck(INTERCONNECTING_DECK_14_Y_OFFSET)}
}

/**************** Interconnecting Pylon ******************/
#declare Interconnecting_Pylon = union {
	
	// Punch out the portholes:
	difference {
		
		union {
			object {Outer_Pylon_Hull}
			object {Inner_Pylon_Hull}
		}

		// Punch out the portholes. Since we are making both sides identical,
		// just punch straight through both walls on the port and starboard:		
		#if (NO_PORTHOLES=false)	
			
			// Deck 9 portholes:
			object {Rectangular_Porthole(1.65,0.725,1,10) translate <0,3.0000,-0.8000>}
			object {Rectangular_Porthole(1.65,0.725,1,10) translate <0,3.0000,14.4000>}
			object {Rectangular_Porthole(1.65,0.725,1,10) translate <0,3.0000,17.2000>}

			// Deck 10 portholes:
			object {Rectangular_Porthole(1.65,0.725,1,10) translate <0,0.5000,-6.2000>}
			object {Rectangular_Porthole(1.65,0.725,1,10) translate <0,0.5000,-0.8000>}
			object {Round_Porthole(0.3625,1,10) translate <0,0.5000,5.2000>}				
			object {Round_Porthole(0.3625,1,10) translate <0,0.5000,7.4000>}				
			                                 
			// Deck 11 portholes:
			object {Rectangular_Porthole(1.65,0.725,1,10) translate <0,-2.0000,-0.8000>}
			object {Rectangular_Porthole(1.65,0.725,1,10) translate <0,-2.0000,3.6000>}
			object {Rectangular_Porthole(1.65,0.725,1,10) translate <0,-2.0000,6.3333>}
			object {Rectangular_Porthole(1.65,0.725,1,10) translate <0,-2.0000,9.0667>}
			object {Rectangular_Porthole(1.65,0.725,1,10) translate <0,-2.0000,11.8000>}
			
			// Deck 12 portholes:
			object {Round_Porthole(0.3625,1,10) translate <0,-4.5000,-13.3000>}				
			object {Rectangular_Porthole(1.65,0.725,1,10) translate <0,-4.5000,-10.5000>}
			object {Rectangular_Porthole(1.65,0.725,1,10) translate <0,-4.5000,-0.8000>}
			object {Round_Porthole(0.3625,1,10) translate <0,-4.5000,3.6000>}				
			
			// Deck 13 portholes:
			object {Rectangular_Porthole(1.65,0.725,1,10) translate <0,-7.0000,-4.1000>}
			object {Rectangular_Porthole(1.65,0.725,1,10) translate <0,-7.0000,-0.8000>}

		#end
	}

	// Add the glass:
	object {Pylon_Glass}

	// Add the core bulkhead and the decks:
	object {Interconnecting_Pylon_Core_Bulkhead}
	object {Interconnecting_Pylon_Decks}		

		// Add interior light sources:
	#if (NO_INTERIOR_LIGHTS=false)
		light_source {<2.2,3,-0.8> color <1,1,0.8> fade_distance 2 fade_power 5}
		light_source {<2.2,3,14.4> color <1,1,0.8> fade_distance 2 fade_power 5}
		light_source {<2.2,3,17.2> color <1,1,0.8> fade_distance 2 fade_power 5}
		light_source {<2.2,0.5,-6.2> color <1,1,0.8> fade_distance 2 fade_power 5}
		light_source {<2.2,0.5,-0.8> color <1,1,0.8> fade_distance 2 fade_power 5}
		light_source {<2.2,0.5,5.2> color <1,1,0.8> fade_distance 2 fade_power 5}
		light_source {<2.2,0.5,7.4> color <1,1,0.8> fade_distance 2 fade_power 5}
		light_source {<2.2,-2,-0.8> color <1,1,0.8> fade_distance 2 fade_power 5}
		light_source {<2.2,-2,3.6> color <1,1,0.8> fade_distance 2 fade_power 5}
		light_source {<2.2,-2,6.33> color <1,1,0.8> fade_distance 2 fade_power 5}
		light_source {<2.2,-2,9.07> color <1,1,0.8> fade_distance 2 fade_power 5}
		light_source {<2.2,-2,11.8> color <1,1,0.8> fade_distance 2 fade_power 5}
		light_source {<2.2,-4.5,-13.3> color <1,1,0.8> fade_distance 2 fade_power 5}
		light_source {<2.2,-4.5,-10.5> color <1,1,0.8> fade_distance 2 fade_power 5}
		light_source {<2.2,-4.5,-0.8> color <1,1,0.8> fade_distance 2 fade_power 5}
		light_source {<2.2,-4.5,3.6> color <1,1,0.8> fade_distance 2 fade_power 5}
		light_source {<2.2,-7,-4.1> color <1,1,0.8> fade_distance 2 fade_power 5}
		light_source {<2.2,-7,-0.8> color <1,1,0.8> fade_distance 2 fade_power 5}

		light_source {<-2.2,3,-0.8> color <1,1,0.8> fade_distance 2 fade_power 5}
		light_source {<-2.2,3,14.4> color <1,1,0.8> fade_distance 2 fade_power 5}
		light_source {<-2.2,3,17.2> color <1,1,0.8> fade_distance 2 fade_power 5}
		light_source {<-2.2,0.5,-6.2> color <1,1,0.8> fade_distance 2 fade_power 5}
		light_source {<-2.2,0.5,-0.8> color <1,1,0.8> fade_distance 2 fade_power 5}
		light_source {<-2.2,0.5,5.2> color <1,1,0.8> fade_distance 2 fade_power 5}
		light_source {<-2.2,0.5,7.4> color <1,1,0.8> fade_distance 2 fade_power 5}
		light_source {<-2.2,-2,-0.8> color <1,1,0.8> fade_distance 2 fade_power 5}
		light_source {<-2.2,-2,3.6> color <1,1,0.8> fade_distance 2 fade_power 5}
		light_source {<-2.2,-2,6.33> color <1,1,0.8> fade_distance 2 fade_power 5}
		light_source {<-2.2,-2,9.07> color <1,1,0.8> fade_distance 2 fade_power 5}
		light_source {<-2.2,-2,11.8> color <1,1,0.8> fade_distance 2 fade_power 5}
		light_source {<-2.2,-4.5,-13.3> color <1,1,0.8> fade_distance 2 fade_power 5}
		light_source {<-2.2,-4.5,-10.5> color <1,1,0.8> fade_distance 2 fade_power 5}
		light_source {<-2.2,-4.5,-0.8> color <1,1,0.8> fade_distance 2 fade_power 5}
		light_source {<-2.2,-4.5,3.6> color <1,1,0.8> fade_distance 2 fade_power 5}
		light_source {<-2.2,-7,-4.1> color <1,1,0.8> fade_distance 2 fade_power 5}
		light_source {<-2.2,-7,-0.8> color <1,1,0.8> fade_distance 2 fade_power 5}
	#end
}

/*******************************************************************************
* Measurement constants                                                        *
* All units of length are expressed in meters. All offsets are measured from   *
* the geometric center of the ship (which lies just aft of the interconnecting *
* pylon between the primary and secondary hulls) to the centerpoint of the     *
* target object.                                                               *
*******************************************************************************/
#declare OVERALL_LENGTH = 288.646;                         // Based on a length of 947' as shown in Matt Jeffries' original drawings
#declare OVERALL_HEIGHT = 64.525;                          // Excludes nacelles. Measured from top of bridge dome to bottom of secondary hull

#declare PRIMARY_HULL_X_OFFSET = 0.000;
#declare PRIMARY_HULL_Y_OFFSET = 15.860;
#declare PRIMARY_HULL_Z_OFFSET = 80.806;

#declare SECONDARY_HULL_X_OFFSET = 0.000;
#declare SECONDARY_HULL_Y_OFFSET = -18.8775;
#declare SECONDARY_HULL_Z_OFFSET = 0.000; 

#declare INTERCONNECTING_PYLON_X_OFFSET = 0.000;
#declare INTERCONNECTING_PYLON_Y_OFFSET = 6.3625;
#declare INTERCONNECTING_PYLON_Z_OFFSET = 25.097; 

#declare WARP_NACELLE_X_OFFSET = 41.950;
#declare WARP_NACELLE_Y_OFFSET = 28.113;
#declare WARP_NACELLE_Z_OFFSET = -66.142;

#declare WARP_NACELLE_PYLON_ANGLE = 43;                    // Angle measured from vertical Y-plane
#declare WARP_NACELLE_PYLON_X_OFFSET = 0.000;
#declare WARP_NACELLE_PYLON_Y_OFFSET = -20.8275;           // The offset if the pylons continued into the hull until they met each other
#declare WARP_NACELLE_PYLON_Z_OFFSET = -30.223;

/*******************************************************************************
* The Starship Enterpise                                                       *
*******************************************************************************/

#declare Starship_Enterprise = union {         
	object {Primary_Hull translate <PRIMARY_HULL_X_OFFSET,PRIMARY_HULL_Y_OFFSET,PRIMARY_HULL_Z_OFFSET>}
	object {Secondary_Hull translate <SECONDARY_HULL_X_OFFSET,SECONDARY_HULL_Y_OFFSET,SECONDARY_HULL_Z_OFFSET>}
	object {Starboard_Warp_Nacelle_Pylon  rotate z*-WARP_NACELLE_PYLON_ANGLE translate <WARP_NACELLE_PYLON_X_OFFSET,WARP_NACELLE_PYLON_Y_OFFSET,WARP_NACELLE_PYLON_Z_OFFSET>}
	object {Interconnecting_Pylon  translate <INTERCONNECTING_PYLON_X_OFFSET,INTERCONNECTING_PYLON_Y_OFFSET,INTERCONNECTING_PYLON_Z_OFFSET>}
	object {Starboard_Warp_Nacelle translate <WARP_NACELLE_X_OFFSET,WARP_NACELLE_Y_OFFSET,WARP_NACELLE_Z_OFFSET>}  
	object {Port_Warp_Nacelle translate <-WARP_NACELLE_X_OFFSET,WARP_NACELLE_Y_OFFSET,WARP_NACELLE_Z_OFFSET>}  
	object {Port_Warp_Nacelle_Pylon  rotate <0,180,WARP_NACELLE_PYLON_ANGLE> translate <WARP_NACELLE_PYLON_X_OFFSET,WARP_NACELLE_PYLON_Y_OFFSET,WARP_NACELLE_PYLON_Z_OFFSET>}
}
       
/******************* End of starship_enterprise.inc ***************************/

light_source {
	y*1000
	color 1
}

object {Starship_Enterprise}

camera {
	location <0,200,100>
	look_at <0,0,100>
}